# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignErrorValue = typing___NewType("CampaignErrorValue", builtin___int)
    type___CampaignErrorValue = CampaignErrorValue
    CampaignError: _CampaignError
    class _CampaignError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignErrorEnum.CampaignErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 0)
        UNKNOWN = typing___cast(CampaignErrorEnum.CampaignErrorValue, 1)
        CANNOT_TARGET_CONTENT_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 3
        )
        CANNOT_TARGET_SEARCH_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 4
        )
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 5
        )
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 6
        )
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 7
        )
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 8
        )
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 9
        )
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 10
        )
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 11
        )
        DUPLICATE_CAMPAIGN_NAME = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 12
        )
        INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 13
        )
        INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 14)
        INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 15
        )
        INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignErrorValue, 16)
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 17
        )
        MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 18
        )
        TIME_UNIT_NOT_SUPPORTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 19
        )
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 20
        )
        BUDGET_CANNOT_BE_SHARED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 21
        )
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 22
        )
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 23
        )
        CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 24
        )
        CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 25
        )
        MISSING_SHOPPING_SETTING = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 26
        )
        INVALID_SHOPPING_SALES_COUNTRY = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 27
        )
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 31
        )
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 32
        )
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 33
        )
        CANNOT_SET_AD_ROTATION_MODE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 34
        )
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 35
        )
        CANNOT_SET_DATE_TO_PAST = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 36
        )
        MISSING_HOTEL_CUSTOMER_LINK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 37
        )
        INVALID_HOTEL_CUSTOMER_LINK = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 38
        )
        MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 39)
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 40
        )
        APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignErrorValue, 41)
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 42
        )
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 43
        )
        INSUFFICIENT_APP_INSTALLS_COUNT = typing___cast(
            CampaignErrorEnum.CampaignErrorValue, 44
        )
        SENSITIVE_CATEGORY_APP = typing___cast(CampaignErrorEnum.CampaignErrorValue, 45)
    UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 0)
    UNKNOWN = typing___cast(CampaignErrorEnum.CampaignErrorValue, 1)
    CANNOT_TARGET_CONTENT_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 3
    )
    CANNOT_TARGET_SEARCH_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 4
    )
    CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 5
    )
    CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 6
    )
    CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 7
    )
    CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 8
    )
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 9
    )
    CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 10
    )
    CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 11
    )
    DUPLICATE_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 12)
    INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 13
    )
    INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignErrorValue, 14)
    INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 15
    )
    INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignErrorValue, 16)
    CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 17
    )
    MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 18
    )
    TIME_UNIT_NOT_SUPPORTED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 19)
    INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 20
    )
    BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignErrorEnum.CampaignErrorValue, 21)
    CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 22
    )
    CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 23
    )
    CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 24
    )
    CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 25
    )
    MISSING_SHOPPING_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 26)
    INVALID_SHOPPING_SALES_COUNTRY = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 27
    )
    ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 31
    )
    INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 32
    )
    AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 33
    )
    CANNOT_SET_AD_ROTATION_MODE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 34
    )
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 35
    )
    CANNOT_SET_DATE_TO_PAST = typing___cast(CampaignErrorEnum.CampaignErrorValue, 36)
    MISSING_HOTEL_CUSTOMER_LINK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 37
    )
    INVALID_HOTEL_CUSTOMER_LINK = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 38
    )
    MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignErrorValue, 39)
    CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 40
    )
    APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignErrorValue, 41)
    SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 42
    )
    MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 43
    )
    INSUFFICIENT_APP_INSTALLS_COUNT = typing___cast(
        CampaignErrorEnum.CampaignErrorValue, 44
    )
    SENSITIVE_CATEGORY_APP = typing___cast(CampaignErrorEnum.CampaignErrorValue, 45)
    type___CampaignError = CampaignError
    def __init__(self,) -> None: ...

type___CampaignErrorEnum = CampaignErrorEnum
