from typing import Any

class AgeRangeViewServiceStub:
    GetAgeRangeView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AgeRangeViewServiceServicer:
    def GetAgeRangeView(self, request: Any, context: Any) -> None: ...

def add_AgeRangeViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
