from typing import Any

class UserListServiceStub:
    GetUserList: Any = ...
    MutateUserLists: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserListServiceServicer:
    def GetUserList(self, request: Any, context: Any) -> None: ...
    def MutateUserLists(self, request: Any, context: Any) -> None: ...

def add_UserListServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
