# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.tracking_code_page_format_pb2 import (
    TrackingCodePageFormatEnum as google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum,
)
from google.ads.google_ads.v4.proto.enums.tracking_code_type_pb2 import (
    TrackingCodeTypeEnum as google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TagSnippet(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue = ...
    page_format: google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue = ...
    @property
    def global_site_tag(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def event_snippet(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___tracking_code_type_pb2___TrackingCodeTypeEnum.TrackingCodeTypeValue
        ] = None,
        page_format: typing___Optional[
            google___ads___googleads___v4___enums___tracking_code_page_format_pb2___TrackingCodePageFormatEnum.TrackingCodePageFormatValue
        ] = None,
        global_site_tag: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        event_snippet: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "event_snippet", b"event_snippet", "global_site_tag", b"global_site_tag"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
            "page_format",
            b"page_format",
            "type",
            b"type",
        ],
    ) -> None: ...

type___TagSnippet = TagSnippet
