# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LinkedAccountTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LinkedAccountTypeValue = typing___NewType("LinkedAccountTypeValue", builtin___int)
    type___LinkedAccountTypeValue = LinkedAccountTypeValue
    LinkedAccountType: _LinkedAccountType
    class _LinkedAccountType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LinkedAccountTypeEnum.LinkedAccountTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 0)
        UNKNOWN = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 1)
        THIRD_PARTY_APP_ANALYTICS = typing___cast(
            LinkedAccountTypeEnum.LinkedAccountTypeValue, 2
        )
        DATA_PARTNER = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 3)
        GOOGLE_ADS = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 4)
    UNSPECIFIED = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 0)
    UNKNOWN = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 1)
    THIRD_PARTY_APP_ANALYTICS = typing___cast(
        LinkedAccountTypeEnum.LinkedAccountTypeValue, 2
    )
    DATA_PARTNER = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 3)
    GOOGLE_ADS = typing___cast(LinkedAccountTypeEnum.LinkedAccountTypeValue, 4)
    type___LinkedAccountType = LinkedAccountType
    def __init__(self,) -> None: ...

type___LinkedAccountTypeEnum = LinkedAccountTypeEnum
