# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PricePlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PricePlaceholderFieldValue = typing___NewType(
        "PricePlaceholderFieldValue", builtin___int
    )
    type___PricePlaceholderFieldValue = PricePlaceholderFieldValue
    PricePlaceholderField: _PricePlaceholderField
    class _PricePlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 1)
        TYPE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 2)
        PRICE_QUALIFIER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 3
        )
        TRACKING_TEMPLATE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 4
        )
        LANGUAGE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 5
        )
        FINAL_URL_SUFFIX = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 6
        )
        ITEM_1_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 100
        )
        ITEM_1_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 101
        )
        ITEM_1_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 102
        )
        ITEM_1_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 103
        )
        ITEM_1_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 104
        )
        ITEM_1_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 105
        )
        ITEM_2_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 200
        )
        ITEM_2_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 201
        )
        ITEM_2_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 202
        )
        ITEM_2_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 203
        )
        ITEM_2_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 204
        )
        ITEM_2_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 205
        )
        ITEM_3_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 300
        )
        ITEM_3_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 301
        )
        ITEM_3_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 302
        )
        ITEM_3_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 303
        )
        ITEM_3_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 304
        )
        ITEM_3_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 305
        )
        ITEM_4_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 400
        )
        ITEM_4_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 401
        )
        ITEM_4_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 402
        )
        ITEM_4_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 403
        )
        ITEM_4_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 404
        )
        ITEM_4_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 405
        )
        ITEM_5_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 500
        )
        ITEM_5_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 501
        )
        ITEM_5_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 502
        )
        ITEM_5_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 503
        )
        ITEM_5_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 504
        )
        ITEM_5_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 505
        )
        ITEM_6_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 600
        )
        ITEM_6_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 601
        )
        ITEM_6_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 602
        )
        ITEM_6_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 603
        )
        ITEM_6_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 604
        )
        ITEM_6_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 605
        )
        ITEM_7_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 700
        )
        ITEM_7_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 701
        )
        ITEM_7_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 702
        )
        ITEM_7_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 703
        )
        ITEM_7_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 704
        )
        ITEM_7_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 705
        )
        ITEM_8_HEADER = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 800
        )
        ITEM_8_DESCRIPTION = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 801
        )
        ITEM_8_PRICE = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 802
        )
        ITEM_8_UNIT = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 803
        )
        ITEM_8_FINAL_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 804
        )
        ITEM_8_FINAL_MOBILE_URLS = typing___cast(
            PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 805
        )
    UNSPECIFIED = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 1)
    TYPE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 2)
    PRICE_QUALIFIER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 3
    )
    TRACKING_TEMPLATE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 4
    )
    LANGUAGE = typing___cast(PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 5)
    FINAL_URL_SUFFIX = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 6
    )
    ITEM_1_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 100
    )
    ITEM_1_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 101
    )
    ITEM_1_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 102
    )
    ITEM_1_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 103
    )
    ITEM_1_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 104
    )
    ITEM_1_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 105
    )
    ITEM_2_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 200
    )
    ITEM_2_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 201
    )
    ITEM_2_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 202
    )
    ITEM_2_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 203
    )
    ITEM_2_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 204
    )
    ITEM_2_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 205
    )
    ITEM_3_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 300
    )
    ITEM_3_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 301
    )
    ITEM_3_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 302
    )
    ITEM_3_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 303
    )
    ITEM_3_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 304
    )
    ITEM_3_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 305
    )
    ITEM_4_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 400
    )
    ITEM_4_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 401
    )
    ITEM_4_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 402
    )
    ITEM_4_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 403
    )
    ITEM_4_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 404
    )
    ITEM_4_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 405
    )
    ITEM_5_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 500
    )
    ITEM_5_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 501
    )
    ITEM_5_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 502
    )
    ITEM_5_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 503
    )
    ITEM_5_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 504
    )
    ITEM_5_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 505
    )
    ITEM_6_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 600
    )
    ITEM_6_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 601
    )
    ITEM_6_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 602
    )
    ITEM_6_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 603
    )
    ITEM_6_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 604
    )
    ITEM_6_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 605
    )
    ITEM_7_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 700
    )
    ITEM_7_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 701
    )
    ITEM_7_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 702
    )
    ITEM_7_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 703
    )
    ITEM_7_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 704
    )
    ITEM_7_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 705
    )
    ITEM_8_HEADER = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 800
    )
    ITEM_8_DESCRIPTION = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 801
    )
    ITEM_8_PRICE = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 802
    )
    ITEM_8_UNIT = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 803
    )
    ITEM_8_FINAL_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 804
    )
    ITEM_8_FINAL_MOBILE_URLS = typing___cast(
        PricePlaceholderFieldEnum.PricePlaceholderFieldValue, 805
    )
    type___PricePlaceholderField = PricePlaceholderField
    def __init__(self,) -> None: ...

type___PricePlaceholderFieldEnum = PricePlaceholderFieldEnum
