from typing import Any

class SharedSetServiceStub:
    GetSharedSet: Any = ...
    MutateSharedSets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SharedSetServiceServicer:
    def GetSharedSet(self, request: Any, context: Any) -> None: ...
    def MutateSharedSets(self, request: Any, context: Any) -> None: ...

def add_SharedSetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
