# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.account_link_status_pb2 import (
    AccountLinkStatusEnum as google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.linked_account_type_pb2 import (
    LinkedAccountTypeEnum as google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.mobile_app_vendor_pb2 import (
    MobileAppVendorEnum as google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountLink(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum.AccountLinkStatusValue = ...
    type: google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum.LinkedAccountTypeValue = ...
    @property
    def account_link_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def third_party_app_analytics(
        self,
    ) -> type___ThirdPartyAppAnalyticsLinkIdentifier: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        account_link_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___account_link_status_pb2___AccountLinkStatusEnum.AccountLinkStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___linked_account_type_pb2___LinkedAccountTypeEnum.LinkedAccountTypeValue
        ] = None,
        third_party_app_analytics: typing___Optional[
            type___ThirdPartyAppAnalyticsLinkIdentifier
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "account_link_id",
            b"account_link_id",
            "linked_account",
            b"linked_account",
            "third_party_app_analytics",
            b"third_party_app_analytics",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_link_id",
            b"account_link_id",
            "linked_account",
            b"linked_account",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "third_party_app_analytics",
            b"third_party_app_analytics",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["linked_account", b"linked_account"],
    ) -> typing_extensions___Literal["third_party_app_analytics"]: ...

type___AccountLink = AccountLink

class ThirdPartyAppAnalyticsLinkIdentifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    app_vendor: google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue = ...
    @property
    def app_analytics_provider_id(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        app_analytics_provider_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        app_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        app_vendor: typing___Optional[
            google___ads___googleads___v4___enums___mobile_app_vendor_pb2___MobileAppVendorEnum.MobileAppVendorValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "app_analytics_provider_id",
            b"app_analytics_provider_id",
            "app_id",
            b"app_id",
            "app_vendor",
            b"app_vendor",
        ],
    ) -> None: ...

type___ThirdPartyAppAnalyticsLinkIdentifier = ThirdPartyAppAnalyticsLinkIdentifier
