# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetTypeValue = typing___NewType("AssetTypeValue", builtin___int)
    type___AssetTypeValue = AssetTypeValue
    AssetType: _AssetType
    class _AssetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetTypeEnum.AssetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetTypeEnum.AssetTypeValue, 0)
        UNKNOWN = typing___cast(AssetTypeEnum.AssetTypeValue, 1)
        YOUTUBE_VIDEO = typing___cast(AssetTypeEnum.AssetTypeValue, 2)
        MEDIA_BUNDLE = typing___cast(AssetTypeEnum.AssetTypeValue, 3)
        IMAGE = typing___cast(AssetTypeEnum.AssetTypeValue, 4)
        TEXT = typing___cast(AssetTypeEnum.AssetTypeValue, 5)
    UNSPECIFIED = typing___cast(AssetTypeEnum.AssetTypeValue, 0)
    UNKNOWN = typing___cast(AssetTypeEnum.AssetTypeValue, 1)
    YOUTUBE_VIDEO = typing___cast(AssetTypeEnum.AssetTypeValue, 2)
    MEDIA_BUNDLE = typing___cast(AssetTypeEnum.AssetTypeValue, 3)
    IMAGE = typing___cast(AssetTypeEnum.AssetTypeValue, 4)
    TEXT = typing___cast(AssetTypeEnum.AssetTypeValue, 5)
    type___AssetType = AssetType
    def __init__(self,) -> None: ...

type___AssetTypeEnum = AssetTypeEnum
