# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdCustomizerErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdCustomizerErrorValue = typing___NewType("AdCustomizerErrorValue", builtin___int)
    type___AdCustomizerErrorValue = AdCustomizerErrorValue
    AdCustomizerError: _AdCustomizerError
    class _AdCustomizerError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdCustomizerErrorEnum.AdCustomizerErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 0)
        UNKNOWN = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 1)
        COUNTDOWN_INVALID_DATE_FORMAT = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 2
        )
        COUNTDOWN_DATE_IN_PAST = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 3
        )
        COUNTDOWN_INVALID_LOCALE = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 4
        )
        COUNTDOWN_INVALID_START_DAYS_BEFORE = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 5
        )
        UNKNOWN_USER_LIST = typing___cast(
            AdCustomizerErrorEnum.AdCustomizerErrorValue, 6
        )
    UNSPECIFIED = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 0)
    UNKNOWN = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 1)
    COUNTDOWN_INVALID_DATE_FORMAT = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 2
    )
    COUNTDOWN_DATE_IN_PAST = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 3
    )
    COUNTDOWN_INVALID_LOCALE = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 4
    )
    COUNTDOWN_INVALID_START_DAYS_BEFORE = typing___cast(
        AdCustomizerErrorEnum.AdCustomizerErrorValue, 5
    )
    UNKNOWN_USER_LIST = typing___cast(AdCustomizerErrorEnum.AdCustomizerErrorValue, 6)
    type___AdCustomizerError = AdCustomizerError
    def __init__(self,) -> None: ...

type___AdCustomizerErrorEnum = AdCustomizerErrorEnum
