from typing import Any

class ConversionAdjustmentUploadServiceStub:
    UploadConversionAdjustments: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ConversionAdjustmentUploadServiceServicer:
    def UploadConversionAdjustments(self, request: Any, context: Any) -> None: ...

def add_ConversionAdjustmentUploadServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
