from typing import Any

class HotelGroupViewServiceStub:
    GetHotelGroupView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class HotelGroupViewServiceServicer:
    def GetHotelGroupView(self, request: Any, context: Any) -> None: ...

def add_HotelGroupViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
