from typing import Any

class AdGroupExtensionSettingServiceStub:
    GetAdGroupExtensionSetting: Any = ...
    MutateAdGroupExtensionSettings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupExtensionSettingServiceServicer:
    def GetAdGroupExtensionSetting(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupExtensionSettings(self, request: Any, context: Any) -> None: ...

def add_AdGroupExtensionSettingServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
