# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignServingStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignServingStatusValue = typing___NewType(
        "CampaignServingStatusValue", builtin___int
    )
    type___CampaignServingStatusValue = CampaignServingStatusValue
    CampaignServingStatus: _CampaignServingStatus
    class _CampaignServingStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignServingStatusEnum.CampaignServingStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignServingStatusEnum.CampaignServingStatusValue, 0
        )
        UNKNOWN = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 1)
        SERVING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 2)
        NONE = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 3)
        ENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 4)
        PENDING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 5)
        SUSPENDED = typing___cast(
            CampaignServingStatusEnum.CampaignServingStatusValue, 6
        )
    UNSPECIFIED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 0)
    UNKNOWN = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 1)
    SERVING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 2)
    NONE = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 3)
    ENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 4)
    PENDING = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 5)
    SUSPENDED = typing___cast(CampaignServingStatusEnum.CampaignServingStatusValue, 6)
    type___CampaignServingStatus = CampaignServingStatus
    def __init__(self,) -> None: ...

type___CampaignServingStatusEnum = CampaignServingStatusEnum
