# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomPlaceholderFieldValue = typing___NewType(
        "CustomPlaceholderFieldValue", builtin___int
    )
    type___CustomPlaceholderFieldValue = CustomPlaceholderFieldValue
    CustomPlaceholderField: _CustomPlaceholderField
    class _CustomPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 1
        )
        ID = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 2)
        ID2 = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 3)
        ITEM_TITLE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 4
        )
        ITEM_SUBTITLE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 5
        )
        ITEM_DESCRIPTION = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 6
        )
        ITEM_ADDRESS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 7
        )
        PRICE = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 8)
        FORMATTED_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 9
        )
        SALE_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 10
        )
        FORMATTED_SALE_PRICE = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 11
        )
        IMAGE_URL = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 12
        )
        ITEM_CATEGORY = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 13
        )
        FINAL_URLS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 14
        )
        FINAL_MOBILE_URLS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 15
        )
        TRACKING_URL = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 16
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 17
        )
        ANDROID_APP_LINK = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 18
        )
        SIMILAR_IDS = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 19
        )
        IOS_APP_LINK = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 20
        )
        IOS_APP_STORE_ID = typing___cast(
            CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 21
        )
    UNSPECIFIED = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 1)
    ID = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 2)
    ID2 = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 3)
    ITEM_TITLE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 4
    )
    ITEM_SUBTITLE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 5
    )
    ITEM_DESCRIPTION = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 6
    )
    ITEM_ADDRESS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 7
    )
    PRICE = typing___cast(CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 8)
    FORMATTED_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 9
    )
    SALE_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 10
    )
    FORMATTED_SALE_PRICE = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 11
    )
    IMAGE_URL = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 12
    )
    ITEM_CATEGORY = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 13
    )
    FINAL_URLS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 14
    )
    FINAL_MOBILE_URLS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 15
    )
    TRACKING_URL = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 16
    )
    CONTEXTUAL_KEYWORDS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 17
    )
    ANDROID_APP_LINK = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 18
    )
    SIMILAR_IDS = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 19
    )
    IOS_APP_LINK = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 20
    )
    IOS_APP_STORE_ID = typing___cast(
        CustomPlaceholderFieldEnum.CustomPlaceholderFieldValue, 21
    )
    type___CustomPlaceholderField = CustomPlaceholderField
    def __init__(self,) -> None: ...

type___CustomPlaceholderFieldEnum = CustomPlaceholderFieldEnum
