# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperimentTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignExperimentTypeValue = typing___NewType(
        "CampaignExperimentTypeValue", builtin___int
    )
    type___CampaignExperimentTypeValue = CampaignExperimentTypeValue
    CampaignExperimentType: _CampaignExperimentType
    class _CampaignExperimentType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 1
        )
        BASE = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 2)
        DRAFT = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 3)
        EXPERIMENT = typing___cast(
            CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 4
        )
    UNSPECIFIED = typing___cast(
        CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 0
    )
    UNKNOWN = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 1)
    BASE = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 2)
    DRAFT = typing___cast(CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 3)
    EXPERIMENT = typing___cast(
        CampaignExperimentTypeEnum.CampaignExperimentTypeValue, 4
    )
    type___CampaignExperimentType = CampaignExperimentType
    def __init__(self,) -> None: ...

type___CampaignExperimentTypeEnum = CampaignExperimentTypeEnum
