# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SitelinkPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SitelinkPlaceholderFieldValue = typing___NewType(
        "SitelinkPlaceholderFieldValue", builtin___int
    )
    type___SitelinkPlaceholderFieldValue = SitelinkPlaceholderFieldValue
    SitelinkPlaceholderField: _SitelinkPlaceholderField
    class _SitelinkPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 1
        )
        TEXT = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 2
        )
        LINE_1 = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 3
        )
        LINE_2 = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 4
        )
        FINAL_URLS = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 5
        )
        FINAL_MOBILE_URLS = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 6
        )
        TRACKING_URL = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 7
        )
        FINAL_URL_SUFFIX = typing___cast(
            SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 8
        )
    UNSPECIFIED = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 1
    )
    TEXT = typing___cast(SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 2)
    LINE_1 = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 3
    )
    LINE_2 = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 4
    )
    FINAL_URLS = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 5
    )
    FINAL_MOBILE_URLS = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 6
    )
    TRACKING_URL = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 7
    )
    FINAL_URL_SUFFIX = typing___cast(
        SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldValue, 8
    )
    type___SitelinkPlaceholderField = SitelinkPlaceholderField
    def __init__(self,) -> None: ...

type___SitelinkPlaceholderFieldEnum = SitelinkPlaceholderFieldEnum
