# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AffiliateLocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AffiliateLocationPlaceholderFieldValue = typing___NewType(
        "AffiliateLocationPlaceholderFieldValue", builtin___int
    )
    type___AffiliateLocationPlaceholderFieldValue = (
        AffiliateLocationPlaceholderFieldValue
    )
    AffiliateLocationPlaceholderField: _AffiliateLocationPlaceholderField
    class _AffiliateLocationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            0,
        )
        UNKNOWN = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            1,
        )
        BUSINESS_NAME = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            2,
        )
        ADDRESS_LINE_1 = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            3,
        )
        ADDRESS_LINE_2 = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            4,
        )
        CITY = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            5,
        )
        PROVINCE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            6,
        )
        POSTAL_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            7,
        )
        COUNTRY_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            8,
        )
        PHONE_NUMBER = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            9,
        )
        LANGUAGE_CODE = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            10,
        )
        CHAIN_ID = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            11,
        )
        CHAIN_NAME = typing___cast(
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue,
            12,
        )
    UNSPECIFIED = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 1
    )
    BUSINESS_NAME = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 2
    )
    ADDRESS_LINE_1 = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 3
    )
    ADDRESS_LINE_2 = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 4
    )
    CITY = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 5
    )
    PROVINCE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 6
    )
    POSTAL_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 7
    )
    COUNTRY_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 8
    )
    PHONE_NUMBER = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 9
    )
    LANGUAGE_CODE = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 10
    )
    CHAIN_ID = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 11
    )
    CHAIN_NAME = typing___cast(
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldValue, 12
    )
    type___AffiliateLocationPlaceholderField = AffiliateLocationPlaceholderField
    def __init__(self,) -> None: ...

type___AffiliateLocationPlaceholderFieldEnum = AffiliateLocationPlaceholderFieldEnum
