# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class VanityPharmaTextEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    VanityPharmaTextValue = typing___NewType("VanityPharmaTextValue", builtin___int)
    type___VanityPharmaTextValue = VanityPharmaTextValue
    VanityPharmaText: _VanityPharmaText
    class _VanityPharmaText(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            VanityPharmaTextEnum.VanityPharmaTextValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 0)
        UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 2
        )
        PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 3
        )
        PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 4
        )
        PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 5
        )
        MEDICAL_DEVICE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 6
        )
        MEDICAL_DEVICE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 7
        )
        PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 8
        )
        PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 9
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 10
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 11
        )
        PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 12
        )
        PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 13
        )
    UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 0)
    UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 2
    )
    PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 3
    )
    PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 4
    )
    PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 5
    )
    MEDICAL_DEVICE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 6
    )
    MEDICAL_DEVICE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 7
    )
    PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 8
    )
    PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 9
    )
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 10
    )
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 11
    )
    PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 12
    )
    PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 13
    )
    type___VanityPharmaText = VanityPharmaText
    def __init__(self,) -> None: ...

type___VanityPharmaTextEnum = VanityPharmaTextEnum
