from typing import Any

class ReachPlanServiceStub:
    ListPlannableLocations: Any = ...
    ListPlannableProducts: Any = ...
    GenerateProductMixIdeas: Any = ...
    GenerateReachForecast: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ReachPlanServiceServicer:
    def ListPlannableLocations(self, request: Any, context: Any) -> None: ...
    def ListPlannableProducts(self, request: Any, context: Any) -> None: ...
    def GenerateProductMixIdeas(self, request: Any, context: Any) -> None: ...
    def GenerateReachForecast(self, request: Any, context: Any) -> None: ...

def add_ReachPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
