# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTargetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemTargetErrorValue = typing___NewType(
        "FeedItemTargetErrorValue", builtin___int
    )
    type___FeedItemTargetErrorValue = FeedItemTargetErrorValue
    FeedItemTargetError: _FeedItemTargetError
    class _FeedItemTargetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 0)
        UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 1)
        MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 2
        )
        FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 3
        )
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 4
        )
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 5
        )
        TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 6
        )
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 7
        )
        DUPLICATE_AD_SCHEDULE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 8
        )
        DUPLICATE_KEYWORD = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 9
        )
    UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 0)
    UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 1)
    MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 2
    )
    FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 3
    )
    FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 4
    )
    TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 5
    )
    TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 6
    )
    CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 7
    )
    DUPLICATE_AD_SCHEDULE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 8
    )
    DUPLICATE_KEYWORD = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 9
    )
    type___FeedItemTargetError = FeedItemTargetError
    def __init__(self,) -> None: ...

type___FeedItemTargetErrorEnum = FeedItemTargetErrorEnum
