# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemErrorValue = typing___NewType("FeedItemErrorValue", builtin___int)
    type___FeedItemErrorValue = FeedItemErrorValue
    FeedItemError: _FeedItemError
    class _FeedItemError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemErrorEnum.FeedItemErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 0)
        UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 1)
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 2
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 3
        )
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 4
        )
        KEY_ATTRIBUTES_NOT_FOUND = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 5
        )
        INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 6)
        MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 7)
        KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 8
        )
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 9
        )
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 10
        )
    UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 0)
    UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 1)
    CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 2
    )
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 3
    )
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 4
    )
    KEY_ATTRIBUTES_NOT_FOUND = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 5)
    INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 6)
    MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 7)
    KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 8)
    CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 9
    )
    SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 10
    )
    type___FeedItemError = FeedItemError
    def __init__(self,) -> None: ...

type___FeedItemErrorEnum = FeedItemErrorEnum
