from typing import Any

class DomainCategoryServiceStub:
    GetDomainCategory: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DomainCategoryServiceServicer:
    def GetDomainCategory(self, request: Any, context: Any) -> None: ...

def add_DomainCategoryServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
