# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListingGroupTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ListingGroupTypeValue = typing___NewType("ListingGroupTypeValue", builtin___int)
    type___ListingGroupTypeValue = ListingGroupTypeValue
    ListingGroupType: _ListingGroupType
    class _ListingGroupType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ListingGroupTypeEnum.ListingGroupTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 0)
        UNKNOWN = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 1)
        SUBDIVISION = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 2)
        UNIT = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 3)
    UNSPECIFIED = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 0)
    UNKNOWN = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 1)
    SUBDIVISION = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 2)
    UNIT = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 3)
    type___ListingGroupType = ListingGroupType
    def __init__(self,) -> None: ...

type___ListingGroupTypeEnum = ListingGroupTypeEnum
