# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanAdLengthEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanAdLengthValue = typing___NewType("ReachPlanAdLengthValue", builtin___int)
    type___ReachPlanAdLengthValue = ReachPlanAdLengthValue
    ReachPlanAdLength: _ReachPlanAdLength
    class _ReachPlanAdLength(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 0)
        UNKNOWN = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 1)
        SIX_SECONDS = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 2)
        FIFTEEN_OR_TWENTY_SECONDS = typing___cast(
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 3
        )
        TWENTY_SECONDS_OR_MORE = typing___cast(
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 4
        )
    UNSPECIFIED = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 0)
    UNKNOWN = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 1)
    SIX_SECONDS = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 2)
    FIFTEEN_OR_TWENTY_SECONDS = typing___cast(
        ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 3
    )
    TWENTY_SECONDS_OR_MORE = typing___cast(
        ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 4
    )
    type___ReachPlanAdLength = ReachPlanAdLength
    def __init__(self,) -> None: ...

type___ReachPlanAdLengthEnum = ReachPlanAdLengthEnum
