# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue = typing___NewType(
        "PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue", builtin___int
    )
    type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue = (
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue
    )
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorType: _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    class _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            1,
        )
        HOSTNAME_NOT_FOUND = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            2,
        )
        GOOGLE_CRAWLER_DNS_ISSUE = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            3,
        )
    UNSPECIFIED = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        1,
    )
    HOSTNAME_NOT_FOUND = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        2,
    )
    GOOGLE_CRAWLER_DNS_ISSUE = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        3,
    )
    type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = (
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    )
    def __init__(self,) -> None: ...

type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum = (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
)
