from typing import Any

class TopicConstantServiceStub:
    GetTopicConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class TopicConstantServiceServicer:
    def GetTopicConstant(self, request: Any, context: Any) -> None: ...

def add_TopicConstantServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
