# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionErrorValue = typing___NewType("CriterionErrorValue", builtin___int)
    type___CriterionErrorValue = CriterionErrorValue
    CriterionError: _CriterionError
    class _CriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionErrorEnum.CriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 0)
        UNKNOWN = typing___cast(CriterionErrorEnum.CriterionErrorValue, 1)
        CONCRETE_TYPE_REQUIRED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 2
        )
        INVALID_EXCLUDED_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 3
        )
        INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 4)
        KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 5)
        KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 6
        )
        KEYWORD_HAS_INVALID_CHARS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 7
        )
        INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionErrorValue, 8)
        INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 9)
        INVALID_USER_INTEREST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 10
        )
        INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 11
        )
        PLACEMENT_URL_IS_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 12
        )
        PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 13
        )
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 14
        )
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 15
        )
        INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 16)
        INVALID_YOUTUBE_CHANNEL_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 17
        )
        INVALID_YOUTUBE_VIDEO_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 18
        )
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 19
        )
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 20
        )
        YOUTUBE_URL_UNSUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 21
        )
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 22
        )
        CANNOT_ADD_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 23
        )
        CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 26
        )
        CANNOT_ADD_CLOSED_USER_LIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 27
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 28
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 29
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 30
        )
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 31
        )
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 32
        )
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 33
        )
        INVALID_CUSTOM_AFFINITY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 96
        )
        INVALID_CUSTOM_INTENT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 97
        )
        INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 34)
        INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 35)
        INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionErrorValue, 36)
        INVALID_MOBILE_APP_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 37
        )
        INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 38)
        CANNOT_TARGET_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 39
        )
        CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 40
        )
        CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 41
        )
        INVALID_PROXIMITY_RADIUS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 42
        )
        INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 43
        )
        INVALID_STREETADDRESS_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 44
        )
        INVALID_CITYNAME_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 45
        )
        INVALID_REGIONCODE_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 46
        )
        INVALID_REGIONNAME_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 47
        )
        INVALID_POSTALCODE_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 48
        )
        INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 49)
        INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 50)
        INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 51)
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 52
        )
        INVALID_PROXIMITY_ADDRESS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 53
        )
        INVALID_USER_DOMAIN_NAME = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 54
        )
        CRITERION_PARAMETER_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 55
        )
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 56
        )
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 57
        )
        AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 58
        )
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 59
        )
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 60
        )
        CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 61
        )
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 62
        )
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 63
        )
        BID_MODIFIER_ALREADY_EXISTS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 64
        )
        FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 65)
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 66
        )
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 67
        )
        CANNOT_EXCLUDE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 68
        )
        CANNOT_REMOVE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 69
        )
        INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 76
        )
        MISSING_SHOPPING_SETTING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 77
        )
        INVALID_MATCHING_FUNCTION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 78
        )
        LOCATION_FILTER_NOT_ALLOWED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 79
        )
        INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 98
        )
        LOCATION_FILTER_INVALID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 80
        )
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 81
        )
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 82
        )
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 83
        )
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 84
        )
        INVALID_WEBPAGE_CONDITION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 85
        )
        INVALID_WEBPAGE_CONDITION_URL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 86
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 87
        )
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 88
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 89
        )
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 90
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 91
        )
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 92
        )
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 93
        )
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 94
        )
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 95
        )
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 99
        )
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 100
        )
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 101
        )
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 102
        )
        DUPLICATE_LISTING_DIMENSION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 103
        )
        DUPLICATE_LISTING_DIMENSION_VALUE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 104
        )
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 105
        )
        INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 106
        )
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 107
        )
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 108
        )
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 109
        )
        LISTING_GROUP_ALREADY_EXISTS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 110
        )
        LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 111
        )
        LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 112
        )
        INVALID_LISTING_GROUP_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 113
        )
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 114
        )
        LISTING_SCOPE_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 115
        )
        LISTING_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 116
        )
        LISTING_GROUP_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 117
        )
        LISTING_GROUP_TREE_TOO_DEEP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 118
        )
        INVALID_LISTING_DIMENSION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 119
        )
        INVALID_LISTING_DIMENSION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 120
        )
    UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 0)
    UNKNOWN = typing___cast(CriterionErrorEnum.CriterionErrorValue, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 2)
    INVALID_EXCLUDED_CATEGORY = typing___cast(CriterionErrorEnum.CriterionErrorValue, 3)
    INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 4)
    KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 5)
    KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 6
    )
    KEYWORD_HAS_INVALID_CHARS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 7)
    INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionErrorValue, 8)
    INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 9)
    INVALID_USER_INTEREST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 10)
    INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 11
    )
    PLACEMENT_URL_IS_TOO_LONG = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 12
    )
    PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 13
    )
    PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 14
    )
    PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 15
    )
    INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 16)
    INVALID_YOUTUBE_CHANNEL_ID = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 17
    )
    INVALID_YOUTUBE_VIDEO_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 18)
    YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 19
    )
    YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 20
    )
    YOUTUBE_URL_UNSUPPORTED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 21)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 22
    )
    CANNOT_ADD_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 23)
    CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 26
    )
    CANNOT_ADD_CLOSED_USER_LIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 27
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 28
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 29
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 30
    )
    CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 31
    )
    CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 32
    )
    CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 33
    )
    INVALID_CUSTOM_AFFINITY = typing___cast(CriterionErrorEnum.CriterionErrorValue, 96)
    INVALID_CUSTOM_INTENT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 97)
    INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 34)
    INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 35)
    INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionErrorValue, 36)
    INVALID_MOBILE_APP_CATEGORY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 37
    )
    INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 38)
    CANNOT_TARGET_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 39)
    CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 40
    )
    CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 41
    )
    INVALID_PROXIMITY_RADIUS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 42)
    INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 43
    )
    INVALID_STREETADDRESS_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 44
    )
    INVALID_CITYNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 45)
    INVALID_REGIONCODE_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 46
    )
    INVALID_REGIONNAME_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 47
    )
    INVALID_POSTALCODE_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 48
    )
    INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 49)
    INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 50)
    INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 51)
    PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 52
    )
    INVALID_PROXIMITY_ADDRESS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 53
    )
    INVALID_USER_DOMAIN_NAME = typing___cast(CriterionErrorEnum.CriterionErrorValue, 54)
    CRITERION_PARAMETER_TOO_LONG = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 55
    )
    AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 56
    )
    AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 57
    )
    AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 58
    )
    AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 59
    )
    AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 60
    )
    CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 61
    )
    CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 62
    )
    CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 63
    )
    BID_MODIFIER_ALREADY_EXISTS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 64
    )
    FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 65)
    ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 66
    )
    CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 67
    )
    CANNOT_EXCLUDE_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 68)
    CANNOT_REMOVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 69)
    INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 76
    )
    MISSING_SHOPPING_SETTING = typing___cast(CriterionErrorEnum.CriterionErrorValue, 77)
    INVALID_MATCHING_FUNCTION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 78
    )
    LOCATION_FILTER_NOT_ALLOWED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 79
    )
    INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 98
    )
    LOCATION_FILTER_INVALID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 80)
    CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 81
    )
    HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 82
    )
    HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 83
    )
    FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 84
    )
    INVALID_WEBPAGE_CONDITION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 85
    )
    INVALID_WEBPAGE_CONDITION_URL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 86
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 87
    )
    WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 88
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 89
    )
    WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 90
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 91
    )
    WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 92
    )
    WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 93
    )
    WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 94
    )
    WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 95
    )
    CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 99
    )
    LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 100
    )
    LISTING_SCOPE_TOO_MANY_IN_OPERATORS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 101
    )
    LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 102
    )
    DUPLICATE_LISTING_DIMENSION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 103
    )
    DUPLICATE_LISTING_DIMENSION_VALUE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 104
    )
    CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 105
    )
    INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 106
    )
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 107
    )
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 108
    )
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 109
    )
    LISTING_GROUP_ALREADY_EXISTS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 110
    )
    LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 111
    )
    LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 112
    )
    INVALID_LISTING_GROUP_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 113
    )
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 114
    )
    LISTING_SCOPE_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 115)
    LISTING_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 116
    )
    LISTING_GROUP_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 117)
    LISTING_GROUP_TREE_TOO_DEEP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 118
    )
    INVALID_LISTING_DIMENSION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 119
    )
    INVALID_LISTING_DIMENSION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 120
    )
    type___CriterionError = CriterionError
    def __init__(self,) -> None: ...

type___CriterionErrorEnum = CriterionErrorEnum
