# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.frequency_cap_event_type_pb2 import (
    FrequencyCapEventTypeEnum as google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.frequency_cap_level_pb2 import (
    FrequencyCapLevelEnum as google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum,
)
from google.ads.google_ads.v5.proto.enums.frequency_cap_time_unit_pb2 import (
    FrequencyCapTimeUnitEnum as google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FrequencyCapEntry(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cap: builtin___int = ...
    @property
    def key(self) -> type___FrequencyCapKey: ...
    def __init__(
        self,
        *,
        key: typing___Optional[type___FrequencyCapKey] = None,
        cap: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cap", b"_cap", "cap", b"cap", "key", b"key"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cap", b"_cap", "cap", b"cap", "key", b"key"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cap", b"_cap"]
    ) -> typing_extensions___Literal["cap"]: ...

type___FrequencyCapEntry = FrequencyCapEntry

class FrequencyCapKey(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level: google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevelValue = ...
    event_type: google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventTypeValue = ...
    time_unit: google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnitValue = ...
    time_length: builtin___int = ...
    def __init__(
        self,
        *,
        level: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevelValue
        ] = None,
        event_type: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventTypeValue
        ] = None,
        time_unit: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnitValue
        ] = None,
        time_length: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_time_length", b"_time_length", "time_length", b"time_length"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_time_length",
            b"_time_length",
            "event_type",
            b"event_type",
            "level",
            b"level",
            "time_length",
            b"time_length",
            "time_unit",
            b"time_unit",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_time_length", b"_time_length"]
    ) -> typing_extensions___Literal["time_length"]: ...

type___FrequencyCapKey = FrequencyCapKey
