# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.keyword_plan_competition_level_pb2 import (
    KeywordPlanCompetitionLevelEnum as google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum,
)
from google.ads.google_ads.v6.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    avg_monthly_searches: builtin___int = ...
    competition: google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue = ...
    competition_index: builtin___int = ...
    low_top_of_page_bid_micros: builtin___int = ...
    high_top_of_page_bid_micros: builtin___int = ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MonthlySearchVolume
    ]: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: typing___Optional[builtin___int] = None,
        monthly_search_volumes: typing___Optional[
            typing___Iterable[type___MonthlySearchVolume]
        ] = None,
        competition: typing___Optional[
            google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue
        ] = None,
        competition_index: typing___Optional[builtin___int] = None,
        low_top_of_page_bid_micros: typing___Optional[builtin___int] = None,
        high_top_of_page_bid_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_avg_monthly_searches", b"_avg_monthly_searches"
        ],
    ) -> typing_extensions___Literal["avg_monthly_searches"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_competition_index", b"_competition_index"
        ],
    ) -> typing_extensions___Literal["competition_index"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_high_top_of_page_bid_micros", b"_high_top_of_page_bid_micros"
        ],
    ) -> typing_extensions___Literal["high_top_of_page_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_low_top_of_page_bid_micros", b"_low_top_of_page_bid_micros"
        ],
    ) -> typing_extensions___Literal["low_top_of_page_bid_micros"]: ...

type___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    year: builtin___int = ...
    month: google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue = ...
    monthly_searches: builtin___int = ...
    def __init__(
        self,
        *,
        year: typing___Optional[builtin___int] = None,
        month: typing___Optional[
            google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue
        ] = None,
        monthly_searches: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "month",
            b"month",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_monthly_searches", b"_monthly_searches"
        ],
    ) -> typing_extensions___Literal["monthly_searches"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_year", b"_year"]
    ) -> typing_extensions___Literal["year"]: ...

type___MonthlySearchVolume = MonthlySearchVolume
