# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanNetworkEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanNetworkValue = typing___NewType("ReachPlanNetworkValue", builtin___int)
    type___ReachPlanNetworkValue = ReachPlanNetworkValue
    ReachPlanNetwork: _ReachPlanNetwork
    class _ReachPlanNetwork(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanNetworkEnum.ReachPlanNetworkValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 0)
        UNKNOWN = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 1)
        YOUTUBE = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 2)
        GOOGLE_VIDEO_PARTNERS = typing___cast(
            ReachPlanNetworkEnum.ReachPlanNetworkValue, 3
        )
        YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS = typing___cast(
            ReachPlanNetworkEnum.ReachPlanNetworkValue, 4
        )
    UNSPECIFIED = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 0)
    UNKNOWN = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 1)
    YOUTUBE = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 2)
    GOOGLE_VIDEO_PARTNERS = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 3)
    YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS = typing___cast(
        ReachPlanNetworkEnum.ReachPlanNetworkValue, 4
    )
    type___ReachPlanNetwork = ReachPlanNetwork
    def __init__(self,) -> None: ...

type___ReachPlanNetworkEnum = ReachPlanNetworkEnum
