from typing import Any

class SearchTermViewServiceStub:
    GetSearchTermView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SearchTermViewServiceServicer:
    def GetSearchTermView(self, request: Any, context: Any) -> None: ...

def add_SearchTermViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
