# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudgetProposalStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountBudgetProposalStatusValue = typing___NewType(
        "AccountBudgetProposalStatusValue", builtin___int
    )
    type___AccountBudgetProposalStatusValue = AccountBudgetProposalStatusValue
    AccountBudgetProposalStatus: _AccountBudgetProposalStatus
    class _AccountBudgetProposalStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 0
        )
        UNKNOWN = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 1
        )
        PENDING = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 2
        )
        APPROVED_HELD = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 3
        )
        APPROVED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 4
        )
        CANCELLED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 5
        )
        REJECTED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 6
        )
    UNSPECIFIED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 0
    )
    UNKNOWN = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 1
    )
    PENDING = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 2
    )
    APPROVED_HELD = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 3
    )
    APPROVED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 4
    )
    CANCELLED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 5
    )
    REJECTED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 6
    )
    type___AccountBudgetProposalStatus = AccountBudgetProposalStatus
    def __init__(self,) -> None: ...

type___AccountBudgetProposalStatusEnum = AccountBudgetProposalStatusEnum
