# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionTypeValue = typing___NewType(
        "ConversionActionTypeValue", builtin___int
    )
    type___ConversionActionTypeValue = ConversionActionTypeValue
    ConversionActionType: _ConversionActionType
    class _ConversionActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionTypeEnum.ConversionActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 0
        )
        UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
        AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
        CLICK_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 3
        )
        GOOGLE_PLAY_DOWNLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 4
        )
        GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 5
        )
        UPLOAD_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 6
        )
        UPLOAD_CLICKS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 7
        )
        WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
        WEBSITE_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 9
        )
    UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 0)
    UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
    AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
    CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 3)
    GOOGLE_PLAY_DOWNLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 4
    )
    GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 5
    )
    UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 6)
    UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 7)
    WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
    WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 9)
    type___ConversionActionType = ConversionActionType
    def __init__(self,) -> None: ...

type___ConversionActionTypeEnum = ConversionActionTypeEnum
