# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LocationPlaceholderFieldValue = typing___NewType(
        "LocationPlaceholderFieldValue", builtin___int
    )
    type___LocationPlaceholderFieldValue = LocationPlaceholderFieldValue
    LocationPlaceholderField: _LocationPlaceholderField
    class _LocationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 1
        )
        BUSINESS_NAME = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 2
        )
        ADDRESS_LINE_1 = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 3
        )
        ADDRESS_LINE_2 = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 4
        )
        CITY = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 5
        )
        PROVINCE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 6
        )
        POSTAL_CODE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 7
        )
        COUNTRY_CODE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 8
        )
        PHONE_NUMBER = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 9
        )
    UNSPECIFIED = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 1
    )
    BUSINESS_NAME = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 2
    )
    ADDRESS_LINE_1 = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 3
    )
    ADDRESS_LINE_2 = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 4
    )
    CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 5)
    PROVINCE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 6
    )
    POSTAL_CODE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 7
    )
    COUNTRY_CODE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 8
    )
    PHONE_NUMBER = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 9
    )
    type___LocationPlaceholderField = LocationPlaceholderField
    def __init__(self,) -> None: ...

type___LocationPlaceholderFieldEnum = LocationPlaceholderFieldEnum
