from typing import Any

class ProductBiddingCategoryConstantServiceStub:
    GetProductBiddingCategoryConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ProductBiddingCategoryConstantServiceServicer:
    def GetProductBiddingCategoryConstant(self, request: Any, context: Any) -> None: ...

def add_ProductBiddingCategoryConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
