from typing import Any

class RecommendationServiceStub:
    GetRecommendation: Any = ...
    ApplyRecommendation: Any = ...
    DismissRecommendation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class RecommendationServiceServicer:
    def GetRecommendation(self, request: Any, context: Any) -> None: ...
    def ApplyRecommendation(self, request: Any, context: Any) -> None: ...
    def DismissRecommendation(self, request: Any, context: Any) -> None: ...

def add_RecommendationServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
