# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerClientLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerClientLinkErrorValue = typing___NewType(
        "CustomerClientLinkErrorValue", builtin___int
    )
    type___CustomerClientLinkErrorValue = CustomerClientLinkErrorValue
    CustomerClientLinkError: _CustomerClientLinkError
    class _CustomerClientLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 1
        )
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 2
        )
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 3
        )
        CYCLIC_LINK_NOT_ALLOWED = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 4
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 5
        )
        CLIENT_HAS_TOO_MANY_INVITATIONS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 6
        )
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 7
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 8
        )
        CLIENT_HAS_TOO_MANY_MANAGERS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 9
        )
    UNSPECIFIED = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 0
    )
    UNKNOWN = typing___cast(CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 1)
    CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 2
    )
    CLIENT_ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 3
    )
    CYCLIC_LINK_NOT_ALLOWED = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 4
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 5
    )
    CLIENT_HAS_TOO_MANY_INVITATIONS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 6
    )
    CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 7
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 8
    )
    CLIENT_HAS_TOO_MANY_MANAGERS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 9
    )
    type___CustomerClientLinkError = CustomerClientLinkError
    def __init__(self,) -> None: ...

type___CustomerClientLinkErrorEnum = CustomerClientLinkErrorEnum
