# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetLinkErrorValue = typing___NewType("AssetLinkErrorValue", builtin___int)
    type___AssetLinkErrorValue = AssetLinkErrorValue
    AssetLinkError: _AssetLinkError
    class _AssetLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetLinkErrorEnum.AssetLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 0)
        UNKNOWN = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 1)
        PINNING_UNSUPPORTED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 2)
        UNSUPPORTED_FIELD_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 3
        )
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 4
        )
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 5
        )
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 6
        )
    UNSPECIFIED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 0)
    UNKNOWN = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 1)
    PINNING_UNSUPPORTED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 2)
    UNSUPPORTED_FIELD_TYPE = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 3)
    FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 4
    )
    FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 5
    )
    INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 6
    )
    type___AssetLinkError = AssetLinkError
    def __init__(self,) -> None: ...

type___AssetLinkErrorEnum = AssetLinkErrorEnum
