from typing import Any

class ParentalStatusViewServiceStub:
    GetParentalStatusView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ParentalStatusViewServiceServicer:
    def GetParentalStatusView(self, request: Any, context: Any) -> None: ...

def add_ParentalStatusViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
