# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class YoutubeVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    youtube_video_id: typing___Text = ...
    def __init__(
        self, *, youtube_video_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions___Literal["youtube_video_id"]: ...

type___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    def __init__(self, *, data: typing___Optional[builtin___bytes] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...

type___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    file_size: builtin___int = ...
    mime_type: google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    @property
    def full_size(self) -> type___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing___Optional[builtin___bytes] = None,
        file_size: typing___Optional[builtin___int] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        full_size: typing___Optional[type___ImageDimension] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_file_size", b"_file_size"]
    ) -> typing_extensions___Literal["file_size"]: ...

type___ImageAsset = ImageAsset

class ImageDimension(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    height_pixels: builtin___int = ...
    width_pixels: builtin___int = ...
    url: typing___Text = ...
    def __init__(
        self,
        *,
        height_pixels: typing___Optional[builtin___int] = None,
        width_pixels: typing___Optional[builtin___int] = None,
        url: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions___Literal["height_pixels"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_url", b"_url"]
    ) -> typing_extensions___Literal["url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_width_pixels", b"_width_pixels"],
    ) -> typing_extensions___Literal["width_pixels"]: ...

type___ImageDimension = ImageDimension

class TextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    def __init__(self, *, text: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___TextAsset = TextAsset

class BookOnGoogleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___BookOnGoogleAsset = BookOnGoogleAsset
