from typing import Any

class DistanceViewServiceStub:
    GetDistanceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DistanceViewServiceServicer:
    def GetDistanceView(self, request: Any, context: Any) -> None: ...

def add_DistanceViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
