# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v5___common___criteria_pb2___KeywordInfo,
)
from google.ads.google_ads.v5.proto.enums.ad_network_type_pb2 import (
    AdNetworkTypeEnum as google___ads___googleads___v5___enums___ad_network_type_pb2___AdNetworkTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.budget_campaign_association_status_pb2 import (
    BudgetCampaignAssociationStatusEnum as google___ads___googleads___v5___enums___budget_campaign_association_status_pb2___BudgetCampaignAssociationStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.click_type_pb2 import (
    ClickTypeEnum as google___ads___googleads___v5___enums___click_type_pb2___ClickTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2 import (
    ConversionActionCategoryEnum as google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_attribution_event_type_pb2 import (
    ConversionAttributionEventTypeEnum as google___ads___googleads___v5___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_lag_bucket_pb2 import (
    ConversionLagBucketEnum as google___ads___googleads___v5___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum,
)
from google.ads.google_ads.v5.proto.enums.conversion_or_adjustment_lag_bucket_pb2 import (
    ConversionOrAdjustmentLagBucketEnum as google___ads___googleads___v5___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum,
)
from google.ads.google_ads.v5.proto.enums.day_of_week_pb2 import (
    DayOfWeekEnum as google___ads___googleads___v5___enums___day_of_week_pb2___DayOfWeekEnum,
)
from google.ads.google_ads.v5.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v5___enums___device_pb2___DeviceEnum,
)
from google.ads.google_ads.v5.proto.enums.external_conversion_source_pb2 import (
    ExternalConversionSourceEnum as google___ads___googleads___v5___enums___external_conversion_source_pb2___ExternalConversionSourceEnum,
)
from google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2 import (
    HotelDateSelectionTypeEnum as google___ads___googleads___v5___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.hotel_price_bucket_pb2 import (
    HotelPriceBucketEnum as google___ads___googleads___v5___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum,
)
from google.ads.google_ads.v5.proto.enums.hotel_rate_type_pb2 import (
    HotelRateTypeEnum as google___ads___googleads___v5___enums___hotel_rate_type_pb2___HotelRateTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum,
)
from google.ads.google_ads.v5.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2 import (
    ProductChannelExclusivityEnum as google___ads___googleads___v5___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum,
)
from google.ads.google_ads.v5.proto.enums.product_channel_pb2 import (
    ProductChannelEnum as google___ads___googleads___v5___enums___product_channel_pb2___ProductChannelEnum,
)
from google.ads.google_ads.v5.proto.enums.product_condition_pb2 import (
    ProductConditionEnum as google___ads___googleads___v5___enums___product_condition_pb2___ProductConditionEnum,
)
from google.ads.google_ads.v5.proto.enums.search_engine_results_page_type_pb2 import (
    SearchEngineResultsPageTypeEnum as google___ads___googleads___v5___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.search_term_match_type_pb2 import (
    SearchTermMatchTypeEnum as google___ads___googleads___v5___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.slot_pb2 import (
    SlotEnum as google___ads___googleads___v5___enums___slot_pb2___SlotEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Segments(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ad_network_type: google___ads___googleads___v5___enums___ad_network_type_pb2___AdNetworkTypeEnum.AdNetworkTypeValue = ...
    click_type: google___ads___googleads___v5___enums___click_type_pb2___ClickTypeEnum.ClickTypeValue = ...
    conversion_action: typing___Text = ...
    conversion_action_category: google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue = ...
    conversion_action_name: typing___Text = ...
    conversion_adjustment: builtin___bool = ...
    conversion_attribution_event_type: google___ads___googleads___v5___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum.ConversionAttributionEventTypeValue = ...
    conversion_lag_bucket: google___ads___googleads___v5___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum.ConversionLagBucketValue = ...
    conversion_or_adjustment_lag_bucket: google___ads___googleads___v5___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue = ...
    date: typing___Text = ...
    day_of_week: google___ads___googleads___v5___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue = ...
    device: google___ads___googleads___v5___enums___device_pb2___DeviceEnum.DeviceValue = ...
    external_conversion_source: google___ads___googleads___v5___enums___external_conversion_source_pb2___ExternalConversionSourceEnum.ExternalConversionSourceValue = ...
    geo_target_airport: typing___Text = ...
    geo_target_canton: typing___Text = ...
    geo_target_city: typing___Text = ...
    geo_target_country: typing___Text = ...
    geo_target_county: typing___Text = ...
    geo_target_district: typing___Text = ...
    geo_target_metro: typing___Text = ...
    geo_target_most_specific_location: typing___Text = ...
    geo_target_postal_code: typing___Text = ...
    geo_target_province: typing___Text = ...
    geo_target_region: typing___Text = ...
    geo_target_state: typing___Text = ...
    hotel_booking_window_days: builtin___int = ...
    hotel_center_id: builtin___int = ...
    hotel_check_in_date: typing___Text = ...
    hotel_check_in_day_of_week: google___ads___googleads___v5___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue = ...
    hotel_city: typing___Text = ...
    hotel_class: builtin___int = ...
    hotel_country: typing___Text = ...
    hotel_date_selection_type: google___ads___googleads___v5___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue = ...
    hotel_length_of_stay: builtin___int = ...
    hotel_rate_rule_id: typing___Text = ...
    hotel_rate_type: google___ads___googleads___v5___enums___hotel_rate_type_pb2___HotelRateTypeEnum.HotelRateTypeValue = ...
    hotel_price_bucket: google___ads___googleads___v5___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum.HotelPriceBucketValue = ...
    hotel_state: typing___Text = ...
    hour: builtin___int = ...
    interaction_on_this_extension: builtin___bool = ...
    month: typing___Text = ...
    month_of_year: google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue = ...
    partner_hotel_id: typing___Text = ...
    placeholder_type: google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue = ...
    product_aggregator_id: builtin___int = ...
    product_bidding_category_level1: typing___Text = ...
    product_bidding_category_level2: typing___Text = ...
    product_bidding_category_level3: typing___Text = ...
    product_bidding_category_level4: typing___Text = ...
    product_bidding_category_level5: typing___Text = ...
    product_brand: typing___Text = ...
    product_channel: google___ads___googleads___v5___enums___product_channel_pb2___ProductChannelEnum.ProductChannelValue = ...
    product_channel_exclusivity: google___ads___googleads___v5___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivityValue = ...
    product_condition: google___ads___googleads___v5___enums___product_condition_pb2___ProductConditionEnum.ProductConditionValue = ...
    product_country: typing___Text = ...
    product_custom_attribute0: typing___Text = ...
    product_custom_attribute1: typing___Text = ...
    product_custom_attribute2: typing___Text = ...
    product_custom_attribute3: typing___Text = ...
    product_custom_attribute4: typing___Text = ...
    product_item_id: typing___Text = ...
    product_language: typing___Text = ...
    product_merchant_id: builtin___int = ...
    product_store_id: typing___Text = ...
    product_title: typing___Text = ...
    product_type_l1: typing___Text = ...
    product_type_l2: typing___Text = ...
    product_type_l3: typing___Text = ...
    product_type_l4: typing___Text = ...
    product_type_l5: typing___Text = ...
    quarter: typing___Text = ...
    search_engine_results_page_type: google___ads___googleads___v5___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum.SearchEngineResultsPageTypeValue = ...
    search_term_match_type: google___ads___googleads___v5___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum.SearchTermMatchTypeValue = ...
    slot: google___ads___googleads___v5___enums___slot_pb2___SlotEnum.SlotValue = ...
    webpage: typing___Text = ...
    week: typing___Text = ...
    year: builtin___int = ...
    @property
    def budget_campaign_association_status(
        self,
    ) -> type___BudgetCampaignAssociationStatus: ...
    @property
    def keyword(self) -> type___Keyword: ...
    def __init__(
        self,
        *,
        ad_network_type: typing___Optional[
            google___ads___googleads___v5___enums___ad_network_type_pb2___AdNetworkTypeEnum.AdNetworkTypeValue
        ] = None,
        budget_campaign_association_status: typing___Optional[
            type___BudgetCampaignAssociationStatus
        ] = None,
        click_type: typing___Optional[
            google___ads___googleads___v5___enums___click_type_pb2___ClickTypeEnum.ClickTypeValue
        ] = None,
        conversion_action: typing___Optional[typing___Text] = None,
        conversion_action_category: typing___Optional[
            google___ads___googleads___v5___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategoryValue
        ] = None,
        conversion_action_name: typing___Optional[typing___Text] = None,
        conversion_adjustment: typing___Optional[builtin___bool] = None,
        conversion_attribution_event_type: typing___Optional[
            google___ads___googleads___v5___enums___conversion_attribution_event_type_pb2___ConversionAttributionEventTypeEnum.ConversionAttributionEventTypeValue
        ] = None,
        conversion_lag_bucket: typing___Optional[
            google___ads___googleads___v5___enums___conversion_lag_bucket_pb2___ConversionLagBucketEnum.ConversionLagBucketValue
        ] = None,
        conversion_or_adjustment_lag_bucket: typing___Optional[
            google___ads___googleads___v5___enums___conversion_or_adjustment_lag_bucket_pb2___ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue
        ] = None,
        date: typing___Optional[typing___Text] = None,
        day_of_week: typing___Optional[
            google___ads___googleads___v5___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue
        ] = None,
        device: typing___Optional[
            google___ads___googleads___v5___enums___device_pb2___DeviceEnum.DeviceValue
        ] = None,
        external_conversion_source: typing___Optional[
            google___ads___googleads___v5___enums___external_conversion_source_pb2___ExternalConversionSourceEnum.ExternalConversionSourceValue
        ] = None,
        geo_target_airport: typing___Optional[typing___Text] = None,
        geo_target_canton: typing___Optional[typing___Text] = None,
        geo_target_city: typing___Optional[typing___Text] = None,
        geo_target_country: typing___Optional[typing___Text] = None,
        geo_target_county: typing___Optional[typing___Text] = None,
        geo_target_district: typing___Optional[typing___Text] = None,
        geo_target_metro: typing___Optional[typing___Text] = None,
        geo_target_most_specific_location: typing___Optional[typing___Text] = None,
        geo_target_postal_code: typing___Optional[typing___Text] = None,
        geo_target_province: typing___Optional[typing___Text] = None,
        geo_target_region: typing___Optional[typing___Text] = None,
        geo_target_state: typing___Optional[typing___Text] = None,
        hotel_booking_window_days: typing___Optional[builtin___int] = None,
        hotel_center_id: typing___Optional[builtin___int] = None,
        hotel_check_in_date: typing___Optional[typing___Text] = None,
        hotel_check_in_day_of_week: typing___Optional[
            google___ads___googleads___v5___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue
        ] = None,
        hotel_city: typing___Optional[typing___Text] = None,
        hotel_class: typing___Optional[builtin___int] = None,
        hotel_country: typing___Optional[typing___Text] = None,
        hotel_date_selection_type: typing___Optional[
            google___ads___googleads___v5___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue
        ] = None,
        hotel_length_of_stay: typing___Optional[builtin___int] = None,
        hotel_rate_rule_id: typing___Optional[typing___Text] = None,
        hotel_rate_type: typing___Optional[
            google___ads___googleads___v5___enums___hotel_rate_type_pb2___HotelRateTypeEnum.HotelRateTypeValue
        ] = None,
        hotel_price_bucket: typing___Optional[
            google___ads___googleads___v5___enums___hotel_price_bucket_pb2___HotelPriceBucketEnum.HotelPriceBucketValue
        ] = None,
        hotel_state: typing___Optional[typing___Text] = None,
        hour: typing___Optional[builtin___int] = None,
        interaction_on_this_extension: typing___Optional[builtin___bool] = None,
        keyword: typing___Optional[type___Keyword] = None,
        month: typing___Optional[typing___Text] = None,
        month_of_year: typing___Optional[
            google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue
        ] = None,
        partner_hotel_id: typing___Optional[typing___Text] = None,
        placeholder_type: typing___Optional[
            google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
        ] = None,
        product_aggregator_id: typing___Optional[builtin___int] = None,
        product_bidding_category_level1: typing___Optional[typing___Text] = None,
        product_bidding_category_level2: typing___Optional[typing___Text] = None,
        product_bidding_category_level3: typing___Optional[typing___Text] = None,
        product_bidding_category_level4: typing___Optional[typing___Text] = None,
        product_bidding_category_level5: typing___Optional[typing___Text] = None,
        product_brand: typing___Optional[typing___Text] = None,
        product_channel: typing___Optional[
            google___ads___googleads___v5___enums___product_channel_pb2___ProductChannelEnum.ProductChannelValue
        ] = None,
        product_channel_exclusivity: typing___Optional[
            google___ads___googleads___v5___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivityValue
        ] = None,
        product_condition: typing___Optional[
            google___ads___googleads___v5___enums___product_condition_pb2___ProductConditionEnum.ProductConditionValue
        ] = None,
        product_country: typing___Optional[typing___Text] = None,
        product_custom_attribute0: typing___Optional[typing___Text] = None,
        product_custom_attribute1: typing___Optional[typing___Text] = None,
        product_custom_attribute2: typing___Optional[typing___Text] = None,
        product_custom_attribute3: typing___Optional[typing___Text] = None,
        product_custom_attribute4: typing___Optional[typing___Text] = None,
        product_item_id: typing___Optional[typing___Text] = None,
        product_language: typing___Optional[typing___Text] = None,
        product_merchant_id: typing___Optional[builtin___int] = None,
        product_store_id: typing___Optional[typing___Text] = None,
        product_title: typing___Optional[typing___Text] = None,
        product_type_l1: typing___Optional[typing___Text] = None,
        product_type_l2: typing___Optional[typing___Text] = None,
        product_type_l3: typing___Optional[typing___Text] = None,
        product_type_l4: typing___Optional[typing___Text] = None,
        product_type_l5: typing___Optional[typing___Text] = None,
        quarter: typing___Optional[typing___Text] = None,
        search_engine_results_page_type: typing___Optional[
            google___ads___googleads___v5___enums___search_engine_results_page_type_pb2___SearchEngineResultsPageTypeEnum.SearchEngineResultsPageTypeValue
        ] = None,
        search_term_match_type: typing___Optional[
            google___ads___googleads___v5___enums___search_term_match_type_pb2___SearchTermMatchTypeEnum.SearchTermMatchTypeValue
        ] = None,
        slot: typing___Optional[
            google___ads___googleads___v5___enums___slot_pb2___SlotEnum.SlotValue
        ] = None,
        webpage: typing___Optional[typing___Text] = None,
        week: typing___Optional[typing___Text] = None,
        year: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "conversion_action",
            b"conversion_action",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "date",
            b"date",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "partner_hotel_id",
            b"partner_hotel_id",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "ad_network_type",
            b"ad_network_type",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "click_type",
            b"click_type",
            "conversion_action",
            b"conversion_action",
            "conversion_action_category",
            b"conversion_action_category",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "conversion_attribution_event_type",
            b"conversion_attribution_event_type",
            "conversion_lag_bucket",
            b"conversion_lag_bucket",
            "conversion_or_adjustment_lag_bucket",
            b"conversion_or_adjustment_lag_bucket",
            "date",
            b"date",
            "day_of_week",
            b"day_of_week",
            "device",
            b"device",
            "external_conversion_source",
            b"external_conversion_source",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_check_in_day_of_week",
            b"hotel_check_in_day_of_week",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_price_bucket",
            b"hotel_price_bucket",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_rate_type",
            b"hotel_rate_type",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "month_of_year",
            b"month_of_year",
            "partner_hotel_id",
            b"partner_hotel_id",
            "placeholder_type",
            b"placeholder_type",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "search_engine_results_page_type",
            b"search_engine_results_page_type",
            "search_term_match_type",
            b"search_term_match_type",
            "slot",
            b"slot",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions___Literal["conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action_name", b"_conversion_action_name"
        ],
    ) -> typing_extensions___Literal["conversion_action_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_adjustment", b"_conversion_adjustment"
        ],
    ) -> typing_extensions___Literal["conversion_adjustment"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_date", b"_date"]
    ) -> typing_extensions___Literal["date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_airport", b"_geo_target_airport"
        ],
    ) -> typing_extensions___Literal["geo_target_airport"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_canton", b"_geo_target_canton"
        ],
    ) -> typing_extensions___Literal["geo_target_canton"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_city", b"_geo_target_city"
        ],
    ) -> typing_extensions___Literal["geo_target_city"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_country", b"_geo_target_country"
        ],
    ) -> typing_extensions___Literal["geo_target_country"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_county", b"_geo_target_county"
        ],
    ) -> typing_extensions___Literal["geo_target_county"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_district", b"_geo_target_district"
        ],
    ) -> typing_extensions___Literal["geo_target_district"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_metro", b"_geo_target_metro"
        ],
    ) -> typing_extensions___Literal["geo_target_metro"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_most_specific_location", b"_geo_target_most_specific_location"
        ],
    ) -> typing_extensions___Literal["geo_target_most_specific_location"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_postal_code", b"_geo_target_postal_code"
        ],
    ) -> typing_extensions___Literal["geo_target_postal_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_province", b"_geo_target_province"
        ],
    ) -> typing_extensions___Literal["geo_target_province"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_region", b"_geo_target_region"
        ],
    ) -> typing_extensions___Literal["geo_target_region"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_geo_target_state", b"_geo_target_state"
        ],
    ) -> typing_extensions___Literal["geo_target_state"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_booking_window_days", b"_hotel_booking_window_days"
        ],
    ) -> typing_extensions___Literal["hotel_booking_window_days"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_center_id", b"_hotel_center_id"
        ],
    ) -> typing_extensions___Literal["hotel_center_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_check_in_date", b"_hotel_check_in_date"
        ],
    ) -> typing_extensions___Literal["hotel_check_in_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hotel_city", b"_hotel_city"]
    ) -> typing_extensions___Literal["hotel_city"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hotel_class", b"_hotel_class"]
    ) -> typing_extensions___Literal["hotel_class"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_hotel_country", b"_hotel_country"],
    ) -> typing_extensions___Literal["hotel_country"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_length_of_stay", b"_hotel_length_of_stay"
        ],
    ) -> typing_extensions___Literal["hotel_length_of_stay"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_rate_rule_id", b"_hotel_rate_rule_id"
        ],
    ) -> typing_extensions___Literal["hotel_rate_rule_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hotel_state", b"_hotel_state"]
    ) -> typing_extensions___Literal["hotel_state"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hour", b"_hour"]
    ) -> typing_extensions___Literal["hour"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_interaction_on_this_extension", b"_interaction_on_this_extension"
        ],
    ) -> typing_extensions___Literal["interaction_on_this_extension"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_month", b"_month"]
    ) -> typing_extensions___Literal["month"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_partner_hotel_id", b"_partner_hotel_id"
        ],
    ) -> typing_extensions___Literal["partner_hotel_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_aggregator_id", b"_product_aggregator_id"
        ],
    ) -> typing_extensions___Literal["product_aggregator_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_level1", b"_product_bidding_category_level1"
        ],
    ) -> typing_extensions___Literal["product_bidding_category_level1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_level2", b"_product_bidding_category_level2"
        ],
    ) -> typing_extensions___Literal["product_bidding_category_level2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_level3", b"_product_bidding_category_level3"
        ],
    ) -> typing_extensions___Literal["product_bidding_category_level3"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_level4", b"_product_bidding_category_level4"
        ],
    ) -> typing_extensions___Literal["product_bidding_category_level4"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_level5", b"_product_bidding_category_level5"
        ],
    ) -> typing_extensions___Literal["product_bidding_category_level5"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_product_brand", b"_product_brand"],
    ) -> typing_extensions___Literal["product_brand"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_country", b"_product_country"
        ],
    ) -> typing_extensions___Literal["product_country"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_custom_attribute0", b"_product_custom_attribute0"
        ],
    ) -> typing_extensions___Literal["product_custom_attribute0"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_custom_attribute1", b"_product_custom_attribute1"
        ],
    ) -> typing_extensions___Literal["product_custom_attribute1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_custom_attribute2", b"_product_custom_attribute2"
        ],
    ) -> typing_extensions___Literal["product_custom_attribute2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_custom_attribute3", b"_product_custom_attribute3"
        ],
    ) -> typing_extensions___Literal["product_custom_attribute3"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_custom_attribute4", b"_product_custom_attribute4"
        ],
    ) -> typing_extensions___Literal["product_custom_attribute4"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_item_id", b"_product_item_id"
        ],
    ) -> typing_extensions___Literal["product_item_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_language", b"_product_language"
        ],
    ) -> typing_extensions___Literal["product_language"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_merchant_id", b"_product_merchant_id"
        ],
    ) -> typing_extensions___Literal["product_merchant_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_store_id", b"_product_store_id"
        ],
    ) -> typing_extensions___Literal["product_store_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_product_title", b"_product_title"],
    ) -> typing_extensions___Literal["product_title"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_type_l1", b"_product_type_l1"
        ],
    ) -> typing_extensions___Literal["product_type_l1"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_type_l2", b"_product_type_l2"
        ],
    ) -> typing_extensions___Literal["product_type_l2"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_type_l3", b"_product_type_l3"
        ],
    ) -> typing_extensions___Literal["product_type_l3"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_type_l4", b"_product_type_l4"
        ],
    ) -> typing_extensions___Literal["product_type_l4"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_type_l5", b"_product_type_l5"
        ],
    ) -> typing_extensions___Literal["product_type_l5"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_quarter", b"_quarter"]
    ) -> typing_extensions___Literal["quarter"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_webpage", b"_webpage"]
    ) -> typing_extensions___Literal["webpage"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_week", b"_week"]
    ) -> typing_extensions___Literal["week"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_year", b"_year"]
    ) -> typing_extensions___Literal["year"]: ...

type___Segments = Segments

class Keyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ad_group_criterion: typing___Text = ...
    @property
    def info(
        self,
    ) -> google___ads___googleads___v5___common___criteria_pb2___KeywordInfo: ...
    def __init__(
        self,
        *,
        ad_group_criterion: typing___Optional[typing___Text] = None,
        info: typing___Optional[
            google___ads___googleads___v5___common___criteria_pb2___KeywordInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_ad_group_criterion", b"_ad_group_criterion"
        ],
    ) -> typing_extensions___Literal["ad_group_criterion"]: ...

type___Keyword = Keyword

class BudgetCampaignAssociationStatus(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    campaign: typing___Text = ...
    status: google___ads___googleads___v5___enums___budget_campaign_association_status_pb2___BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatusValue = ...
    def __init__(
        self,
        *,
        campaign: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___budget_campaign_association_status_pb2___BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign", b"_campaign", "campaign", b"campaign"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign", b"_campaign", "campaign", b"campaign", "status", b"status"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_campaign", b"_campaign"]
    ) -> typing_extensions___Literal["campaign"]: ...

type___BudgetCampaignAssociationStatus = BudgetCampaignAssociationStatus
