from typing import Any

class AdGroupServiceStub:
    GetAdGroup: Any = ...
    MutateAdGroups: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupServiceServicer:
    def GetAdGroup(self, request: Any, context: Any) -> None: ...
    def MutateAdGroups(self, request: Any, context: Any) -> None: ...

def add_AdGroupServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
