# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdNetworkTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdNetworkTypeValue = typing___NewType("AdNetworkTypeValue", builtin___int)
    type___AdNetworkTypeValue = AdNetworkTypeValue
    AdNetworkType: _AdNetworkType
    class _AdNetworkType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdNetworkTypeEnum.AdNetworkTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 0)
        UNKNOWN = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 1)
        SEARCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 2)
        SEARCH_PARTNERS = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 3)
        CONTENT = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 4)
        YOUTUBE_SEARCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 5)
        YOUTUBE_WATCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 6)
        MIXED = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 7)
    UNSPECIFIED = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 0)
    UNKNOWN = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 1)
    SEARCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 2)
    SEARCH_PARTNERS = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 3)
    CONTENT = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 4)
    YOUTUBE_SEARCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 5)
    YOUTUBE_WATCH = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 6)
    MIXED = typing___cast(AdNetworkTypeEnum.AdNetworkTypeValue, 7)
    type___AdNetworkType = AdNetworkType
    def __init__(self,) -> None: ...

type___AdNetworkTypeEnum = AdNetworkTypeEnum
