# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2 import (
    CampaignDraftStatusEnum as google___ads___googleads___v6___enums___campaign_draft_status_pb2___CampaignDraftStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignDraft(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    draft_id: builtin___int = ...
    base_campaign: typing___Text = ...
    name: typing___Text = ...
    draft_campaign: typing___Text = ...
    status: google___ads___googleads___v6___enums___campaign_draft_status_pb2___CampaignDraftStatusEnum.CampaignDraftStatusValue = ...
    has_experiment_running: builtin___bool = ...
    long_running_operation: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        draft_id: typing___Optional[builtin___int] = None,
        base_campaign: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        draft_campaign: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___campaign_draft_status_pb2___CampaignDraftStatusEnum.CampaignDraftStatusValue
        ] = None,
        has_experiment_running: typing___Optional[builtin___bool] = None,
        long_running_operation: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_base_campaign", b"_base_campaign"],
    ) -> typing_extensions___Literal["base_campaign"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_draft_campaign", b"_draft_campaign"],
    ) -> typing_extensions___Literal["draft_campaign"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_draft_id", b"_draft_id"]
    ) -> typing_extensions___Literal["draft_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_has_experiment_running", b"_has_experiment_running"
        ],
    ) -> typing_extensions___Literal["has_experiment_running"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions___Literal["long_running_operation"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...

type___CampaignDraft = CampaignDraft
