# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductBiddingCategoryLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ProductBiddingCategoryLevelValue = typing___NewType(
        "ProductBiddingCategoryLevelValue", builtin___int
    )
    type___ProductBiddingCategoryLevelValue = ProductBiddingCategoryLevelValue
    ProductBiddingCategoryLevel: _ProductBiddingCategoryLevel
    class _ProductBiddingCategoryLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 0
        )
        UNKNOWN = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 1
        )
        LEVEL1 = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 2
        )
        LEVEL2 = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 3
        )
        LEVEL3 = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 4
        )
        LEVEL4 = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 5
        )
        LEVEL5 = typing___cast(
            ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 6
        )
    UNSPECIFIED = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 0
    )
    UNKNOWN = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 1
    )
    LEVEL1 = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 2
    )
    LEVEL2 = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 3
    )
    LEVEL3 = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 4
    )
    LEVEL4 = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 5
    )
    LEVEL5 = typing___cast(
        ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue, 6
    )
    type___ProductBiddingCategoryLevel = ProductBiddingCategoryLevel
    def __init__(self,) -> None: ...

type___ProductBiddingCategoryLevelEnum = ProductBiddingCategoryLevelEnum
