# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PositiveGeoTargetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PositiveGeoTargetTypeValue = typing___NewType(
        "PositiveGeoTargetTypeValue", builtin___int
    )
    type___PositiveGeoTargetTypeValue = PositiveGeoTargetTypeValue
    PositiveGeoTargetType: _PositiveGeoTargetType
    class _PositiveGeoTargetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 0
        )
        UNKNOWN = typing___cast(PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 1)
        PRESENCE_OR_INTEREST = typing___cast(
            PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 5
        )
        SEARCH_INTEREST = typing___cast(
            PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 6
        )
        PRESENCE = typing___cast(
            PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 7
        )
    UNSPECIFIED = typing___cast(PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 0)
    UNKNOWN = typing___cast(PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 1)
    PRESENCE_OR_INTEREST = typing___cast(
        PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 5
    )
    SEARCH_INTEREST = typing___cast(
        PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 6
    )
    PRESENCE = typing___cast(PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue, 7)
    type___PositiveGeoTargetType = PositiveGeoTargetType
    def __init__(self,) -> None: ...

type___PositiveGeoTargetTypeEnum = PositiveGeoTargetTypeEnum
