# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyValidationParameterErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyValidationParameterErrorValue = typing___NewType(
        "PolicyValidationParameterErrorValue", builtin___int
    )
    type___PolicyValidationParameterErrorValue = PolicyValidationParameterErrorValue
    PolicyValidationParameterError: _PolicyValidationParameterError
    class _PolicyValidationParameterError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 0
        )
        UNKNOWN = typing___cast(
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 1
        )
        UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = typing___cast(
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 2
        )
        UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = typing___cast(
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 3
        )
        CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = typing___cast(
            PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 4
        )
    UNSPECIFIED = typing___cast(
        PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 0
    )
    UNKNOWN = typing___cast(
        PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 1
    )
    UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = typing___cast(
        PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 2
    )
    UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = typing___cast(
        PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 3
    )
    CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = typing___cast(
        PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorValue, 4
    )
    type___PolicyValidationParameterError = PolicyValidationParameterError
    def __init__(self,) -> None: ...

type___PolicyValidationParameterErrorEnum = PolicyValidationParameterErrorEnum
