from typing import Any

class GenderViewServiceStub:
    GetGenderView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GenderViewServiceServicer:
    def GetGenderView(self, request: Any, context: Any) -> None: ...

def add_GenderViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
