from typing import Any

class AdGroupAdAssetViewServiceStub:
    GetAdGroupAdAssetView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupAdAssetViewServiceServicer:
    def GetAdGroupAdAssetView(self, request: Any, context: Any) -> None: ...

def add_AdGroupAdAssetViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
