from typing import Any

class CampaignCriterionSimulationServiceStub:
    GetCampaignCriterionSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignCriterionSimulationServiceServicer:
    def GetCampaignCriterionSimulation(self, request: Any, context: Any) -> None: ...

def add_CampaignCriterionSimulationServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
