# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LocalPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LocalPlaceholderFieldValue = typing___NewType(
        "LocalPlaceholderFieldValue", builtin___int
    )
    type___LocalPlaceholderFieldValue = LocalPlaceholderFieldValue
    LocalPlaceholderField: _LocalPlaceholderField
    class _LocalPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 1)
        DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 2)
        DEAL_NAME = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 3
        )
        SUBTITLE = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 4
        )
        DESCRIPTION = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 5
        )
        PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 6)
        FORMATTED_PRICE = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 7
        )
        SALE_PRICE = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 8
        )
        FORMATTED_SALE_PRICE = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 9
        )
        IMAGE_URL = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 10
        )
        ADDRESS = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 11
        )
        CATEGORY = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 12
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 13
        )
        FINAL_URLS = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 14
        )
        FINAL_MOBILE_URLS = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 15
        )
        TRACKING_URL = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 16
        )
        ANDROID_APP_LINK = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 17
        )
        SIMILAR_DEAL_IDS = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 18
        )
        IOS_APP_LINK = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 19
        )
        IOS_APP_STORE_ID = typing___cast(
            LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 20
        )
    UNSPECIFIED = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 1)
    DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 2)
    DEAL_NAME = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 3)
    SUBTITLE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 4)
    DESCRIPTION = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 5)
    PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 6)
    FORMATTED_PRICE = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 7
    )
    SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 8)
    FORMATTED_SALE_PRICE = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 9
    )
    IMAGE_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 10)
    ADDRESS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 11)
    CATEGORY = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 12)
    CONTEXTUAL_KEYWORDS = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 13
    )
    FINAL_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 14)
    FINAL_MOBILE_URLS = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 15
    )
    TRACKING_URL = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 16
    )
    ANDROID_APP_LINK = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 17
    )
    SIMILAR_DEAL_IDS = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 18
    )
    IOS_APP_LINK = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 19
    )
    IOS_APP_STORE_ID = typing___cast(
        LocalPlaceholderFieldEnum.LocalPlaceholderFieldValue, 20
    )
    type___LocalPlaceholderField = LocalPlaceholderField
    def __init__(self,) -> None: ...

type___LocalPlaceholderFieldEnum = LocalPlaceholderFieldEnum
