from typing import Any

class GoogleAdsServiceStub:
    Search: Any = ...
    SearchStream: Any = ...
    Mutate: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GoogleAdsServiceServicer:
    def Search(self, request: Any, context: Any) -> None: ...
    def SearchStream(self, request: Any, context: Any) -> None: ...
    def Mutate(self, request: Any, context: Any) -> None: ...

def add_GoogleAdsServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
