# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccessReasonEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccessReasonValue = typing___NewType("AccessReasonValue", builtin___int)
    type___AccessReasonValue = AccessReasonValue
    AccessReason: _AccessReason
    class _AccessReason(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccessReasonEnum.AccessReasonValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AccessReasonEnum.AccessReasonValue, 0)
        UNKNOWN = typing___cast(AccessReasonEnum.AccessReasonValue, 1)
        OWNED = typing___cast(AccessReasonEnum.AccessReasonValue, 2)
        SHARED = typing___cast(AccessReasonEnum.AccessReasonValue, 3)
        LICENSED = typing___cast(AccessReasonEnum.AccessReasonValue, 4)
        SUBSCRIBED = typing___cast(AccessReasonEnum.AccessReasonValue, 5)
        AFFILIATED = typing___cast(AccessReasonEnum.AccessReasonValue, 6)
    UNSPECIFIED = typing___cast(AccessReasonEnum.AccessReasonValue, 0)
    UNKNOWN = typing___cast(AccessReasonEnum.AccessReasonValue, 1)
    OWNED = typing___cast(AccessReasonEnum.AccessReasonValue, 2)
    SHARED = typing___cast(AccessReasonEnum.AccessReasonValue, 3)
    LICENSED = typing___cast(AccessReasonEnum.AccessReasonValue, 4)
    SUBSCRIBED = typing___cast(AccessReasonEnum.AccessReasonValue, 5)
    AFFILIATED = typing___cast(AccessReasonEnum.AccessReasonValue, 6)
    type___AccessReason = AccessReason
    def __init__(self,) -> None: ...

type___AccessReasonEnum = AccessReasonEnum
