# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupTypeValue = typing___NewType("AdGroupTypeValue", builtin___int)
    type___AdGroupTypeValue = AdGroupTypeValue
    AdGroupType: _AdGroupType
    class _AdGroupType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupTypeEnum.AdGroupTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 0)
        UNKNOWN = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 1)
        SEARCH_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 2)
        DISPLAY_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 3)
        SHOPPING_PRODUCT_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 4)
        HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 6)
        SHOPPING_SMART_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 7)
        VIDEO_BUMPER = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 8)
        VIDEO_TRUE_VIEW_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 9)
        VIDEO_TRUE_VIEW_IN_DISPLAY = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 10)
        VIDEO_NON_SKIPPABLE_IN_STREAM = typing___cast(
            AdGroupTypeEnum.AdGroupTypeValue, 11
        )
        VIDEO_OUTSTREAM = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 12)
        SEARCH_DYNAMIC_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 13)
        SHOPPING_COMPARISON_LISTING_ADS = typing___cast(
            AdGroupTypeEnum.AdGroupTypeValue, 14
        )
        PROMOTED_HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 15)
        VIDEO_RESPONSIVE = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 16)
    UNSPECIFIED = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 0)
    UNKNOWN = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 1)
    SEARCH_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 2)
    DISPLAY_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 3)
    SHOPPING_PRODUCT_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 4)
    HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 6)
    SHOPPING_SMART_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 7)
    VIDEO_BUMPER = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 8)
    VIDEO_TRUE_VIEW_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 9)
    VIDEO_TRUE_VIEW_IN_DISPLAY = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 10)
    VIDEO_NON_SKIPPABLE_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 11)
    VIDEO_OUTSTREAM = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 12)
    SEARCH_DYNAMIC_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 13)
    SHOPPING_COMPARISON_LISTING_ADS = typing___cast(
        AdGroupTypeEnum.AdGroupTypeValue, 14
    )
    PROMOTED_HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 15)
    VIDEO_RESPONSIVE = typing___cast(AdGroupTypeEnum.AdGroupTypeValue, 16)
    type___AdGroupType = AdGroupType
    def __init__(self,) -> None: ...

type___AdGroupTypeEnum = AdGroupTypeEnum
