from typing import Any

class KeywordPlanNegativeKeywordServiceStub:
    GetKeywordPlanNegativeKeyword: Any = ...
    MutateKeywordPlanNegativeKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanNegativeKeywordServiceServicer:
    def GetKeywordPlanNegativeKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanNegativeKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanNegativeKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
