# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TextLabel(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    background_color: typing___Text = ...
    description: typing___Text = ...
    def __init__(
        self,
        *,
        background_color: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_background_color", b"_background_color"
        ],
    ) -> typing_extensions___Literal["background_color"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...

type___TextLabel = TextLabel
