# Stubs for google.ads.google_ads.v6.proto.enums.policy_topic_evidence_destination_not_working_device_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.
