# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeoTargetingTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GeoTargetingTypeValue = typing___NewType("GeoTargetingTypeValue", builtin___int)
    type___GeoTargetingTypeValue = GeoTargetingTypeValue
    GeoTargetingType: _GeoTargetingType
    class _GeoTargetingType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GeoTargetingTypeEnum.GeoTargetingTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 0)
        UNKNOWN = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 1)
        AREA_OF_INTEREST = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 2)
        LOCATION_OF_PRESENCE = typing___cast(
            GeoTargetingTypeEnum.GeoTargetingTypeValue, 3
        )
    UNSPECIFIED = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 0)
    UNKNOWN = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 1)
    AREA_OF_INTEREST = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 2)
    LOCATION_OF_PRESENCE = typing___cast(GeoTargetingTypeEnum.GeoTargetingTypeValue, 3)
    type___GeoTargetingType = GeoTargetingType
    def __init__(self,) -> None: ...

type___GeoTargetingTypeEnum = GeoTargetingTypeEnum
