# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordMatchTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordMatchTypeValue = typing___NewType("KeywordMatchTypeValue", builtin___int)
    type___KeywordMatchTypeValue = KeywordMatchTypeValue
    KeywordMatchType: _KeywordMatchType
    class _KeywordMatchType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordMatchTypeEnum.KeywordMatchTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 0)
        UNKNOWN = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 1)
        EXACT = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 2)
        PHRASE = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 3)
        BROAD = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 4)
    UNSPECIFIED = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 0)
    UNKNOWN = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 1)
    EXACT = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 2)
    PHRASE = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 3)
    BROAD = typing___cast(KeywordMatchTypeEnum.KeywordMatchTypeValue, 4)
    type___KeywordMatchType = KeywordMatchType
    def __init__(self,) -> None: ...

type___KeywordMatchTypeEnum = KeywordMatchTypeEnum
