from typing import Any

class LanguageConstantServiceStub:
    GetLanguageConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LanguageConstantServiceServicer:
    def GetLanguageConstant(self, request: Any, context: Any) -> None: ...

def add_LanguageConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
