# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListTypeValue = typing___NewType("UserListTypeValue", builtin___int)
    type___UserListTypeValue = UserListTypeValue
    UserListType: _UserListType
    class _UserListType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListTypeEnum.UserListTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserListTypeEnum.UserListTypeValue, 0)
        UNKNOWN = typing___cast(UserListTypeEnum.UserListTypeValue, 1)
        REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 2)
        LOGICAL = typing___cast(UserListTypeEnum.UserListTypeValue, 3)
        EXTERNAL_REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 4)
        RULE_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 5)
        SIMILAR = typing___cast(UserListTypeEnum.UserListTypeValue, 6)
        CRM_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 7)
    UNSPECIFIED = typing___cast(UserListTypeEnum.UserListTypeValue, 0)
    UNKNOWN = typing___cast(UserListTypeEnum.UserListTypeValue, 1)
    REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 2)
    LOGICAL = typing___cast(UserListTypeEnum.UserListTypeValue, 3)
    EXTERNAL_REMARKETING = typing___cast(UserListTypeEnum.UserListTypeValue, 4)
    RULE_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 5)
    SIMILAR = typing___cast(UserListTypeEnum.UserListTypeValue, 6)
    CRM_BASED = typing___cast(UserListTypeEnum.UserListTypeValue, 7)
    type___UserListType = UserListType
    def __init__(self,) -> None: ...

type___UserListTypeEnum = UserListTypeEnum
