# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo,
    KeywordInfo as google___ads___googleads___v6___common___criteria_pb2___KeywordInfo,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_device_pb2 import (
    FeedItemTargetDeviceEnum as google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_status_pb2 import (
    FeedItemTargetStatusEnum as google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_type_pb2 import (
    FeedItemTargetTypeEnum as google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    feed_item: typing___Text = ...
    feed_item_target_type: google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetTypeValue = ...
    feed_item_target_id: builtin___int = ...
    status: google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum.FeedItemTargetStatusValue = ...
    campaign: typing___Text = ...
    ad_group: typing___Text = ...
    geo_target_constant: typing___Text = ...
    device: google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue = ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___KeywordInfo: ...
    @property
    def ad_schedule(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed_item: typing___Optional[typing___Text] = None,
        feed_item_target_type: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetTypeValue
        ] = None,
        feed_item_target_id: typing___Optional[builtin___int] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum.FeedItemTargetStatusValue
        ] = None,
        campaign: typing___Optional[typing___Text] = None,
        ad_group: typing___Optional[typing___Text] = None,
        keyword: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___KeywordInfo
        ] = None,
        geo_target_constant: typing___Optional[typing___Text] = None,
        device: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue
        ] = None,
        ad_schedule: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_item",
            b"_feed_item",
            "_feed_item_target_id",
            b"_feed_item_target_id",
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "target",
            b"target",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_item",
            b"_feed_item",
            "_feed_item_target_id",
            b"_feed_item_target_id",
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "feed_item_target_type",
            b"feed_item_target_type",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target",
            b"target",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_feed_item", b"_feed_item"]
    ) -> typing_extensions___Literal["feed_item"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_feed_item_target_id", b"_feed_item_target_id"
        ],
    ) -> typing_extensions___Literal["feed_item_target_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["target", b"target"]
    ) -> typing_extensions___Literal[
        "campaign",
        "ad_group",
        "keyword",
        "geo_target_constant",
        "device",
        "ad_schedule",
    ]: ...

type___FeedItemTarget = FeedItemTarget
