from typing import Any

class AccountLinkServiceStub:
    GetAccountLink: Any = ...
    MutateAccountLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountLinkServiceServicer:
    def GetAccountLink(self, request: Any, context: Any) -> None: ...
    def MutateAccountLink(self, request: Any, context: Any) -> None: ...

def add_AccountLinkServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
