# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemQualityDisapprovalReasonEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemQualityDisapprovalReasonValue = typing___NewType(
        "FeedItemQualityDisapprovalReasonValue", builtin___int
    )
    type___FeedItemQualityDisapprovalReasonValue = FeedItemQualityDisapprovalReasonValue
    FeedItemQualityDisapprovalReason: _FeedItemQualityDisapprovalReason
    class _FeedItemQualityDisapprovalReason(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            0,
        )
        UNKNOWN = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            1,
        )
        PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            2,
        )
        PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            3,
        )
        PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            4,
        )
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            5,
        )
        PRICE_UNSUPPORTED_LANGUAGE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            6,
        )
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            7,
        )
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            8,
        )
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            9,
        )
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            10,
        )
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            11,
        )
        PRICE_TABLE_ROW_UNRATEABLE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            12,
        )
        PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            13,
        )
        PRICE_TABLE_ROW_URL_INVALID = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            14,
        )
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            15,
        )
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            16,
        )
        STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            17,
        )
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            18,
        )
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            19,
        )
    UNSPECIFIED = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 0
    )
    UNKNOWN = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 1
    )
    PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 2
    )
    PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 3
    )
    PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 4
    )
    PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 5
    )
    PRICE_UNSUPPORTED_LANGUAGE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 6
    )
    PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 7
    )
    PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 8
    )
    PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 9
    )
    PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 10
    )
    PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 11
    )
    PRICE_TABLE_ROW_UNRATEABLE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 12
    )
    PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 13
    )
    PRICE_TABLE_ROW_URL_INVALID = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 14
    )
    PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 15
    )
    STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 16
    )
    STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 17
    )
    STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 18
    )
    STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 19
    )
    type___FeedItemQualityDisapprovalReason = FeedItemQualityDisapprovalReason
    def __init__(self,) -> None: ...

type___FeedItemQualityDisapprovalReasonEnum = FeedItemQualityDisapprovalReasonEnum
