# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v6___common___dates_pb2___DateRange,
)
from google.ads.google_ads.v6.proto.enums.keyword_plan_forecast_interval_pb2 import (
    KeywordPlanForecastIntervalEnum as google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlan(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    @property
    def forecast_period(self) -> type___KeywordPlanForecastPeriod: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        forecast_period: typing___Optional[type___KeywordPlanForecastPeriod] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "forecast_period",
            b"forecast_period",
            "id",
            b"id",
            "name",
            b"name",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "forecast_period",
            b"forecast_period",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...

type___KeywordPlan = KeywordPlan

class KeywordPlanForecastPeriod(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    date_interval: google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalValue = ...
    @property
    def date_range(
        self,
    ) -> google___ads___googleads___v6___common___dates_pb2___DateRange: ...
    def __init__(
        self,
        *,
        date_interval: typing___Optional[
            google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalValue
        ] = None,
        date_range: typing___Optional[
            google___ads___googleads___v6___common___dates_pb2___DateRange
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "date_interval",
            b"date_interval",
            "date_range",
            b"date_range",
            "interval",
            b"interval",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "date_interval",
            b"date_interval",
            "date_range",
            b"date_range",
            "interval",
            b"interval",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["interval", b"interval"]
    ) -> typing_extensions___Literal["date_interval", "date_range"]: ...

type___KeywordPlanForecastPeriod = KeywordPlanForecastPeriod
