# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.account_budget_proposal_type_pb2 import (
    AccountBudgetProposalTypeEnum as google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.account_budget_status_pb2 import (
    AccountBudgetStatusEnum as google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.spending_limit_type_pb2 import (
    SpendingLimitTypeEnum as google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PendingAccountBudgetProposal(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        account_budget_proposal: typing___Text = ...
        proposal_type: google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue = ...
        name: typing___Text = ...
        start_date_time: typing___Text = ...
        purchase_order_number: typing___Text = ...
        notes: typing___Text = ...
        creation_date_time: typing___Text = ...
        end_date_time: typing___Text = ...
        end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
        spending_limit_micros: builtin___int = ...
        spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
        def __init__(
            self,
            *,
            account_budget_proposal: typing___Optional[typing___Text] = None,
            proposal_type: typing___Optional[
                google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue
            ] = None,
            name: typing___Optional[typing___Text] = None,
            start_date_time: typing___Optional[typing___Text] = None,
            purchase_order_number: typing___Optional[typing___Text] = None,
            notes: typing___Optional[typing___Text] = None,
            creation_date_time: typing___Optional[typing___Text] = None,
            end_date_time: typing___Optional[typing___Text] = None,
            end_time_type: typing___Optional[
                google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
            ] = None,
            spending_limit_micros: typing___Optional[builtin___int] = None,
            spending_limit_type: typing___Optional[
                google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "proposal_type",
                b"proposal_type",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_account_budget_proposal", b"_account_budget_proposal"
            ],
        ) -> typing_extensions___Literal["account_budget_proposal"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions___Literal["creation_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_name", b"_name"]
        ) -> typing_extensions___Literal["name"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_notes", b"_notes"]
        ) -> typing_extensions___Literal["notes"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions___Literal["purchase_order_number"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions___Literal["start_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["end_time", b"end_time"]
        ) -> typing_extensions___Literal["end_date_time", "end_time_type"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "spending_limit", b"spending_limit"
            ],
        ) -> typing_extensions___Literal[
            "spending_limit_micros", "spending_limit_type"
        ]: ...
    type___PendingAccountBudgetProposal = PendingAccountBudgetProposal

    resource_name: typing___Text = ...
    id: builtin___int = ...
    billing_setup: typing___Text = ...
    status: google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatusValue = ...
    name: typing___Text = ...
    proposed_start_date_time: typing___Text = ...
    approved_start_date_time: typing___Text = ...
    total_adjustments_micros: builtin___int = ...
    amount_served_micros: builtin___int = ...
    purchase_order_number: typing___Text = ...
    notes: typing___Text = ...
    proposed_end_date_time: typing___Text = ...
    proposed_end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    approved_end_date_time: typing___Text = ...
    approved_end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    proposed_spending_limit_micros: builtin___int = ...
    proposed_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    approved_spending_limit_micros: builtin___int = ...
    approved_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    adjusted_spending_limit_micros: builtin___int = ...
    adjusted_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    @property
    def pending_proposal(self) -> type___AccountBudget.PendingAccountBudgetProposal: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        billing_setup: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatusValue
        ] = None,
        name: typing___Optional[typing___Text] = None,
        proposed_start_date_time: typing___Optional[typing___Text] = None,
        approved_start_date_time: typing___Optional[typing___Text] = None,
        total_adjustments_micros: typing___Optional[builtin___int] = None,
        amount_served_micros: typing___Optional[builtin___int] = None,
        purchase_order_number: typing___Optional[typing___Text] = None,
        notes: typing___Optional[typing___Text] = None,
        pending_proposal: typing___Optional[
            type___AccountBudget.PendingAccountBudgetProposal
        ] = None,
        proposed_end_date_time: typing___Optional[typing___Text] = None,
        proposed_end_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        approved_end_date_time: typing___Optional[typing___Text] = None,
        approved_end_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        proposed_spending_limit_micros: typing___Optional[builtin___int] = None,
        proposed_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
        approved_spending_limit_micros: typing___Optional[builtin___int] = None,
        approved_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
        adjusted_spending_limit_micros: typing___Optional[builtin___int] = None,
        adjusted_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "amount_served_micros",
            b"amount_served_micros",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_adjustments_micros",
            b"total_adjustments_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions___Literal["approved_start_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions___Literal["billing_setup"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_notes", b"_notes"]
    ) -> typing_extensions___Literal["notes"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_proposed_start_date_time", b"_proposed_start_date_time"
        ],
    ) -> typing_extensions___Literal["proposed_start_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_purchase_order_number", b"_purchase_order_number"
        ],
    ) -> typing_extensions___Literal["purchase_order_number"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "adjusted_spending_limit", b"adjusted_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "adjusted_spending_limit_micros", "adjusted_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions___Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions___Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...

type___AccountBudget = AccountBudget
