# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAdErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupAdErrorValue = typing___NewType("AdGroupAdErrorValue", builtin___int)
    type___AdGroupAdErrorValue = AdGroupAdErrorValue
    AdGroupAdError: _AdGroupAdError
    class _AdGroupAdError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupAdErrorEnum.AdGroupAdErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 0)
        UNKNOWN = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 1)
        AD_GROUP_AD_LABEL_DOES_NOT_EXIST = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 2
        )
        AD_GROUP_AD_LABEL_ALREADY_EXISTS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 3
        )
        AD_NOT_UNDER_ADGROUP = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 4)
        CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 5
        )
        CANNOT_CREATE_DEPRECATED_ADS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 6
        )
        CANNOT_CREATE_TEXT_ADS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 7
        )
        EMPTY_FIELD = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 8)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 9
        )
        AD_TYPE_CANNOT_BE_PAUSED = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 10
        )
        AD_TYPE_CANNOT_BE_REMOVED = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 11
        )
    UNSPECIFIED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 0)
    UNKNOWN = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 1)
    AD_GROUP_AD_LABEL_DOES_NOT_EXIST = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 2
    )
    AD_GROUP_AD_LABEL_ALREADY_EXISTS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 3
    )
    AD_NOT_UNDER_ADGROUP = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 4)
    CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 5
    )
    CANNOT_CREATE_DEPRECATED_ADS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 6
    )
    CANNOT_CREATE_TEXT_ADS = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 7)
    EMPTY_FIELD = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 8)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 9
    )
    AD_TYPE_CANNOT_BE_PAUSED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 10)
    AD_TYPE_CANNOT_BE_REMOVED = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 11
    )
    type___AdGroupAdError = AdGroupAdError
    def __init__(self,) -> None: ...

type___AdGroupAdErrorEnum = AdGroupAdErrorEnum
