from typing import Any

class FeedItemServiceStub:
    GetFeedItem: Any = ...
    MutateFeedItems: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedItemServiceServicer:
    def GetFeedItem(self, request: Any, context: Any) -> None: ...
    def MutateFeedItems(self, request: Any, context: Any) -> None: ...

def add_FeedItemServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
