# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PlacementTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PlacementTypeValue = typing___NewType("PlacementTypeValue", builtin___int)
    type___PlacementTypeValue = PlacementTypeValue
    PlacementType: _PlacementType
    class _PlacementType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PlacementTypeEnum.PlacementTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PlacementTypeEnum.PlacementTypeValue, 0)
        UNKNOWN = typing___cast(PlacementTypeEnum.PlacementTypeValue, 1)
        WEBSITE = typing___cast(PlacementTypeEnum.PlacementTypeValue, 2)
        MOBILE_APP_CATEGORY = typing___cast(PlacementTypeEnum.PlacementTypeValue, 3)
        MOBILE_APPLICATION = typing___cast(PlacementTypeEnum.PlacementTypeValue, 4)
        YOUTUBE_VIDEO = typing___cast(PlacementTypeEnum.PlacementTypeValue, 5)
        YOUTUBE_CHANNEL = typing___cast(PlacementTypeEnum.PlacementTypeValue, 6)
    UNSPECIFIED = typing___cast(PlacementTypeEnum.PlacementTypeValue, 0)
    UNKNOWN = typing___cast(PlacementTypeEnum.PlacementTypeValue, 1)
    WEBSITE = typing___cast(PlacementTypeEnum.PlacementTypeValue, 2)
    MOBILE_APP_CATEGORY = typing___cast(PlacementTypeEnum.PlacementTypeValue, 3)
    MOBILE_APPLICATION = typing___cast(PlacementTypeEnum.PlacementTypeValue, 4)
    YOUTUBE_VIDEO = typing___cast(PlacementTypeEnum.PlacementTypeValue, 5)
    YOUTUBE_CHANNEL = typing___cast(PlacementTypeEnum.PlacementTypeValue, 6)
    type___PlacementType = PlacementType
    def __init__(self,) -> None: ...

type___PlacementTypeEnum = PlacementTypeEnum
