# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.ad_type_infos_pb2 import (
    AppAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo,
    AppEngagementAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo,
    CallOnlyAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo,
    DisplayUploadAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo,
    GmailAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo,
    HotelAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo,
    ImageAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo,
    LegacyAppInstallAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo,
    LocalAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo,
    ResponsiveDisplayAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo,
    ShoppingSmartAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo,
    TextAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo,
    VideoAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo,
    VideoResponsiveAdInfo as google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo,
)
from google.ads.google_ads.v6.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v6.proto.common.final_app_url_pb2 import (
    FinalAppUrl as google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl,
)
from google.ads.google_ads.v6.proto.common.url_collection_pb2 import (
    UrlCollection as google___ads___googleads___v6___common___url_collection_pb2___UrlCollection,
)
from google.ads.google_ads.v6.proto.enums.ad_type_pb2 import (
    AdTypeEnum as google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v6___enums___device_pb2___DeviceEnum,
)
from google.ads.google_ads.v6.proto.enums.system_managed_entity_source_pb2 import (
    SystemManagedResourceSourceEnum as google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Ad(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    final_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    final_mobile_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    tracking_url_template: typing___Text = ...
    final_url_suffix: typing___Text = ...
    display_url: typing___Text = ...
    type: google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum.AdTypeValue = ...
    added_by_google_ads: builtin___bool = ...
    device_preference: google___ads___googleads___v6___enums___device_pb2___DeviceEnum.DeviceValue = ...
    name: typing___Text = ...
    system_managed_resource_source: google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSourceValue = ...
    @property
    def final_app_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl
    ]: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def url_collections(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___url_collection_pb2___UrlCollection
    ]: ...
    @property
    def text_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo: ...
    @property
    def expanded_text_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo: ...
    @property
    def call_only_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo: ...
    @property
    def expanded_dynamic_search_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo: ...
    @property
    def hotel_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo: ...
    @property
    def shopping_smart_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo: ...
    @property
    def shopping_product_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo: ...
    @property
    def gmail_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo: ...
    @property
    def image_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo: ...
    @property
    def video_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo: ...
    @property
    def video_responsive_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo: ...
    @property
    def responsive_search_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo: ...
    @property
    def legacy_responsive_display_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo: ...
    @property
    def app_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo: ...
    @property
    def legacy_app_install_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo: ...
    @property
    def responsive_display_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo: ...
    @property
    def local_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo: ...
    @property
    def display_upload_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo: ...
    @property
    def app_engagement_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo: ...
    @property
    def shopping_comparison_listing_ad(
        self,
    ) -> google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        final_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        final_app_urls: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___final_app_url_pb2___FinalAppUrl
            ]
        ] = None,
        final_mobile_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
        final_url_suffix: typing___Optional[typing___Text] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        display_url: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___ad_type_pb2___AdTypeEnum.AdTypeValue
        ] = None,
        added_by_google_ads: typing___Optional[builtin___bool] = None,
        device_preference: typing___Optional[
            google___ads___googleads___v6___enums___device_pb2___DeviceEnum.DeviceValue
        ] = None,
        url_collections: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___url_collection_pb2___UrlCollection
            ]
        ] = None,
        name: typing___Optional[typing___Text] = None,
        system_managed_resource_source: typing___Optional[
            google___ads___googleads___v6___enums___system_managed_entity_source_pb2___SystemManagedResourceSourceEnum.SystemManagedResourceSourceValue
        ] = None,
        text_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___TextAdInfo
        ] = None,
        expanded_text_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedTextAdInfo
        ] = None,
        call_only_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___CallOnlyAdInfo
        ] = None,
        expanded_dynamic_search_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ExpandedDynamicSearchAdInfo
        ] = None,
        hotel_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___HotelAdInfo
        ] = None,
        shopping_smart_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingSmartAdInfo
        ] = None,
        shopping_product_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingProductAdInfo
        ] = None,
        gmail_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___GmailAdInfo
        ] = None,
        image_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ImageAdInfo
        ] = None,
        video_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___VideoAdInfo
        ] = None,
        video_responsive_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___VideoResponsiveAdInfo
        ] = None,
        responsive_search_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveSearchAdInfo
        ] = None,
        legacy_responsive_display_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyResponsiveDisplayAdInfo
        ] = None,
        app_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___AppAdInfo
        ] = None,
        legacy_app_install_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LegacyAppInstallAdInfo
        ] = None,
        responsive_display_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ResponsiveDisplayAdInfo
        ] = None,
        local_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___LocalAdInfo
        ] = None,
        display_upload_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___DisplayUploadAdInfo
        ] = None,
        app_engagement_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___AppEngagementAdInfo
        ] = None,
        shopping_comparison_listing_ad: typing___Optional[
            google___ads___googleads___v6___common___ad_type_infos_pb2___ShoppingComparisonListingAdInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_added_by_google_ads",
            b"_added_by_google_ads",
            "_display_url",
            b"_display_url",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_url_suffix",
            b"final_url_suffix",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "video_ad",
            b"video_ad",
            "video_responsive_ad",
            b"video_responsive_ad",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_added_by_google_ads",
            b"_added_by_google_ads",
            "_display_url",
            b"_display_url",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "device_preference",
            b"device_preference",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_app_urls",
            b"final_app_urls",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "system_managed_resource_source",
            b"system_managed_resource_source",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_collections",
            b"url_collections",
            "url_custom_parameters",
            b"url_custom_parameters",
            "video_ad",
            b"video_ad",
            "video_responsive_ad",
            b"video_responsive_ad",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_added_by_google_ads", b"_added_by_google_ads"
        ],
    ) -> typing_extensions___Literal["added_by_google_ads"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_display_url", b"_display_url"]
    ) -> typing_extensions___Literal["display_url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions___Literal["final_url_suffix"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["ad_data", b"ad_data"]
    ) -> typing_extensions___Literal[
        "text_ad",
        "expanded_text_ad",
        "call_only_ad",
        "expanded_dynamic_search_ad",
        "hotel_ad",
        "shopping_smart_ad",
        "shopping_product_ad",
        "gmail_ad",
        "image_ad",
        "video_ad",
        "video_responsive_ad",
        "responsive_search_ad",
        "legacy_responsive_display_ad",
        "app_ad",
        "legacy_app_install_ad",
        "responsive_display_ad",
        "local_ad",
        "display_upload_ad",
        "app_engagement_ad",
        "shopping_comparison_listing_ad",
    ]: ...

type___Ad = Ad
