# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanErrorValue = typing___NewType("KeywordPlanErrorValue", builtin___int)
    type___KeywordPlanErrorValue = KeywordPlanErrorValue
    KeywordPlanError: _KeywordPlanError
    class _KeywordPlanError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanErrorEnum.KeywordPlanErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 0)
        UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 1)
        BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 2
        )
        BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 3)
        BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 4)
        BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 5
        )
        DAILY_BUDGET_TOO_LOW = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 6
        )
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 7
        )
        INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 8)
        KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 9
        )
        KEYWORD_PLAN_NOT_ENABLED = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 10
        )
        KEYWORD_PLAN_NOT_FOUND = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 11
        )
        MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 13)
        MISSING_FORECAST_PERIOD = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 14
        )
        INVALID_FORECAST_DATE_RANGE = typing___cast(
            KeywordPlanErrorEnum.KeywordPlanErrorValue, 15
        )
        INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 16)
    UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 0)
    UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 1)
    BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 2
    )
    BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 3)
    BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 4)
    BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 5
    )
    DAILY_BUDGET_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 6)
    DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 7
    )
    INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 8)
    KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 9
    )
    KEYWORD_PLAN_NOT_ENABLED = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 10
    )
    KEYWORD_PLAN_NOT_FOUND = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 11
    )
    MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 13)
    MISSING_FORECAST_PERIOD = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 14
    )
    INVALID_FORECAST_DATE_RANGE = typing___cast(
        KeywordPlanErrorEnum.KeywordPlanErrorValue, 15
    )
    INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanErrorValue, 16)
    type___KeywordPlanError = KeywordPlanError
    def __init__(self,) -> None: ...

type___KeywordPlanErrorEnum = KeywordPlanErrorEnum
