# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEvidenceDestinationMismatchUrlTypeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEvidenceDestinationMismatchUrlTypeValue = typing___NewType(
        "PolicyTopicEvidenceDestinationMismatchUrlTypeValue", builtin___int
    )
    type___PolicyTopicEvidenceDestinationMismatchUrlTypeValue = (
        PolicyTopicEvidenceDestinationMismatchUrlTypeValue
    )
    PolicyTopicEvidenceDestinationMismatchUrlType: _PolicyTopicEvidenceDestinationMismatchUrlType
    class _PolicyTopicEvidenceDestinationMismatchUrlType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            1,
        )
        DISPLAY_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            2,
        )
        FINAL_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            3,
        )
        FINAL_MOBILE_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            4,
        )
        TRACKING_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            5,
        )
        MOBILE_TRACKING_URL = typing___cast(
            PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
            6,
        )
    UNSPECIFIED = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        1,
    )
    DISPLAY_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        2,
    )
    FINAL_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        3,
    )
    FINAL_MOBILE_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        4,
    )
    TRACKING_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        5,
    )
    MOBILE_TRACKING_URL = typing___cast(
        PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlTypeValue,
        6,
    )
    type___PolicyTopicEvidenceDestinationMismatchUrlType = (
        PolicyTopicEvidenceDestinationMismatchUrlType
    )
    def __init__(self,) -> None: ...

type___PolicyTopicEvidenceDestinationMismatchUrlTypeEnum = (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
)
