# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RecommendationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    RecommendationErrorValue = typing___NewType(
        "RecommendationErrorValue", builtin___int
    )
    type___RecommendationErrorValue = RecommendationErrorValue
    RecommendationError: _RecommendationError
    class _RecommendationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            RecommendationErrorEnum.RecommendationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 0)
        UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 1)
        BUDGET_AMOUNT_TOO_SMALL = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 2
        )
        BUDGET_AMOUNT_TOO_LARGE = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 3
        )
        INVALID_BUDGET_AMOUNT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 4
        )
        POLICY_ERROR = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 5
        )
        INVALID_BID_AMOUNT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 6
        )
        ADGROUP_KEYWORD_LIMIT = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 7
        )
        RECOMMENDATION_ALREADY_APPLIED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 8
        )
        RECOMMENDATION_INVALIDATED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 9
        )
        TOO_MANY_OPERATIONS = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 10
        )
        NO_OPERATIONS = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 11
        )
        DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 12
        )
        DUPLICATE_RESOURCE_NAME = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 13
        )
        RECOMMENDATION_ALREADY_DISMISSED = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 14
        )
        INVALID_APPLY_REQUEST = typing___cast(
            RecommendationErrorEnum.RecommendationErrorValue, 15
        )
    UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 0)
    UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 1)
    BUDGET_AMOUNT_TOO_SMALL = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 2
    )
    BUDGET_AMOUNT_TOO_LARGE = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 3
    )
    INVALID_BUDGET_AMOUNT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 4
    )
    POLICY_ERROR = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 5)
    INVALID_BID_AMOUNT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 6
    )
    ADGROUP_KEYWORD_LIMIT = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 7
    )
    RECOMMENDATION_ALREADY_APPLIED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 8
    )
    RECOMMENDATION_INVALIDATED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 9
    )
    TOO_MANY_OPERATIONS = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 10
    )
    NO_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationErrorValue, 11)
    DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 12
    )
    DUPLICATE_RESOURCE_NAME = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 13
    )
    RECOMMENDATION_ALREADY_DISMISSED = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 14
    )
    INVALID_APPLY_REQUEST = typing___cast(
        RecommendationErrorEnum.RecommendationErrorValue, 15
    )
    type___RecommendationError = RecommendationError
    def __init__(self,) -> None: ...

type___RecommendationErrorEnum = RecommendationErrorEnum
