# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCampaignErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanCampaignErrorValue = typing___NewType(
        "KeywordPlanCampaignErrorValue", builtin___int
    )
    type___KeywordPlanCampaignErrorValue = KeywordPlanCampaignErrorValue
    KeywordPlanCampaignError: _KeywordPlanCampaignError
    class _KeywordPlanCampaignError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 0
        )
        UNKNOWN = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 1
        )
        INVALID_NAME = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 2
        )
        INVALID_LANGUAGES = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 3
        )
        INVALID_GEOS = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 4
        )
        DUPLICATE_NAME = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 5
        )
        MAX_GEOS_EXCEEDED = typing___cast(
            KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 6
        )
    UNSPECIFIED = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 0
    )
    UNKNOWN = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 1
    )
    INVALID_NAME = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 2
    )
    INVALID_LANGUAGES = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 3
    )
    INVALID_GEOS = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 4
    )
    DUPLICATE_NAME = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 5
    )
    MAX_GEOS_EXCEEDED = typing___cast(
        KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorValue, 6
    )
    type___KeywordPlanCampaignError = KeywordPlanCampaignError
    def __init__(self,) -> None: ...

type___KeywordPlanCampaignErrorEnum = KeywordPlanCampaignErrorEnum
