# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperimentStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignExperimentStatusValue = typing___NewType(
        "CampaignExperimentStatusValue", builtin___int
    )
    type___CampaignExperimentStatusValue = CampaignExperimentStatusValue
    CampaignExperimentStatus: _CampaignExperimentStatus
    class _CampaignExperimentStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 1
        )
        INITIALIZING = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 2
        )
        INITIALIZATION_FAILED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 8
        )
        ENABLED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 3
        )
        GRADUATED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 4
        )
        REMOVED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 5
        )
        PROMOTING = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 6
        )
        PROMOTION_FAILED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 9
        )
        PROMOTED = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 7
        )
        ENDED_MANUALLY = typing___cast(
            CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 10
        )
    UNSPECIFIED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 0
    )
    UNKNOWN = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 1
    )
    INITIALIZING = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 2
    )
    INITIALIZATION_FAILED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 8
    )
    ENABLED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 3
    )
    GRADUATED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 4
    )
    REMOVED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 5
    )
    PROMOTING = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 6
    )
    PROMOTION_FAILED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 9
    )
    PROMOTED = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 7
    )
    ENDED_MANUALLY = typing___cast(
        CampaignExperimentStatusEnum.CampaignExperimentStatusValue, 10
    )
    type___CampaignExperimentStatus = CampaignExperimentStatus
    def __init__(self,) -> None: ...

type___CampaignExperimentStatusEnum = CampaignExperimentStatusEnum
