# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DateRangeErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DateRangeErrorValue = typing___NewType("DateRangeErrorValue", builtin___int)
    type___DateRangeErrorValue = DateRangeErrorValue
    DateRangeError: _DateRangeError
    class _DateRangeError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DateRangeErrorEnum.DateRangeErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 0)
        UNKNOWN = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 1)
        INVALID_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 2)
        START_DATE_AFTER_END_DATE = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 3
        )
        CANNOT_SET_DATE_TO_PAST = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 4
        )
        AFTER_MAXIMUM_ALLOWABLE_DATE = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 5
        )
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
            DateRangeErrorEnum.DateRangeErrorValue, 6
        )
    UNSPECIFIED = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 0)
    UNKNOWN = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 1)
    INVALID_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 2)
    START_DATE_AFTER_END_DATE = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 3)
    CANNOT_SET_DATE_TO_PAST = typing___cast(DateRangeErrorEnum.DateRangeErrorValue, 4)
    AFTER_MAXIMUM_ALLOWABLE_DATE = typing___cast(
        DateRangeErrorEnum.DateRangeErrorValue, 5
    )
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(
        DateRangeErrorEnum.DateRangeErrorValue, 6
    )
    type___DateRangeError = DateRangeError
    def __init__(self,) -> None: ...

type___DateRangeErrorEnum = DateRangeErrorEnum
