# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.distance_bucket_pb2 import (
    DistanceBucketEnum as google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DistanceView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    distance_bucket: google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum.DistanceBucketValue = ...
    metric_system: builtin___bool = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        distance_bucket: typing___Optional[
            google___ads___googleads___v5___enums___distance_bucket_pb2___DistanceBucketEnum.DistanceBucketValue
        ] = None,
        metric_system: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_metric_system", b"_metric_system", "metric_system", b"metric_system"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_metric_system",
            b"_metric_system",
            "distance_bucket",
            b"distance_bucket",
            "metric_system",
            b"metric_system",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_metric_system", b"_metric_system"],
    ) -> typing_extensions___Literal["metric_system"]: ...

type___DistanceView = DistanceView
