# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionTypeValue = typing___NewType("CriterionTypeValue", builtin___int)
    type___CriterionTypeValue = CriterionTypeValue
    CriterionType: _CriterionType
    class _CriterionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionTypeEnum.CriterionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionTypeValue, 0)
        UNKNOWN = typing___cast(CriterionTypeEnum.CriterionTypeValue, 1)
        KEYWORD = typing___cast(CriterionTypeEnum.CriterionTypeValue, 2)
        PLACEMENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 3)
        MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 4)
        MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 5)
        DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 6)
        LOCATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 7)
        LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 8)
        AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 9)
        AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 10)
        GENDER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 11)
        INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 12)
        PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionTypeValue, 13)
        YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionTypeValue, 14)
        YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 15)
        USER_LIST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 16)
        PROXIMITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 17)
        TOPIC = typing___cast(CriterionTypeEnum.CriterionTypeValue, 18)
        LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 19)
        LANGUAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 20)
        IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionTypeValue, 21)
        CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 22)
        CARRIER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 23)
        USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 24)
        WEBPAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 25)
        OPERATING_SYSTEM_VERSION = typing___cast(
            CriterionTypeEnum.CriterionTypeValue, 26
        )
        APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 27)
        MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 28)
        CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 29)
        CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 30)
        LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 31)
    UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionTypeValue, 0)
    UNKNOWN = typing___cast(CriterionTypeEnum.CriterionTypeValue, 1)
    KEYWORD = typing___cast(CriterionTypeEnum.CriterionTypeValue, 2)
    PLACEMENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 3)
    MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 4)
    MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 5)
    DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 6)
    LOCATION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 7)
    LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 8)
    AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 9)
    AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 10)
    GENDER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 11)
    INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 12)
    PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionTypeValue, 13)
    YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionTypeValue, 14)
    YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 15)
    USER_LIST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 16)
    PROXIMITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 17)
    TOPIC = typing___cast(CriterionTypeEnum.CriterionTypeValue, 18)
    LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 19)
    LANGUAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 20)
    IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionTypeValue, 21)
    CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 22)
    CARRIER = typing___cast(CriterionTypeEnum.CriterionTypeValue, 23)
    USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionTypeValue, 24)
    WEBPAGE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 25)
    OPERATING_SYSTEM_VERSION = typing___cast(CriterionTypeEnum.CriterionTypeValue, 26)
    APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionTypeValue, 27)
    MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionTypeValue, 28)
    CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionTypeValue, 29)
    CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionTypeValue, 30)
    LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionTypeValue, 31)
    type___CriterionType = CriterionType
    def __init__(self,) -> None: ...

type___CriterionTypeEnum = CriterionTypeEnum
