# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class NotAllowlistedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    NotAllowlistedErrorValue = typing___NewType(
        "NotAllowlistedErrorValue", builtin___int
    )
    type___NotAllowlistedErrorValue = NotAllowlistedErrorValue
    NotAllowlistedError: _NotAllowlistedError
    class _NotAllowlistedError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            NotAllowlistedErrorEnum.NotAllowlistedErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 0)
        UNKNOWN = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 1)
        CUSTOMER_NOT_ALLOWLISTED_FOR_THIS_FEATURE = typing___cast(
            NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 2
        )
    UNSPECIFIED = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 0)
    UNKNOWN = typing___cast(NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 1)
    CUSTOMER_NOT_ALLOWLISTED_FOR_THIS_FEATURE = typing___cast(
        NotAllowlistedErrorEnum.NotAllowlistedErrorValue, 2
    )
    type___NotAllowlistedError = NotAllowlistedError
    def __init__(self,) -> None: ...

type___NotAllowlistedErrorEnum = NotAllowlistedErrorEnum
