from typing import Any

class OfflineUserDataJobServiceStub:
    CreateOfflineUserDataJob: Any = ...
    GetOfflineUserDataJob: Any = ...
    AddOfflineUserDataJobOperations: Any = ...
    RunOfflineUserDataJob: Any = ...
    def __init__(self, channel: Any) -> None: ...

class OfflineUserDataJobServiceServicer:
    def CreateOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def GetOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def AddOfflineUserDataJobOperations(self, request: Any, context: Any) -> None: ...
    def RunOfflineUserDataJob(self, request: Any, context: Any) -> None: ...

def add_OfflineUserDataJobServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
