# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class NegativeGeoTargetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    NegativeGeoTargetTypeValue = typing___NewType(
        "NegativeGeoTargetTypeValue", builtin___int
    )
    type___NegativeGeoTargetTypeValue = NegativeGeoTargetTypeValue
    NegativeGeoTargetType: _NegativeGeoTargetType
    class _NegativeGeoTargetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 0
        )
        UNKNOWN = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 1)
        PRESENCE_OR_INTEREST = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 4
        )
        PRESENCE = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 5
        )
    UNSPECIFIED = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 0)
    UNKNOWN = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 1)
    PRESENCE_OR_INTEREST = typing___cast(
        NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 4
    )
    PRESENCE = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 5)
    type___NegativeGeoTargetType = NegativeGeoTargetType
    def __init__(self,) -> None: ...

type___NegativeGeoTargetTypeEnum = NegativeGeoTargetTypeEnum
