# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedErrorValue = typing___NewType("FeedErrorValue", builtin___int)
    type___FeedErrorValue = FeedErrorValue
    FeedError: _FeedError
    class _FeedError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedErrorEnum.FeedErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedErrorEnum.FeedErrorValue, 0)
        UNKNOWN = typing___cast(FeedErrorEnum.FeedErrorValue, 1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedErrorValue, 2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(
            FeedErrorEnum.FeedErrorValue, 3
        )
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 4
        )
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 5
        )
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 6
        )
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(
            FeedErrorEnum.FeedErrorValue, 7
        )
        FEED_REMOVED = typing___cast(FeedErrorEnum.FeedErrorValue, 8)
        INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedErrorValue, 9)
        FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedErrorValue, 10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 11)
        INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 12)
        DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 13)
        INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 14)
        MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedErrorValue, 15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(
            FeedErrorEnum.FeedErrorValue, 16
        )
        TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedErrorValue, 17)
        INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedErrorValue, 18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(
            FeedErrorEnum.FeedErrorValue, 19
        )
        INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedErrorValue, 20)
        DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedErrorValue, 21)
        GMB_ACCESS_ERROR = typing___cast(FeedErrorEnum.FeedErrorValue, 22)
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = typing___cast(
            FeedErrorEnum.FeedErrorValue, 23
        )
    UNSPECIFIED = typing___cast(FeedErrorEnum.FeedErrorValue, 0)
    UNKNOWN = typing___cast(FeedErrorEnum.FeedErrorValue, 1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedErrorValue, 2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(
        FeedErrorEnum.FeedErrorValue, 3
    )
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 4
    )
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 5
    )
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 6
    )
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(
        FeedErrorEnum.FeedErrorValue, 7
    )
    FEED_REMOVED = typing___cast(FeedErrorEnum.FeedErrorValue, 8)
    INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedErrorValue, 9)
    FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedErrorValue, 10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 11)
    INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 12)
    DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 13)
    INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 14)
    MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedErrorValue, 15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(
        FeedErrorEnum.FeedErrorValue, 16
    )
    TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedErrorValue, 17)
    INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedErrorValue, 18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(
        FeedErrorEnum.FeedErrorValue, 19
    )
    INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedErrorValue, 20)
    DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedErrorValue, 21)
    GMB_ACCESS_ERROR = typing___cast(FeedErrorEnum.FeedErrorValue, 22)
    CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = typing___cast(
        FeedErrorEnum.FeedErrorValue, 23
    )
    type___FeedError = FeedError
    def __init__(self,) -> None: ...

type___FeedErrorEnum = FeedErrorEnum
