# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DeviceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DeviceValue = typing___NewType("DeviceValue", builtin___int)
    type___DeviceValue = DeviceValue
    Device: _Device
    class _Device(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DeviceEnum.DeviceValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DeviceEnum.DeviceValue, 0)
        UNKNOWN = typing___cast(DeviceEnum.DeviceValue, 1)
        MOBILE = typing___cast(DeviceEnum.DeviceValue, 2)
        TABLET = typing___cast(DeviceEnum.DeviceValue, 3)
        DESKTOP = typing___cast(DeviceEnum.DeviceValue, 4)
        CONNECTED_TV = typing___cast(DeviceEnum.DeviceValue, 6)
        OTHER = typing___cast(DeviceEnum.DeviceValue, 5)
    UNSPECIFIED = typing___cast(DeviceEnum.DeviceValue, 0)
    UNKNOWN = typing___cast(DeviceEnum.DeviceValue, 1)
    MOBILE = typing___cast(DeviceEnum.DeviceValue, 2)
    TABLET = typing___cast(DeviceEnum.DeviceValue, 3)
    DESKTOP = typing___cast(DeviceEnum.DeviceValue, 4)
    CONNECTED_TV = typing___cast(DeviceEnum.DeviceValue, 6)
    OTHER = typing___cast(DeviceEnum.DeviceValue, 5)
    type___Device = Device
    def __init__(self,) -> None: ...

type___DeviceEnum = DeviceEnum
