from typing import Any

class CustomerManagerLinkServiceStub:
    GetCustomerManagerLink: Any = ...
    MutateCustomerManagerLink: Any = ...
    MoveManagerLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerManagerLinkServiceServicer:
    def GetCustomerManagerLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerManagerLink(self, request: Any, context: Any) -> None: ...
    def MoveManagerLink(self, request: Any, context: Any) -> None: ...

def add_CustomerManagerLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
