# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.manager_link_status_pb2 import (
    ManagerLinkStatusEnum as google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerManagerLink(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    manager_customer: typing___Text = ...
    manager_link_id: builtin___int = ...
    status: google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        manager_customer: typing___Optional[typing___Text] = None,
        manager_link_id: typing___Optional[builtin___int] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_manager_customer",
            b"_manager_customer",
            "_manager_link_id",
            b"_manager_link_id",
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_manager_customer",
            b"_manager_customer",
            "_manager_link_id",
            b"_manager_link_id",
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_manager_customer", b"_manager_customer"
        ],
    ) -> typing_extensions___Literal["manager_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_manager_link_id", b"_manager_link_id"
        ],
    ) -> typing_extensions___Literal["manager_link_id"]: ...

type___CustomerManagerLink = CustomerManagerLink
