# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class JobPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    JobPlaceholderFieldValue = typing___NewType(
        "JobPlaceholderFieldValue", builtin___int
    )
    type___JobPlaceholderFieldValue = JobPlaceholderFieldValue
    JobPlaceholderField: _JobPlaceholderField
    class _JobPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 0)
        UNKNOWN = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 1)
        JOB_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 2)
        LOCATION_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 3)
        TITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 4)
        SUBTITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 5)
        DESCRIPTION = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 6)
        IMAGE_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 7)
        CATEGORY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 8)
        CONTEXTUAL_KEYWORDS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 9
        )
        ADDRESS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 10)
        SALARY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 11)
        FINAL_URLS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 12)
        FINAL_MOBILE_URLS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 14
        )
        TRACKING_URL = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 15
        )
        ANDROID_APP_LINK = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 16
        )
        SIMILAR_JOB_IDS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 17
        )
        IOS_APP_LINK = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 18
        )
        IOS_APP_STORE_ID = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 19
        )
    UNSPECIFIED = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 1)
    JOB_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 2)
    LOCATION_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 3)
    TITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 4)
    SUBTITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 5)
    DESCRIPTION = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 6)
    IMAGE_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 7)
    CATEGORY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 8)
    CONTEXTUAL_KEYWORDS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 9
    )
    ADDRESS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 10)
    SALARY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 11)
    FINAL_URLS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 12)
    FINAL_MOBILE_URLS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 14
    )
    TRACKING_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 15)
    ANDROID_APP_LINK = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 16
    )
    SIMILAR_JOB_IDS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 17
    )
    IOS_APP_LINK = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 18)
    IOS_APP_STORE_ID = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 19
    )
    type___JobPlaceholderField = JobPlaceholderField
    def __init__(self,) -> None: ...

type___JobPlaceholderFieldEnum = JobPlaceholderFieldEnum
