# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.campaign_experiment_status_pb2 import (
    CampaignExperimentStatusEnum as google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.campaign_experiment_traffic_split_type_pb2 import (
    CampaignExperimentTrafficSplitTypeEnum as google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperiment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    campaign_draft: typing___Text = ...
    name: typing___Text = ...
    description: typing___Text = ...
    traffic_split_percent: builtin___int = ...
    traffic_split_type: google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue = ...
    experiment_campaign: typing___Text = ...
    status: google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue = ...
    long_running_operation: typing___Text = ...
    start_date: typing___Text = ...
    end_date: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        campaign_draft: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        traffic_split_percent: typing___Optional[builtin___int] = None,
        traffic_split_type: typing___Optional[
            google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue
        ] = None,
        experiment_campaign: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue
        ] = None,
        long_running_operation: typing___Optional[typing___Text] = None,
        start_date: typing___Optional[typing___Text] = None,
        end_date: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_draft",
            b"_campaign_draft",
            "_description",
            b"_description",
            "_end_date",
            b"_end_date",
            "_experiment_campaign",
            b"_experiment_campaign",
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "_start_date",
            b"_start_date",
            "_traffic_split_percent",
            b"_traffic_split_percent",
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "start_date",
            b"start_date",
            "traffic_split_percent",
            b"traffic_split_percent",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_draft",
            b"_campaign_draft",
            "_description",
            b"_description",
            "_end_date",
            b"_end_date",
            "_experiment_campaign",
            b"_experiment_campaign",
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "_start_date",
            b"_start_date",
            "_traffic_split_percent",
            b"_traffic_split_percent",
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "traffic_split_percent",
            b"traffic_split_percent",
            "traffic_split_type",
            b"traffic_split_type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_campaign_draft", b"_campaign_draft"],
    ) -> typing_extensions___Literal["campaign_draft"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_end_date", b"_end_date"]
    ) -> typing_extensions___Literal["end_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_experiment_campaign", b"_experiment_campaign"
        ],
    ) -> typing_extensions___Literal["experiment_campaign"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions___Literal["long_running_operation"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_traffic_split_percent", b"_traffic_split_percent"
        ],
    ) -> typing_extensions___Literal["traffic_split_percent"]: ...

type___CampaignExperiment = CampaignExperiment
