# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionFeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExtensionFeedItemErrorValue = typing___NewType(
        "ExtensionFeedItemErrorValue", builtin___int
    )
    type___ExtensionFeedItemErrorValue = ExtensionFeedItemErrorValue
    ExtensionFeedItemError: _ExtensionFeedItemError
    class _ExtensionFeedItemError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 1
        )
        VALUE_OUT_OF_RANGE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 2
        )
        URL_LIST_TOO_LONG = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 3
        )
        CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 4
        )
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 5
        )
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 6
        )
        INVALID_PHONE_NUMBER = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 7
        )
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 8
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 9
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 10
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 11
        )
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 12
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 13
        )
        INVALID_CALL_CONVERSION_ACTION = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 14
        )
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 47
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 16
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 17
        )
        INVALID_APP_ID = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 18
        )
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 19
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 20
        )
        REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 21
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 22
        )
        INCONSISTENT_CURRENCY_CODES = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 23
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 24
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 25
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 26
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 27
        )
        UNSUPPORTED_VALUE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 28
        )
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 29
        )
        INVALID_DEVICE_PREFERENCE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 30
        )
        INVALID_SCHEDULE_END = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 31
        )
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 32
        )
        INVALID_SNIPPETS_HEADER = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 33
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 34
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 35
        )
        CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 36
        )
        EXTENSION_TYPE_MISMATCH = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 37
        )
        EXTENSION_SUBTYPE_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 38
        )
        EXTENSION_TYPE_UNSUPPORTED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 39
        )
        CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 40
        )
        CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 41
        )
        INVALID_PRICE_FORMAT = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 42
        )
        PROMOTION_INVALID_TIME = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 43
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 44
        )
        CONCRETE_EXTENSION_TYPE_REQUIRED = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 45
        )
        SCHEDULE_END_NOT_AFTER_START = typing___cast(
            ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 46
        )
    UNSPECIFIED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 0
    )
    UNKNOWN = typing___cast(ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 1)
    VALUE_OUT_OF_RANGE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 2
    )
    URL_LIST_TOO_LONG = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 3
    )
    CANNOT_HAVE_RESTRICTION_ON_EMPTY_GEO_TARGETING = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 4
    )
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 5
    )
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 6
    )
    INVALID_PHONE_NUMBER = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 7
    )
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 8
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 9
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 10
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 11
    )
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 12
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 13
    )
    INVALID_CALL_CONVERSION_ACTION = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 14
    )
    CUSTOMER_NOT_ON_ALLOWLIST_FOR_CALLTRACKING = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 47
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 16
    )
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 17
    )
    INVALID_APP_ID = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 18
    )
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 19
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 20
    )
    REVIEW_EXTENSION_SOURCE_INELIGIBLE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 21
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 22
    )
    INCONSISTENT_CURRENCY_CODES = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 23
    )
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 24
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 25
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 26
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 27
    )
    UNSUPPORTED_VALUE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 28
    )
    UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 29
    )
    INVALID_DEVICE_PREFERENCE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 30
    )
    INVALID_SCHEDULE_END = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 31
    )
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 32
    )
    INVALID_SNIPPETS_HEADER = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 33
    )
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 34
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 35
    )
    CONFLICTING_CALL_CONVERSION_SETTINGS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 36
    )
    EXTENSION_TYPE_MISMATCH = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 37
    )
    EXTENSION_SUBTYPE_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 38
    )
    EXTENSION_TYPE_UNSUPPORTED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 39
    )
    CANNOT_OPERATE_ON_FEED_WITH_MULTIPLE_MAPPINGS = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 40
    )
    CANNOT_OPERATE_ON_FEED_WITH_KEY_ATTRIBUTES = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 41
    )
    INVALID_PRICE_FORMAT = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 42
    )
    PROMOTION_INVALID_TIME = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 43
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 44
    )
    CONCRETE_EXTENSION_TYPE_REQUIRED = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 45
    )
    SCHEDULE_END_NOT_AFTER_START = typing___cast(
        ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorValue, 46
    )
    type___ExtensionFeedItemError = ExtensionFeedItemError
    def __init__(self,) -> None: ...

type___ExtensionFeedItemErrorEnum = ExtensionFeedItemErrorEnum
