# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ManagerLinkStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ManagerLinkStatusValue = typing___NewType("ManagerLinkStatusValue", builtin___int)
    type___ManagerLinkStatusValue = ManagerLinkStatusValue
    ManagerLinkStatus: _ManagerLinkStatus
    class _ManagerLinkStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ManagerLinkStatusEnum.ManagerLinkStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 0)
        UNKNOWN = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 1)
        ACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 2)
        INACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 3)
        PENDING = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 4)
        REFUSED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 5)
        CANCELED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 6)
    UNSPECIFIED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 0)
    UNKNOWN = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 1)
    ACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 2)
    INACTIVE = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 3)
    PENDING = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 4)
    REFUSED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 5)
    CANCELED = typing___cast(ManagerLinkStatusEnum.ManagerLinkStatusValue, 6)
    type___ManagerLinkStatus = ManagerLinkStatus
    def __init__(self,) -> None: ...

type___ManagerLinkStatusEnum = ManagerLinkStatusEnum
