# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MimeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MimeTypeValue = typing___NewType("MimeTypeValue", builtin___int)
    type___MimeTypeValue = MimeTypeValue
    MimeType: _MimeType
    class _MimeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MimeTypeEnum.MimeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MimeTypeEnum.MimeTypeValue, 0)
        UNKNOWN = typing___cast(MimeTypeEnum.MimeTypeValue, 1)
        IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeTypeValue, 2)
        IMAGE_GIF = typing___cast(MimeTypeEnum.MimeTypeValue, 3)
        IMAGE_PNG = typing___cast(MimeTypeEnum.MimeTypeValue, 4)
        FLASH = typing___cast(MimeTypeEnum.MimeTypeValue, 5)
        TEXT_HTML = typing___cast(MimeTypeEnum.MimeTypeValue, 6)
        PDF = typing___cast(MimeTypeEnum.MimeTypeValue, 7)
        MSWORD = typing___cast(MimeTypeEnum.MimeTypeValue, 8)
        MSEXCEL = typing___cast(MimeTypeEnum.MimeTypeValue, 9)
        RTF = typing___cast(MimeTypeEnum.MimeTypeValue, 10)
        AUDIO_WAV = typing___cast(MimeTypeEnum.MimeTypeValue, 11)
        AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeTypeValue, 12)
        HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeTypeValue, 13)
    UNSPECIFIED = typing___cast(MimeTypeEnum.MimeTypeValue, 0)
    UNKNOWN = typing___cast(MimeTypeEnum.MimeTypeValue, 1)
    IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeTypeValue, 2)
    IMAGE_GIF = typing___cast(MimeTypeEnum.MimeTypeValue, 3)
    IMAGE_PNG = typing___cast(MimeTypeEnum.MimeTypeValue, 4)
    FLASH = typing___cast(MimeTypeEnum.MimeTypeValue, 5)
    TEXT_HTML = typing___cast(MimeTypeEnum.MimeTypeValue, 6)
    PDF = typing___cast(MimeTypeEnum.MimeTypeValue, 7)
    MSWORD = typing___cast(MimeTypeEnum.MimeTypeValue, 8)
    MSEXCEL = typing___cast(MimeTypeEnum.MimeTypeValue, 9)
    RTF = typing___cast(MimeTypeEnum.MimeTypeValue, 10)
    AUDIO_WAV = typing___cast(MimeTypeEnum.MimeTypeValue, 11)
    AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeTypeValue, 12)
    HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeTypeValue, 13)
    type___MimeType = MimeType
    def __init__(self,) -> None: ...

type___MimeTypeEnum = MimeTypeEnum
