from typing import Any

class InvoiceServiceStub:
    ListInvoices: Any = ...
    def __init__(self, channel: Any) -> None: ...

class InvoiceServiceServicer:
    def ListInvoices(self, request: Any, context: Any) -> None: ...

def add_InvoiceServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
