# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.interaction_event_type_pb2 import (
    InteractionEventTypeEnum as google___ads___googleads___v5___enums___interaction_event_type_pb2___InteractionEventTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.quality_score_bucket_pb2 import (
    QualityScoreBucketEnum as google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Metrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    absolute_top_impression_percentage: builtin___float = ...
    active_view_cpm: builtin___float = ...
    active_view_ctr: builtin___float = ...
    active_view_impressions: builtin___int = ...
    active_view_measurability: builtin___float = ...
    active_view_measurable_cost_micros: builtin___int = ...
    active_view_measurable_impressions: builtin___int = ...
    active_view_viewability: builtin___float = ...
    all_conversions_from_interactions_rate: builtin___float = ...
    all_conversions_value: builtin___float = ...
    all_conversions: builtin___float = ...
    all_conversions_value_per_cost: builtin___float = ...
    all_conversions_from_click_to_call: builtin___float = ...
    all_conversions_from_directions: builtin___float = ...
    all_conversions_from_interactions_value_per_interaction: builtin___float = ...
    all_conversions_from_menu: builtin___float = ...
    all_conversions_from_order: builtin___float = ...
    all_conversions_from_other_engagement: builtin___float = ...
    all_conversions_from_store_visit: builtin___float = ...
    all_conversions_from_store_website: builtin___float = ...
    average_cost: builtin___float = ...
    average_cpc: builtin___float = ...
    average_cpe: builtin___float = ...
    average_cpm: builtin___float = ...
    average_cpv: builtin___float = ...
    average_page_views: builtin___float = ...
    average_time_on_site: builtin___float = ...
    benchmark_average_max_cpc: builtin___float = ...
    benchmark_ctr: builtin___float = ...
    bounce_rate: builtin___float = ...
    clicks: builtin___int = ...
    combined_clicks: builtin___int = ...
    combined_clicks_per_query: builtin___float = ...
    combined_queries: builtin___int = ...
    content_budget_lost_impression_share: builtin___float = ...
    content_impression_share: builtin___float = ...
    conversion_last_received_request_date_time: typing___Text = ...
    conversion_last_conversion_date: typing___Text = ...
    content_rank_lost_impression_share: builtin___float = ...
    conversions_from_interactions_rate: builtin___float = ...
    conversions_value: builtin___float = ...
    conversions_value_per_cost: builtin___float = ...
    conversions_from_interactions_value_per_interaction: builtin___float = ...
    conversions: builtin___float = ...
    cost_micros: builtin___int = ...
    cost_per_all_conversions: builtin___float = ...
    cost_per_conversion: builtin___float = ...
    cost_per_current_model_attributed_conversion: builtin___float = ...
    cross_device_conversions: builtin___float = ...
    ctr: builtin___float = ...
    current_model_attributed_conversions: builtin___float = ...
    current_model_attributed_conversions_from_interactions_rate: builtin___float = ...
    current_model_attributed_conversions_from_interactions_value_per_interaction: builtin___float = ...
    current_model_attributed_conversions_value: builtin___float = ...
    current_model_attributed_conversions_value_per_cost: builtin___float = ...
    engagement_rate: builtin___float = ...
    engagements: builtin___int = ...
    hotel_average_lead_value_micros: builtin___float = ...
    hotel_price_difference_percentage: builtin___float = ...
    hotel_eligible_impressions: builtin___int = ...
    historical_creative_quality_score: google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
    historical_landing_page_quality_score: google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
    historical_quality_score: builtin___int = ...
    historical_search_predicted_ctr: google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue = ...
    gmail_forwards: builtin___int = ...
    gmail_saves: builtin___int = ...
    gmail_secondary_clicks: builtin___int = ...
    impressions_from_store_reach: builtin___int = ...
    impressions: builtin___int = ...
    interaction_rate: builtin___float = ...
    interactions: builtin___int = ...
    interaction_event_types: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v5___enums___interaction_event_type_pb2___InteractionEventTypeEnum.InteractionEventTypeValue
    ] = ...
    invalid_click_rate: builtin___float = ...
    invalid_clicks: builtin___int = ...
    message_chats: builtin___int = ...
    message_impressions: builtin___int = ...
    message_chat_rate: builtin___float = ...
    mobile_friendly_clicks_percentage: builtin___float = ...
    organic_clicks: builtin___int = ...
    organic_clicks_per_query: builtin___float = ...
    organic_impressions: builtin___int = ...
    organic_impressions_per_query: builtin___float = ...
    organic_queries: builtin___int = ...
    percent_new_visitors: builtin___float = ...
    phone_calls: builtin___int = ...
    phone_impressions: builtin___int = ...
    phone_through_rate: builtin___float = ...
    relative_ctr: builtin___float = ...
    search_absolute_top_impression_share: builtin___float = ...
    search_budget_lost_absolute_top_impression_share: builtin___float = ...
    search_budget_lost_impression_share: builtin___float = ...
    search_budget_lost_top_impression_share: builtin___float = ...
    search_click_share: builtin___float = ...
    search_exact_match_impression_share: builtin___float = ...
    search_impression_share: builtin___float = ...
    search_rank_lost_absolute_top_impression_share: builtin___float = ...
    search_rank_lost_impression_share: builtin___float = ...
    search_rank_lost_top_impression_share: builtin___float = ...
    search_top_impression_share: builtin___float = ...
    speed_score: builtin___int = ...
    top_impression_percentage: builtin___float = ...
    valid_accelerated_mobile_pages_clicks_percentage: builtin___float = ...
    value_per_all_conversions: builtin___float = ...
    value_per_conversion: builtin___float = ...
    value_per_current_model_attributed_conversion: builtin___float = ...
    video_quartile_p100_rate: builtin___float = ...
    video_quartile_p25_rate: builtin___float = ...
    video_quartile_p50_rate: builtin___float = ...
    video_quartile_p75_rate: builtin___float = ...
    video_view_rate: builtin___float = ...
    video_views: builtin___int = ...
    view_through_conversions: builtin___int = ...
    def __init__(
        self,
        *,
        absolute_top_impression_percentage: typing___Optional[builtin___float] = None,
        active_view_cpm: typing___Optional[builtin___float] = None,
        active_view_ctr: typing___Optional[builtin___float] = None,
        active_view_impressions: typing___Optional[builtin___int] = None,
        active_view_measurability: typing___Optional[builtin___float] = None,
        active_view_measurable_cost_micros: typing___Optional[builtin___int] = None,
        active_view_measurable_impressions: typing___Optional[builtin___int] = None,
        active_view_viewability: typing___Optional[builtin___float] = None,
        all_conversions_from_interactions_rate: typing___Optional[
            builtin___float
        ] = None,
        all_conversions_value: typing___Optional[builtin___float] = None,
        all_conversions: typing___Optional[builtin___float] = None,
        all_conversions_value_per_cost: typing___Optional[builtin___float] = None,
        all_conversions_from_click_to_call: typing___Optional[builtin___float] = None,
        all_conversions_from_directions: typing___Optional[builtin___float] = None,
        all_conversions_from_interactions_value_per_interaction: typing___Optional[
            builtin___float
        ] = None,
        all_conversions_from_menu: typing___Optional[builtin___float] = None,
        all_conversions_from_order: typing___Optional[builtin___float] = None,
        all_conversions_from_other_engagement: typing___Optional[
            builtin___float
        ] = None,
        all_conversions_from_store_visit: typing___Optional[builtin___float] = None,
        all_conversions_from_store_website: typing___Optional[builtin___float] = None,
        average_cost: typing___Optional[builtin___float] = None,
        average_cpc: typing___Optional[builtin___float] = None,
        average_cpe: typing___Optional[builtin___float] = None,
        average_cpm: typing___Optional[builtin___float] = None,
        average_cpv: typing___Optional[builtin___float] = None,
        average_page_views: typing___Optional[builtin___float] = None,
        average_time_on_site: typing___Optional[builtin___float] = None,
        benchmark_average_max_cpc: typing___Optional[builtin___float] = None,
        benchmark_ctr: typing___Optional[builtin___float] = None,
        bounce_rate: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        combined_clicks: typing___Optional[builtin___int] = None,
        combined_clicks_per_query: typing___Optional[builtin___float] = None,
        combined_queries: typing___Optional[builtin___int] = None,
        content_budget_lost_impression_share: typing___Optional[builtin___float] = None,
        content_impression_share: typing___Optional[builtin___float] = None,
        conversion_last_received_request_date_time: typing___Optional[
            typing___Text
        ] = None,
        conversion_last_conversion_date: typing___Optional[typing___Text] = None,
        content_rank_lost_impression_share: typing___Optional[builtin___float] = None,
        conversions_from_interactions_rate: typing___Optional[builtin___float] = None,
        conversions_value: typing___Optional[builtin___float] = None,
        conversions_value_per_cost: typing___Optional[builtin___float] = None,
        conversions_from_interactions_value_per_interaction: typing___Optional[
            builtin___float
        ] = None,
        conversions: typing___Optional[builtin___float] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        cost_per_all_conversions: typing___Optional[builtin___float] = None,
        cost_per_conversion: typing___Optional[builtin___float] = None,
        cost_per_current_model_attributed_conversion: typing___Optional[
            builtin___float
        ] = None,
        cross_device_conversions: typing___Optional[builtin___float] = None,
        ctr: typing___Optional[builtin___float] = None,
        current_model_attributed_conversions: typing___Optional[builtin___float] = None,
        current_model_attributed_conversions_from_interactions_rate: typing___Optional[
            builtin___float
        ] = None,
        current_model_attributed_conversions_from_interactions_value_per_interaction: typing___Optional[
            builtin___float
        ] = None,
        current_model_attributed_conversions_value: typing___Optional[
            builtin___float
        ] = None,
        current_model_attributed_conversions_value_per_cost: typing___Optional[
            builtin___float
        ] = None,
        engagement_rate: typing___Optional[builtin___float] = None,
        engagements: typing___Optional[builtin___int] = None,
        hotel_average_lead_value_micros: typing___Optional[builtin___float] = None,
        hotel_price_difference_percentage: typing___Optional[builtin___float] = None,
        hotel_eligible_impressions: typing___Optional[builtin___int] = None,
        historical_creative_quality_score: typing___Optional[
            google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
        ] = None,
        historical_landing_page_quality_score: typing___Optional[
            google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
        ] = None,
        historical_quality_score: typing___Optional[builtin___int] = None,
        historical_search_predicted_ctr: typing___Optional[
            google___ads___googleads___v5___enums___quality_score_bucket_pb2___QualityScoreBucketEnum.QualityScoreBucketValue
        ] = None,
        gmail_forwards: typing___Optional[builtin___int] = None,
        gmail_saves: typing___Optional[builtin___int] = None,
        gmail_secondary_clicks: typing___Optional[builtin___int] = None,
        impressions_from_store_reach: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        interaction_rate: typing___Optional[builtin___float] = None,
        interactions: typing___Optional[builtin___int] = None,
        interaction_event_types: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___enums___interaction_event_type_pb2___InteractionEventTypeEnum.InteractionEventTypeValue
            ]
        ] = None,
        invalid_click_rate: typing___Optional[builtin___float] = None,
        invalid_clicks: typing___Optional[builtin___int] = None,
        message_chats: typing___Optional[builtin___int] = None,
        message_impressions: typing___Optional[builtin___int] = None,
        message_chat_rate: typing___Optional[builtin___float] = None,
        mobile_friendly_clicks_percentage: typing___Optional[builtin___float] = None,
        organic_clicks: typing___Optional[builtin___int] = None,
        organic_clicks_per_query: typing___Optional[builtin___float] = None,
        organic_impressions: typing___Optional[builtin___int] = None,
        organic_impressions_per_query: typing___Optional[builtin___float] = None,
        organic_queries: typing___Optional[builtin___int] = None,
        percent_new_visitors: typing___Optional[builtin___float] = None,
        phone_calls: typing___Optional[builtin___int] = None,
        phone_impressions: typing___Optional[builtin___int] = None,
        phone_through_rate: typing___Optional[builtin___float] = None,
        relative_ctr: typing___Optional[builtin___float] = None,
        search_absolute_top_impression_share: typing___Optional[builtin___float] = None,
        search_budget_lost_absolute_top_impression_share: typing___Optional[
            builtin___float
        ] = None,
        search_budget_lost_impression_share: typing___Optional[builtin___float] = None,
        search_budget_lost_top_impression_share: typing___Optional[
            builtin___float
        ] = None,
        search_click_share: typing___Optional[builtin___float] = None,
        search_exact_match_impression_share: typing___Optional[builtin___float] = None,
        search_impression_share: typing___Optional[builtin___float] = None,
        search_rank_lost_absolute_top_impression_share: typing___Optional[
            builtin___float
        ] = None,
        search_rank_lost_impression_share: typing___Optional[builtin___float] = None,
        search_rank_lost_top_impression_share: typing___Optional[
            builtin___float
        ] = None,
        search_top_impression_share: typing___Optional[builtin___float] = None,
        speed_score: typing___Optional[builtin___int] = None,
        top_impression_percentage: typing___Optional[builtin___float] = None,
        valid_accelerated_mobile_pages_clicks_percentage: typing___Optional[
            builtin___float
        ] = None,
        value_per_all_conversions: typing___Optional[builtin___float] = None,
        value_per_conversion: typing___Optional[builtin___float] = None,
        value_per_current_model_attributed_conversion: typing___Optional[
            builtin___float
        ] = None,
        video_quartile_p100_rate: typing___Optional[builtin___float] = None,
        video_quartile_p25_rate: typing___Optional[builtin___float] = None,
        video_quartile_p50_rate: typing___Optional[builtin___float] = None,
        video_quartile_p75_rate: typing___Optional[builtin___float] = None,
        video_view_rate: typing___Optional[builtin___float] = None,
        video_views: typing___Optional[builtin___int] = None,
        view_through_conversions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_quality_score",
            b"historical_quality_score",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
            "_active_view_cpm",
            b"_active_view_cpm",
            "_active_view_ctr",
            b"_active_view_ctr",
            "_active_view_impressions",
            b"_active_view_impressions",
            "_active_view_measurability",
            b"_active_view_measurability",
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
            "_active_view_viewability",
            b"_active_view_viewability",
            "_all_conversions",
            b"_all_conversions",
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
            "_all_conversions_from_directions",
            b"_all_conversions_from_directions",
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
            "_all_conversions_from_menu",
            b"_all_conversions_from_menu",
            "_all_conversions_from_order",
            b"_all_conversions_from_order",
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
            "_all_conversions_from_store_visit",
            b"_all_conversions_from_store_visit",
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
            "_all_conversions_value",
            b"_all_conversions_value",
            "_all_conversions_value_per_cost",
            b"_all_conversions_value_per_cost",
            "_average_cost",
            b"_average_cost",
            "_average_cpc",
            b"_average_cpc",
            "_average_cpe",
            b"_average_cpe",
            "_average_cpm",
            b"_average_cpm",
            "_average_cpv",
            b"_average_cpv",
            "_average_page_views",
            b"_average_page_views",
            "_average_time_on_site",
            b"_average_time_on_site",
            "_benchmark_average_max_cpc",
            b"_benchmark_average_max_cpc",
            "_benchmark_ctr",
            b"_benchmark_ctr",
            "_bounce_rate",
            b"_bounce_rate",
            "_clicks",
            b"_clicks",
            "_combined_clicks",
            b"_combined_clicks",
            "_combined_clicks_per_query",
            b"_combined_clicks_per_query",
            "_combined_queries",
            b"_combined_queries",
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
            "_content_impression_share",
            b"_content_impression_share",
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
            "_conversion_last_conversion_date",
            b"_conversion_last_conversion_date",
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
            "_conversions",
            b"_conversions",
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
            "_conversions_value",
            b"_conversions_value",
            "_conversions_value_per_cost",
            b"_conversions_value_per_cost",
            "_cost_micros",
            b"_cost_micros",
            "_cost_per_all_conversions",
            b"_cost_per_all_conversions",
            "_cost_per_conversion",
            b"_cost_per_conversion",
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
            "_cross_device_conversions",
            b"_cross_device_conversions",
            "_ctr",
            b"_ctr",
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
            "_engagement_rate",
            b"_engagement_rate",
            "_engagements",
            b"_engagements",
            "_gmail_forwards",
            b"_gmail_forwards",
            "_gmail_saves",
            b"_gmail_saves",
            "_gmail_secondary_clicks",
            b"_gmail_secondary_clicks",
            "_historical_quality_score",
            b"_historical_quality_score",
            "_hotel_average_lead_value_micros",
            b"_hotel_average_lead_value_micros",
            "_hotel_eligible_impressions",
            b"_hotel_eligible_impressions",
            "_hotel_price_difference_percentage",
            b"_hotel_price_difference_percentage",
            "_impressions",
            b"_impressions",
            "_impressions_from_store_reach",
            b"_impressions_from_store_reach",
            "_interaction_rate",
            b"_interaction_rate",
            "_interactions",
            b"_interactions",
            "_invalid_click_rate",
            b"_invalid_click_rate",
            "_invalid_clicks",
            b"_invalid_clicks",
            "_message_chat_rate",
            b"_message_chat_rate",
            "_message_chats",
            b"_message_chats",
            "_message_impressions",
            b"_message_impressions",
            "_mobile_friendly_clicks_percentage",
            b"_mobile_friendly_clicks_percentage",
            "_organic_clicks",
            b"_organic_clicks",
            "_organic_clicks_per_query",
            b"_organic_clicks_per_query",
            "_organic_impressions",
            b"_organic_impressions",
            "_organic_impressions_per_query",
            b"_organic_impressions_per_query",
            "_organic_queries",
            b"_organic_queries",
            "_percent_new_visitors",
            b"_percent_new_visitors",
            "_phone_calls",
            b"_phone_calls",
            "_phone_impressions",
            b"_phone_impressions",
            "_phone_through_rate",
            b"_phone_through_rate",
            "_relative_ctr",
            b"_relative_ctr",
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
            "_search_click_share",
            b"_search_click_share",
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
            "_search_impression_share",
            b"_search_impression_share",
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
            "_search_rank_lost_impression_share",
            b"_search_rank_lost_impression_share",
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
            "_search_top_impression_share",
            b"_search_top_impression_share",
            "_speed_score",
            b"_speed_score",
            "_top_impression_percentage",
            b"_top_impression_percentage",
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
            "_value_per_all_conversions",
            b"_value_per_all_conversions",
            "_value_per_conversion",
            b"_value_per_conversion",
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
            "_video_quartile_p100_rate",
            b"_video_quartile_p100_rate",
            "_video_quartile_p25_rate",
            b"_video_quartile_p25_rate",
            "_video_quartile_p50_rate",
            b"_video_quartile_p50_rate",
            "_video_quartile_p75_rate",
            b"_video_quartile_p75_rate",
            "_video_view_rate",
            b"_video_view_rate",
            "_video_views",
            b"_video_views",
            "_view_through_conversions",
            b"_view_through_conversions",
            "absolute_top_impression_percentage",
            b"absolute_top_impression_percentage",
            "active_view_cpm",
            b"active_view_cpm",
            "active_view_ctr",
            b"active_view_ctr",
            "active_view_impressions",
            b"active_view_impressions",
            "active_view_measurability",
            b"active_view_measurability",
            "active_view_measurable_cost_micros",
            b"active_view_measurable_cost_micros",
            "active_view_measurable_impressions",
            b"active_view_measurable_impressions",
            "active_view_viewability",
            b"active_view_viewability",
            "all_conversions",
            b"all_conversions",
            "all_conversions_from_click_to_call",
            b"all_conversions_from_click_to_call",
            "all_conversions_from_directions",
            b"all_conversions_from_directions",
            "all_conversions_from_interactions_rate",
            b"all_conversions_from_interactions_rate",
            "all_conversions_from_interactions_value_per_interaction",
            b"all_conversions_from_interactions_value_per_interaction",
            "all_conversions_from_menu",
            b"all_conversions_from_menu",
            "all_conversions_from_order",
            b"all_conversions_from_order",
            "all_conversions_from_other_engagement",
            b"all_conversions_from_other_engagement",
            "all_conversions_from_store_visit",
            b"all_conversions_from_store_visit",
            "all_conversions_from_store_website",
            b"all_conversions_from_store_website",
            "all_conversions_value",
            b"all_conversions_value",
            "all_conversions_value_per_cost",
            b"all_conversions_value_per_cost",
            "average_cost",
            b"average_cost",
            "average_cpc",
            b"average_cpc",
            "average_cpe",
            b"average_cpe",
            "average_cpm",
            b"average_cpm",
            "average_cpv",
            b"average_cpv",
            "average_page_views",
            b"average_page_views",
            "average_time_on_site",
            b"average_time_on_site",
            "benchmark_average_max_cpc",
            b"benchmark_average_max_cpc",
            "benchmark_ctr",
            b"benchmark_ctr",
            "bounce_rate",
            b"bounce_rate",
            "clicks",
            b"clicks",
            "combined_clicks",
            b"combined_clicks",
            "combined_clicks_per_query",
            b"combined_clicks_per_query",
            "combined_queries",
            b"combined_queries",
            "content_budget_lost_impression_share",
            b"content_budget_lost_impression_share",
            "content_impression_share",
            b"content_impression_share",
            "content_rank_lost_impression_share",
            b"content_rank_lost_impression_share",
            "conversion_last_conversion_date",
            b"conversion_last_conversion_date",
            "conversion_last_received_request_date_time",
            b"conversion_last_received_request_date_time",
            "conversions",
            b"conversions",
            "conversions_from_interactions_rate",
            b"conversions_from_interactions_rate",
            "conversions_from_interactions_value_per_interaction",
            b"conversions_from_interactions_value_per_interaction",
            "conversions_value",
            b"conversions_value",
            "conversions_value_per_cost",
            b"conversions_value_per_cost",
            "cost_micros",
            b"cost_micros",
            "cost_per_all_conversions",
            b"cost_per_all_conversions",
            "cost_per_conversion",
            b"cost_per_conversion",
            "cost_per_current_model_attributed_conversion",
            b"cost_per_current_model_attributed_conversion",
            "cross_device_conversions",
            b"cross_device_conversions",
            "ctr",
            b"ctr",
            "current_model_attributed_conversions",
            b"current_model_attributed_conversions",
            "current_model_attributed_conversions_from_interactions_rate",
            b"current_model_attributed_conversions_from_interactions_rate",
            "current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"current_model_attributed_conversions_from_interactions_value_per_interaction",
            "current_model_attributed_conversions_value",
            b"current_model_attributed_conversions_value",
            "current_model_attributed_conversions_value_per_cost",
            b"current_model_attributed_conversions_value_per_cost",
            "engagement_rate",
            b"engagement_rate",
            "engagements",
            b"engagements",
            "gmail_forwards",
            b"gmail_forwards",
            "gmail_saves",
            b"gmail_saves",
            "gmail_secondary_clicks",
            b"gmail_secondary_clicks",
            "historical_creative_quality_score",
            b"historical_creative_quality_score",
            "historical_landing_page_quality_score",
            b"historical_landing_page_quality_score",
            "historical_quality_score",
            b"historical_quality_score",
            "historical_search_predicted_ctr",
            b"historical_search_predicted_ctr",
            "hotel_average_lead_value_micros",
            b"hotel_average_lead_value_micros",
            "hotel_eligible_impressions",
            b"hotel_eligible_impressions",
            "hotel_price_difference_percentage",
            b"hotel_price_difference_percentage",
            "impressions",
            b"impressions",
            "impressions_from_store_reach",
            b"impressions_from_store_reach",
            "interaction_event_types",
            b"interaction_event_types",
            "interaction_rate",
            b"interaction_rate",
            "interactions",
            b"interactions",
            "invalid_click_rate",
            b"invalid_click_rate",
            "invalid_clicks",
            b"invalid_clicks",
            "message_chat_rate",
            b"message_chat_rate",
            "message_chats",
            b"message_chats",
            "message_impressions",
            b"message_impressions",
            "mobile_friendly_clicks_percentage",
            b"mobile_friendly_clicks_percentage",
            "organic_clicks",
            b"organic_clicks",
            "organic_clicks_per_query",
            b"organic_clicks_per_query",
            "organic_impressions",
            b"organic_impressions",
            "organic_impressions_per_query",
            b"organic_impressions_per_query",
            "organic_queries",
            b"organic_queries",
            "percent_new_visitors",
            b"percent_new_visitors",
            "phone_calls",
            b"phone_calls",
            "phone_impressions",
            b"phone_impressions",
            "phone_through_rate",
            b"phone_through_rate",
            "relative_ctr",
            b"relative_ctr",
            "search_absolute_top_impression_share",
            b"search_absolute_top_impression_share",
            "search_budget_lost_absolute_top_impression_share",
            b"search_budget_lost_absolute_top_impression_share",
            "search_budget_lost_impression_share",
            b"search_budget_lost_impression_share",
            "search_budget_lost_top_impression_share",
            b"search_budget_lost_top_impression_share",
            "search_click_share",
            b"search_click_share",
            "search_exact_match_impression_share",
            b"search_exact_match_impression_share",
            "search_impression_share",
            b"search_impression_share",
            "search_rank_lost_absolute_top_impression_share",
            b"search_rank_lost_absolute_top_impression_share",
            "search_rank_lost_impression_share",
            b"search_rank_lost_impression_share",
            "search_rank_lost_top_impression_share",
            b"search_rank_lost_top_impression_share",
            "search_top_impression_share",
            b"search_top_impression_share",
            "speed_score",
            b"speed_score",
            "top_impression_percentage",
            b"top_impression_percentage",
            "valid_accelerated_mobile_pages_clicks_percentage",
            b"valid_accelerated_mobile_pages_clicks_percentage",
            "value_per_all_conversions",
            b"value_per_all_conversions",
            "value_per_conversion",
            b"value_per_conversion",
            "value_per_current_model_attributed_conversion",
            b"value_per_current_model_attributed_conversion",
            "video_quartile_p100_rate",
            b"video_quartile_p100_rate",
            "video_quartile_p25_rate",
            b"video_quartile_p25_rate",
            "video_quartile_p50_rate",
            b"video_quartile_p50_rate",
            "video_quartile_p75_rate",
            b"video_quartile_p75_rate",
            "video_view_rate",
            b"video_view_rate",
            "video_views",
            b"video_views",
            "view_through_conversions",
            b"view_through_conversions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_absolute_top_impression_percentage",
            b"_absolute_top_impression_percentage",
        ],
    ) -> typing_extensions___Literal["absolute_top_impression_percentage"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_cpm", b"_active_view_cpm"
        ],
    ) -> typing_extensions___Literal["active_view_cpm"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_ctr", b"_active_view_ctr"
        ],
    ) -> typing_extensions___Literal["active_view_ctr"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_impressions", b"_active_view_impressions"
        ],
    ) -> typing_extensions___Literal["active_view_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_measurability", b"_active_view_measurability"
        ],
    ) -> typing_extensions___Literal["active_view_measurability"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_measurable_cost_micros",
            b"_active_view_measurable_cost_micros",
        ],
    ) -> typing_extensions___Literal["active_view_measurable_cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_measurable_impressions",
            b"_active_view_measurable_impressions",
        ],
    ) -> typing_extensions___Literal["active_view_measurable_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_active_view_viewability", b"_active_view_viewability"
        ],
    ) -> typing_extensions___Literal["active_view_viewability"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions", b"_all_conversions"
        ],
    ) -> typing_extensions___Literal["all_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_click_to_call",
            b"_all_conversions_from_click_to_call",
        ],
    ) -> typing_extensions___Literal["all_conversions_from_click_to_call"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_directions", b"_all_conversions_from_directions"
        ],
    ) -> typing_extensions___Literal["all_conversions_from_directions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_interactions_rate",
            b"_all_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions___Literal["all_conversions_from_interactions_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_interactions_value_per_interaction",
            b"_all_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions___Literal[
        "all_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_menu", b"_all_conversions_from_menu"
        ],
    ) -> typing_extensions___Literal["all_conversions_from_menu"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_order", b"_all_conversions_from_order"
        ],
    ) -> typing_extensions___Literal["all_conversions_from_order"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_other_engagement",
            b"_all_conversions_from_other_engagement",
        ],
    ) -> typing_extensions___Literal["all_conversions_from_other_engagement"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_store_visit", b"_all_conversions_from_store_visit"
        ],
    ) -> typing_extensions___Literal["all_conversions_from_store_visit"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_from_store_website",
            b"_all_conversions_from_store_website",
        ],
    ) -> typing_extensions___Literal["all_conversions_from_store_website"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_value", b"_all_conversions_value"
        ],
    ) -> typing_extensions___Literal["all_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_all_conversions_value_per_cost", b"_all_conversions_value_per_cost"
        ],
    ) -> typing_extensions___Literal["all_conversions_value_per_cost"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_average_cost", b"_average_cost"],
    ) -> typing_extensions___Literal["average_cost"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_average_cpc", b"_average_cpc"]
    ) -> typing_extensions___Literal["average_cpc"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_average_cpe", b"_average_cpe"]
    ) -> typing_extensions___Literal["average_cpe"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_average_cpm", b"_average_cpm"]
    ) -> typing_extensions___Literal["average_cpm"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_average_cpv", b"_average_cpv"]
    ) -> typing_extensions___Literal["average_cpv"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_average_page_views", b"_average_page_views"
        ],
    ) -> typing_extensions___Literal["average_page_views"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_average_time_on_site", b"_average_time_on_site"
        ],
    ) -> typing_extensions___Literal["average_time_on_site"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_benchmark_average_max_cpc", b"_benchmark_average_max_cpc"
        ],
    ) -> typing_extensions___Literal["benchmark_average_max_cpc"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_benchmark_ctr", b"_benchmark_ctr"],
    ) -> typing_extensions___Literal["benchmark_ctr"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_bounce_rate", b"_bounce_rate"]
    ) -> typing_extensions___Literal["bounce_rate"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_combined_clicks", b"_combined_clicks"
        ],
    ) -> typing_extensions___Literal["combined_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_combined_clicks_per_query", b"_combined_clicks_per_query"
        ],
    ) -> typing_extensions___Literal["combined_clicks_per_query"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_combined_queries", b"_combined_queries"
        ],
    ) -> typing_extensions___Literal["combined_queries"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_content_budget_lost_impression_share",
            b"_content_budget_lost_impression_share",
        ],
    ) -> typing_extensions___Literal["content_budget_lost_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_content_impression_share", b"_content_impression_share"
        ],
    ) -> typing_extensions___Literal["content_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_content_rank_lost_impression_share",
            b"_content_rank_lost_impression_share",
        ],
    ) -> typing_extensions___Literal["content_rank_lost_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_last_conversion_date", b"_conversion_last_conversion_date"
        ],
    ) -> typing_extensions___Literal["conversion_last_conversion_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_last_received_request_date_time",
            b"_conversion_last_received_request_date_time",
        ],
    ) -> typing_extensions___Literal["conversion_last_received_request_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_conversions", b"_conversions"]
    ) -> typing_extensions___Literal["conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversions_from_interactions_rate",
            b"_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions___Literal["conversions_from_interactions_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversions_from_interactions_value_per_interaction",
            b"_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions___Literal[
        "conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversions_value", b"_conversions_value"
        ],
    ) -> typing_extensions___Literal["conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversions_value_per_cost", b"_conversions_value_per_cost"
        ],
    ) -> typing_extensions___Literal["conversions_value_per_cost"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cost_per_all_conversions", b"_cost_per_all_conversions"
        ],
    ) -> typing_extensions___Literal["cost_per_all_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cost_per_conversion", b"_cost_per_conversion"
        ],
    ) -> typing_extensions___Literal["cost_per_conversion"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cost_per_current_model_attributed_conversion",
            b"_cost_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions___Literal[
        "cost_per_current_model_attributed_conversion"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cross_device_conversions", b"_cross_device_conversions"
        ],
    ) -> typing_extensions___Literal["cross_device_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ctr", b"_ctr"]
    ) -> typing_extensions___Literal["ctr"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_current_model_attributed_conversions",
            b"_current_model_attributed_conversions",
        ],
    ) -> typing_extensions___Literal["current_model_attributed_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_current_model_attributed_conversions_from_interactions_rate",
            b"_current_model_attributed_conversions_from_interactions_rate",
        ],
    ) -> typing_extensions___Literal[
        "current_model_attributed_conversions_from_interactions_rate"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_current_model_attributed_conversions_from_interactions_value_per_interaction",
            b"_current_model_attributed_conversions_from_interactions_value_per_interaction",
        ],
    ) -> typing_extensions___Literal[
        "current_model_attributed_conversions_from_interactions_value_per_interaction"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_current_model_attributed_conversions_value",
            b"_current_model_attributed_conversions_value",
        ],
    ) -> typing_extensions___Literal["current_model_attributed_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_current_model_attributed_conversions_value_per_cost",
            b"_current_model_attributed_conversions_value_per_cost",
        ],
    ) -> typing_extensions___Literal[
        "current_model_attributed_conversions_value_per_cost"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_engagement_rate", b"_engagement_rate"
        ],
    ) -> typing_extensions___Literal["engagement_rate"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_engagements", b"_engagements"]
    ) -> typing_extensions___Literal["engagements"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_gmail_forwards", b"_gmail_forwards"],
    ) -> typing_extensions___Literal["gmail_forwards"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_gmail_saves", b"_gmail_saves"]
    ) -> typing_extensions___Literal["gmail_saves"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_gmail_secondary_clicks", b"_gmail_secondary_clicks"
        ],
    ) -> typing_extensions___Literal["gmail_secondary_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_historical_quality_score", b"_historical_quality_score"
        ],
    ) -> typing_extensions___Literal["historical_quality_score"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_average_lead_value_micros", b"_hotel_average_lead_value_micros"
        ],
    ) -> typing_extensions___Literal["hotel_average_lead_value_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_eligible_impressions", b"_hotel_eligible_impressions"
        ],
    ) -> typing_extensions___Literal["hotel_eligible_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hotel_price_difference_percentage", b"_hotel_price_difference_percentage"
        ],
    ) -> typing_extensions___Literal["hotel_price_difference_percentage"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_impressions_from_store_reach", b"_impressions_from_store_reach"
        ],
    ) -> typing_extensions___Literal["impressions_from_store_reach"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_interaction_rate", b"_interaction_rate"
        ],
    ) -> typing_extensions___Literal["interaction_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_interactions", b"_interactions"],
    ) -> typing_extensions___Literal["interactions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_invalid_click_rate", b"_invalid_click_rate"
        ],
    ) -> typing_extensions___Literal["invalid_click_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_invalid_clicks", b"_invalid_clicks"],
    ) -> typing_extensions___Literal["invalid_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_message_chat_rate", b"_message_chat_rate"
        ],
    ) -> typing_extensions___Literal["message_chat_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_message_chats", b"_message_chats"],
    ) -> typing_extensions___Literal["message_chats"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_message_impressions", b"_message_impressions"
        ],
    ) -> typing_extensions___Literal["message_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_mobile_friendly_clicks_percentage", b"_mobile_friendly_clicks_percentage"
        ],
    ) -> typing_extensions___Literal["mobile_friendly_clicks_percentage"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_organic_clicks", b"_organic_clicks"],
    ) -> typing_extensions___Literal["organic_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_organic_clicks_per_query", b"_organic_clicks_per_query"
        ],
    ) -> typing_extensions___Literal["organic_clicks_per_query"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_organic_impressions", b"_organic_impressions"
        ],
    ) -> typing_extensions___Literal["organic_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_organic_impressions_per_query", b"_organic_impressions_per_query"
        ],
    ) -> typing_extensions___Literal["organic_impressions_per_query"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_organic_queries", b"_organic_queries"
        ],
    ) -> typing_extensions___Literal["organic_queries"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_percent_new_visitors", b"_percent_new_visitors"
        ],
    ) -> typing_extensions___Literal["percent_new_visitors"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_phone_calls", b"_phone_calls"]
    ) -> typing_extensions___Literal["phone_calls"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_phone_impressions", b"_phone_impressions"
        ],
    ) -> typing_extensions___Literal["phone_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_phone_through_rate", b"_phone_through_rate"
        ],
    ) -> typing_extensions___Literal["phone_through_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_relative_ctr", b"_relative_ctr"],
    ) -> typing_extensions___Literal["relative_ctr"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_absolute_top_impression_share",
            b"_search_absolute_top_impression_share",
        ],
    ) -> typing_extensions___Literal["search_absolute_top_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_budget_lost_absolute_top_impression_share",
            b"_search_budget_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions___Literal[
        "search_budget_lost_absolute_top_impression_share"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_budget_lost_impression_share",
            b"_search_budget_lost_impression_share",
        ],
    ) -> typing_extensions___Literal["search_budget_lost_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_budget_lost_top_impression_share",
            b"_search_budget_lost_top_impression_share",
        ],
    ) -> typing_extensions___Literal["search_budget_lost_top_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_click_share", b"_search_click_share"
        ],
    ) -> typing_extensions___Literal["search_click_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_exact_match_impression_share",
            b"_search_exact_match_impression_share",
        ],
    ) -> typing_extensions___Literal["search_exact_match_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_impression_share", b"_search_impression_share"
        ],
    ) -> typing_extensions___Literal["search_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_rank_lost_absolute_top_impression_share",
            b"_search_rank_lost_absolute_top_impression_share",
        ],
    ) -> typing_extensions___Literal[
        "search_rank_lost_absolute_top_impression_share"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_rank_lost_impression_share", b"_search_rank_lost_impression_share"
        ],
    ) -> typing_extensions___Literal["search_rank_lost_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_rank_lost_top_impression_share",
            b"_search_rank_lost_top_impression_share",
        ],
    ) -> typing_extensions___Literal["search_rank_lost_top_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_search_top_impression_share", b"_search_top_impression_share"
        ],
    ) -> typing_extensions___Literal["search_top_impression_share"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_speed_score", b"_speed_score"]
    ) -> typing_extensions___Literal["speed_score"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_impression_percentage", b"_top_impression_percentage"
        ],
    ) -> typing_extensions___Literal["top_impression_percentage"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_valid_accelerated_mobile_pages_clicks_percentage",
            b"_valid_accelerated_mobile_pages_clicks_percentage",
        ],
    ) -> typing_extensions___Literal[
        "valid_accelerated_mobile_pages_clicks_percentage"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_value_per_all_conversions", b"_value_per_all_conversions"
        ],
    ) -> typing_extensions___Literal["value_per_all_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_value_per_conversion", b"_value_per_conversion"
        ],
    ) -> typing_extensions___Literal["value_per_conversion"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_value_per_current_model_attributed_conversion",
            b"_value_per_current_model_attributed_conversion",
        ],
    ) -> typing_extensions___Literal[
        "value_per_current_model_attributed_conversion"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_video_quartile_p100_rate", b"_video_quartile_p100_rate"
        ],
    ) -> typing_extensions___Literal["video_quartile_p100_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_video_quartile_p25_rate", b"_video_quartile_p25_rate"
        ],
    ) -> typing_extensions___Literal["video_quartile_p25_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_video_quartile_p50_rate", b"_video_quartile_p50_rate"
        ],
    ) -> typing_extensions___Literal["video_quartile_p50_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_video_quartile_p75_rate", b"_video_quartile_p75_rate"
        ],
    ) -> typing_extensions___Literal["video_quartile_p75_rate"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_video_view_rate", b"_video_view_rate"
        ],
    ) -> typing_extensions___Literal["video_view_rate"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_video_views", b"_video_views"]
    ) -> typing_extensions___Literal["video_views"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_view_through_conversions", b"_view_through_conversions"
        ],
    ) -> typing_extensions___Literal["view_through_conversions"]: ...

type___Metrics = Metrics
