# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class IncomeRangeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    IncomeRangeTypeValue = typing___NewType("IncomeRangeTypeValue", builtin___int)
    type___IncomeRangeTypeValue = IncomeRangeTypeValue
    IncomeRangeType: _IncomeRangeType
    class _IncomeRangeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            IncomeRangeTypeEnum.IncomeRangeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 0)
        UNKNOWN = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 1)
        INCOME_RANGE_0_50 = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510001
        )
        INCOME_RANGE_50_60 = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510002
        )
        INCOME_RANGE_60_70 = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510003
        )
        INCOME_RANGE_70_80 = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510004
        )
        INCOME_RANGE_80_90 = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510005
        )
        INCOME_RANGE_90_UP = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510006
        )
        INCOME_RANGE_UNDETERMINED = typing___cast(
            IncomeRangeTypeEnum.IncomeRangeTypeValue, 510000
        )
    UNSPECIFIED = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 0)
    UNKNOWN = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 1)
    INCOME_RANGE_0_50 = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510001)
    INCOME_RANGE_50_60 = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510002)
    INCOME_RANGE_60_70 = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510003)
    INCOME_RANGE_70_80 = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510004)
    INCOME_RANGE_80_90 = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510005)
    INCOME_RANGE_90_UP = typing___cast(IncomeRangeTypeEnum.IncomeRangeTypeValue, 510006)
    INCOME_RANGE_UNDETERMINED = typing___cast(
        IncomeRangeTypeEnum.IncomeRangeTypeValue, 510000
    )
    type___IncomeRangeType = IncomeRangeType
    def __init__(self,) -> None: ...

type___IncomeRangeTypeEnum = IncomeRangeTypeEnum
