# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdStrengthEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdStrengthValue = typing___NewType("AdStrengthValue", builtin___int)
    type___AdStrengthValue = AdStrengthValue
    AdStrength: _AdStrength
    class _AdStrength(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdStrengthEnum.AdStrengthValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdStrengthEnum.AdStrengthValue, 0)
        UNKNOWN = typing___cast(AdStrengthEnum.AdStrengthValue, 1)
        PENDING = typing___cast(AdStrengthEnum.AdStrengthValue, 2)
        NO_ADS = typing___cast(AdStrengthEnum.AdStrengthValue, 3)
        POOR = typing___cast(AdStrengthEnum.AdStrengthValue, 4)
        AVERAGE = typing___cast(AdStrengthEnum.AdStrengthValue, 5)
        GOOD = typing___cast(AdStrengthEnum.AdStrengthValue, 6)
        EXCELLENT = typing___cast(AdStrengthEnum.AdStrengthValue, 7)
    UNSPECIFIED = typing___cast(AdStrengthEnum.AdStrengthValue, 0)
    UNKNOWN = typing___cast(AdStrengthEnum.AdStrengthValue, 1)
    PENDING = typing___cast(AdStrengthEnum.AdStrengthValue, 2)
    NO_ADS = typing___cast(AdStrengthEnum.AdStrengthValue, 3)
    POOR = typing___cast(AdStrengthEnum.AdStrengthValue, 4)
    AVERAGE = typing___cast(AdStrengthEnum.AdStrengthValue, 5)
    GOOD = typing___cast(AdStrengthEnum.AdStrengthValue, 6)
    EXCELLENT = typing___cast(AdStrengthEnum.AdStrengthValue, 7)
    type___AdStrength = AdStrength
    def __init__(self,) -> None: ...

type___AdStrengthEnum = AdStrengthEnum
