from typing import Any

class ThirdPartyAppAnalyticsLinkServiceStub:
    GetThirdPartyAppAnalyticsLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ThirdPartyAppAnalyticsLinkServiceServicer:
    def GetThirdPartyAppAnalyticsLink(self, request: Any, context: Any) -> None: ...

def add_ThirdPartyAppAnalyticsLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
