# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionUploadErrorValue = typing___NewType(
        "ConversionUploadErrorValue", builtin___int
    )
    type___ConversionUploadErrorValue = ConversionUploadErrorValue
    ConversionUploadError: _ConversionUploadError
    class _ConversionUploadError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionUploadErrorEnum.ConversionUploadErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 0
        )
        UNKNOWN = typing___cast(ConversionUploadErrorEnum.ConversionUploadErrorValue, 1)
        TOO_MANY_CONVERSIONS_IN_REQUEST = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 2
        )
        UNPARSEABLE_GCLID = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 3
        )
        CONVERSION_PRECEDES_GCLID = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 4
        )
        EXPIRED_GCLID = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 5
        )
        TOO_RECENT_GCLID = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 6
        )
        GCLID_NOT_FOUND = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 7
        )
        UNAUTHORIZED_CUSTOMER = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 8
        )
        INVALID_CONVERSION_ACTION = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 9
        )
        TOO_RECENT_CONVERSION_ACTION = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 10
        )
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 11
        )
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 12
        )
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 13
        )
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 14
        )
        ORDER_ID_ALREADY_IN_USE = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 15
        )
        DUPLICATE_ORDER_ID = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 16
        )
        TOO_RECENT_CALL = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 17
        )
        EXPIRED_CALL = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 18
        )
        CALL_NOT_FOUND = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 19
        )
        CONVERSION_PRECEDES_CALL = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 20
        )
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 21
        )
        UNPARSEABLE_CALLERS_PHONE_NUMBER = typing___cast(
            ConversionUploadErrorEnum.ConversionUploadErrorValue, 22
        )
    UNSPECIFIED = typing___cast(ConversionUploadErrorEnum.ConversionUploadErrorValue, 0)
    UNKNOWN = typing___cast(ConversionUploadErrorEnum.ConversionUploadErrorValue, 1)
    TOO_MANY_CONVERSIONS_IN_REQUEST = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 2
    )
    UNPARSEABLE_GCLID = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 3
    )
    CONVERSION_PRECEDES_GCLID = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 4
    )
    EXPIRED_GCLID = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 5
    )
    TOO_RECENT_GCLID = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 6
    )
    GCLID_NOT_FOUND = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 7
    )
    UNAUTHORIZED_CUSTOMER = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 8
    )
    INVALID_CONVERSION_ACTION = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 9
    )
    TOO_RECENT_CONVERSION_ACTION = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 10
    )
    CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 11
    )
    EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 12
    )
    EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 13
    )
    ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 14
    )
    ORDER_ID_ALREADY_IN_USE = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 15
    )
    DUPLICATE_ORDER_ID = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 16
    )
    TOO_RECENT_CALL = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 17
    )
    EXPIRED_CALL = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 18
    )
    CALL_NOT_FOUND = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 19
    )
    CONVERSION_PRECEDES_CALL = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 20
    )
    CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 21
    )
    UNPARSEABLE_CALLERS_PHONE_NUMBER = typing___cast(
        ConversionUploadErrorEnum.ConversionUploadErrorValue, 22
    )
    type___ConversionUploadError = ConversionUploadError
    def __init__(self,) -> None: ...

type___ConversionUploadErrorEnum = ConversionUploadErrorEnum
