# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ServedAssetFieldTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ServedAssetFieldTypeValue = typing___NewType(
        "ServedAssetFieldTypeValue", builtin___int
    )
    type___ServedAssetFieldTypeValue = ServedAssetFieldTypeValue
    ServedAssetFieldType: _ServedAssetFieldType
    class _ServedAssetFieldType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 0
        )
        UNKNOWN = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 1)
        HEADLINE_1 = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 2
        )
        HEADLINE_2 = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 3
        )
        HEADLINE_3 = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 4
        )
        DESCRIPTION_1 = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 5
        )
        DESCRIPTION_2 = typing___cast(
            ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 6
        )
    UNSPECIFIED = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 0)
    UNKNOWN = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 1)
    HEADLINE_1 = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 2)
    HEADLINE_2 = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 3)
    HEADLINE_3 = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 4)
    DESCRIPTION_1 = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 5)
    DESCRIPTION_2 = typing___cast(ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue, 6)
    type___ServedAssetFieldType = ServedAssetFieldType
    def __init__(self,) -> None: ...

type___ServedAssetFieldTypeEnum = ServedAssetFieldTypeEnum
