from typing import Any

class AdServiceStub:
    GetAd: Any = ...
    MutateAds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdServiceServicer:
    def GetAd(self, request: Any, context: Any) -> None: ...
    def MutateAds(self, request: Any, context: Any) -> None: ...

def add_AdServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
