# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AttributionModelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AttributionModelValue = typing___NewType("AttributionModelValue", builtin___int)
    type___AttributionModelValue = AttributionModelValue
    AttributionModel: _AttributionModel
    class _AttributionModel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AttributionModelEnum.AttributionModelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModelValue, 0)
        UNKNOWN = typing___cast(AttributionModelEnum.AttributionModelValue, 1)
        EXTERNAL = typing___cast(AttributionModelEnum.AttributionModelValue, 100)
        GOOGLE_ADS_LAST_CLICK = typing___cast(
            AttributionModelEnum.AttributionModelValue, 101
        )
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(
            AttributionModelEnum.AttributionModelValue, 102
        )
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(
            AttributionModelEnum.AttributionModelValue, 103
        )
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(
            AttributionModelEnum.AttributionModelValue, 104
        )
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(
            AttributionModelEnum.AttributionModelValue, 105
        )
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(
            AttributionModelEnum.AttributionModelValue, 106
        )
    UNSPECIFIED = typing___cast(AttributionModelEnum.AttributionModelValue, 0)
    UNKNOWN = typing___cast(AttributionModelEnum.AttributionModelValue, 1)
    EXTERNAL = typing___cast(AttributionModelEnum.AttributionModelValue, 100)
    GOOGLE_ADS_LAST_CLICK = typing___cast(
        AttributionModelEnum.AttributionModelValue, 101
    )
    GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = typing___cast(
        AttributionModelEnum.AttributionModelValue, 102
    )
    GOOGLE_SEARCH_ATTRIBUTION_LINEAR = typing___cast(
        AttributionModelEnum.AttributionModelValue, 103
    )
    GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = typing___cast(
        AttributionModelEnum.AttributionModelValue, 104
    )
    GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = typing___cast(
        AttributionModelEnum.AttributionModelValue, 105
    )
    GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = typing___cast(
        AttributionModelEnum.AttributionModelValue, 106
    )
    type___AttributionModel = AttributionModel
    def __init__(self,) -> None: ...

type___AttributionModelEnum = AttributionModelEnum
