from typing import Any

class CampaignDraftServiceStub:
    GetCampaignDraft: Any = ...
    MutateCampaignDrafts: Any = ...
    PromoteCampaignDraft: Any = ...
    ListCampaignDraftAsyncErrors: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignDraftServiceServicer:
    def GetCampaignDraft(self, request: Any, context: Any) -> None: ...
    def MutateCampaignDrafts(self, request: Any, context: Any) -> None: ...
    def PromoteCampaignDraft(self, request: Any, context: Any) -> None: ...
    def ListCampaignDraftAsyncErrors(self, request: Any, context: Any) -> None: ...

def add_CampaignDraftServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
