from typing import Any

class MerchantCenterLinkServiceStub:
    ListMerchantCenterLinks: Any = ...
    GetMerchantCenterLink: Any = ...
    MutateMerchantCenterLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MerchantCenterLinkServiceServicer:
    def ListMerchantCenterLinks(self, request: Any, context: Any) -> None: ...
    def GetMerchantCenterLink(self, request: Any, context: Any) -> None: ...
    def MutateMerchantCenterLink(self, request: Any, context: Any) -> None: ...

def add_MerchantCenterLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
