# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedSetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SharedSetErrorValue = typing___NewType("SharedSetErrorValue", builtin___int)
    type___SharedSetErrorValue = SharedSetErrorValue
    SharedSetError: _SharedSetError
    class _SharedSetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SharedSetErrorEnum.SharedSetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 0)
        UNKNOWN = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 1)
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = typing___cast(
            SharedSetErrorEnum.SharedSetErrorValue, 2
        )
        DUPLICATE_NAME = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 3)
        SHARED_SET_REMOVED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 4)
        SHARED_SET_IN_USE = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 5)
    UNSPECIFIED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 0)
    UNKNOWN = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 1)
    CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = typing___cast(
        SharedSetErrorEnum.SharedSetErrorValue, 2
    )
    DUPLICATE_NAME = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 3)
    SHARED_SET_REMOVED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 4)
    SHARED_SET_IN_USE = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 5)
    type___SharedSetError = SharedSetError
    def __init__(self,) -> None: ...

type___SharedSetErrorEnum = SharedSetErrorEnum
