from typing import Any

class AdGroupAdLabelServiceStub:
    GetAdGroupAdLabel: Any = ...
    MutateAdGroupAdLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupAdLabelServiceServicer:
    def GetAdGroupAdLabel(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupAdLabels(self, request: Any, context: Any) -> None: ...

def add_AdGroupAdLabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
