# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SharedCriterionErrorValue = typing___NewType(
        "SharedCriterionErrorValue", builtin___int
    )
    type___SharedCriterionErrorValue = SharedCriterionErrorValue
    SharedCriterionError: _SharedCriterionError
    class _SharedCriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SharedCriterionErrorEnum.SharedCriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            SharedCriterionErrorEnum.SharedCriterionErrorValue, 0
        )
        UNKNOWN = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 1)
        CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE = typing___cast(
            SharedCriterionErrorEnum.SharedCriterionErrorValue, 2
        )
    UNSPECIFIED = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 0)
    UNKNOWN = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 1)
    CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE = typing___cast(
        SharedCriterionErrorEnum.SharedCriterionErrorValue, 2
    )
    type___SharedCriterionError = SharedCriterionError
    def __init__(self,) -> None: ...

type___SharedCriterionErrorEnum = SharedCriterionErrorEnum
