from typing import Any

class GeographicViewServiceStub:
    GetGeographicView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GeographicViewServiceServicer:
    def GetGeographicView(self, request: Any, context: Any) -> None: ...

def add_GeographicViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
