# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerUserAccessErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerUserAccessErrorValue = typing___NewType(
        "CustomerUserAccessErrorValue", builtin___int
    )
    type___CustomerUserAccessErrorValue = CustomerUserAccessErrorValue
    CustomerUserAccessError: _CustomerUserAccessError
    class _CustomerUserAccessError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 1
        )
        INVALID_USER_ID = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 2
        )
        REMOVAL_DISALLOWED = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 3
        )
        DISALLOWED_ACCESS_ROLE = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 4
        )
        LAST_ADMIN_USER_OF_SERVING_CUSTOMER = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 5
        )
        LAST_ADMIN_USER_OF_MANAGER = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 6
        )
    UNSPECIFIED = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 0
    )
    UNKNOWN = typing___cast(CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 1)
    INVALID_USER_ID = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 2
    )
    REMOVAL_DISALLOWED = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 3
    )
    DISALLOWED_ACCESS_ROLE = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 4
    )
    LAST_ADMIN_USER_OF_SERVING_CUSTOMER = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 5
    )
    LAST_ADMIN_USER_OF_MANAGER = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 6
    )
    type___CustomerUserAccessError = CustomerUserAccessError
    def __init__(self,) -> None: ...

type___CustomerUserAccessErrorEnum = CustomerUserAccessErrorEnum
