# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PaymentsAccount(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    payments_account_id: typing___Text = ...
    name: typing___Text = ...
    currency_code: typing___Text = ...
    payments_profile_id: typing___Text = ...
    secondary_payments_profile_id: typing___Text = ...
    paying_manager_customer: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        payments_account_id: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[typing___Text] = None,
        payments_profile_id: typing___Optional[typing___Text] = None,
        secondary_payments_profile_id: typing___Optional[typing___Text] = None,
        paying_manager_customer: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "resource_name",
            b"resource_name",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_paying_manager_customer", b"_paying_manager_customer"
        ],
    ) -> typing_extensions___Literal["paying_manager_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions___Literal["payments_account_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions___Literal["payments_profile_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_secondary_payments_profile_id", b"_secondary_payments_profile_id"
        ],
    ) -> typing_extensions___Literal["secondary_payments_profile_id"]: ...

type___PaymentsAccount = PaymentsAccount
