# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AffiliateLocationFeedRelationshipTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AffiliateLocationFeedRelationshipTypeValue = typing___NewType(
        "AffiliateLocationFeedRelationshipTypeValue", builtin___int
    )
    type___AffiliateLocationFeedRelationshipTypeValue = (
        AffiliateLocationFeedRelationshipTypeValue
    )
    AffiliateLocationFeedRelationshipType: _AffiliateLocationFeedRelationshipType
    class _AffiliateLocationFeedRelationshipType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            1,
        )
        GENERAL_RETAILER = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            2,
        )
    UNSPECIFIED = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        1,
    )
    GENERAL_RETAILER = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        2,
    )
    type___AffiliateLocationFeedRelationshipType = AffiliateLocationFeedRelationshipType
    def __init__(self,) -> None: ...

type___AffiliateLocationFeedRelationshipTypeEnum = (
    AffiliateLocationFeedRelationshipTypeEnum
)
