# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeoTargetConstantSuggestionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GeoTargetConstantSuggestionErrorValue = typing___NewType(
        "GeoTargetConstantSuggestionErrorValue", builtin___int
    )
    type___GeoTargetConstantSuggestionErrorValue = GeoTargetConstantSuggestionErrorValue
    GeoTargetConstantSuggestionError: _GeoTargetConstantSuggestionError
    class _GeoTargetConstantSuggestionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            0,
        )
        UNKNOWN = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            1,
        )
        LOCATION_NAME_SIZE_LIMIT = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            2,
        )
        LOCATION_NAME_LIMIT = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            3,
        )
        INVALID_COUNTRY_CODE = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            4,
        )
        REQUEST_PARAMETERS_UNSET = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            5,
        )
    UNSPECIFIED = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 0
    )
    UNKNOWN = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 1
    )
    LOCATION_NAME_SIZE_LIMIT = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 2
    )
    LOCATION_NAME_LIMIT = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 3
    )
    INVALID_COUNTRY_CODE = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 4
    )
    REQUEST_PARAMETERS_UNSET = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 5
    )
    type___GeoTargetConstantSuggestionError = GeoTargetConstantSuggestionError
    def __init__(self,) -> None: ...

type___GeoTargetConstantSuggestionErrorEnum = GeoTargetConstantSuggestionErrorEnum
