# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaUploadErrorValue = typing___NewType("MediaUploadErrorValue", builtin___int)
    type___MediaUploadErrorValue = MediaUploadErrorValue
    MediaUploadError: _MediaUploadError
    class _MediaUploadError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaUploadErrorEnum.MediaUploadErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 0)
        UNKNOWN = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 1)
        FILE_TOO_BIG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 2)
        UNPARSEABLE_IMAGE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 3)
        ANIMATED_IMAGE_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 4
        )
        FORMAT_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 5
        )
        EXTERNAL_URL_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 6
        )
        INVALID_URL_REFERENCE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 7
        )
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 8
        )
        ANIMATED_VISUAL_EFFECT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 9
        )
        ANIMATION_TOO_LONG = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 10
        )
        ASPECT_RATIO_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 11
        )
        AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 12
        )
        CMYK_JPEG_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 13
        )
        FLASH_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 14
        )
        FRAME_RATE_TOO_HIGH = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 15
        )
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 16
        )
        IMAGE_CONSTRAINTS_VIOLATED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 17
        )
        INVALID_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 18
        )
        INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 19
        )
        INVALID_MIME_TYPE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 20
        )
        INVALID_PATH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 21)
        LAYOUT_PROBLEM = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 22)
        MALFORMED_URL = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 23)
        MEDIA_BUNDLE_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 24
        )
        MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 25
        )
        MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 26
        )
        TOO_MANY_FILES_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 27
        )
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 28
        )
        UNSUPPORTED_HTML5_FEATURE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 29
        )
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 30
        )
        VIDEO_FILE_NAME_TOO_LONG = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 31
        )
        VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 32
        )
        VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 33
        )
        CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 34
        )
    UNSPECIFIED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 0)
    UNKNOWN = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 1)
    FILE_TOO_BIG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 2)
    UNPARSEABLE_IMAGE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 3)
    ANIMATED_IMAGE_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 4
    )
    FORMAT_NOT_ALLOWED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 5)
    EXTERNAL_URL_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 6
    )
    INVALID_URL_REFERENCE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 8
    )
    ANIMATED_VISUAL_EFFECT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 9
    )
    ANIMATION_TOO_LONG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 10)
    ASPECT_RATIO_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 11
    )
    AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 12
    )
    CMYK_JPEG_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 13
    )
    FLASH_NOT_ALLOWED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 14)
    FRAME_RATE_TOO_HIGH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 15)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 16
    )
    IMAGE_CONSTRAINTS_VIOLATED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 17
    )
    INVALID_MEDIA_BUNDLE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 18)
    INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 19
    )
    INVALID_MIME_TYPE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 20)
    INVALID_PATH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 21)
    LAYOUT_PROBLEM = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 22)
    MALFORMED_URL = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 23)
    MEDIA_BUNDLE_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 24
    )
    MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 25
    )
    MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 26
    )
    TOO_MANY_FILES_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 27
    )
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 28
    )
    UNSUPPORTED_HTML5_FEATURE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 29
    )
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 30
    )
    VIDEO_FILE_NAME_TOO_LONG = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 31
    )
    VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 32
    )
    VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 33
    )
    CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 34
    )
    type___MediaUploadError = MediaUploadError
    def __init__(self,) -> None: ...

type___MediaUploadErrorEnum = MediaUploadErrorEnum
