# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v6___common___criteria_pb2___KeywordInfo,
    MobileAppCategoryInfo as google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo,
    PlacementInfo as google___ads___googleads___v6___common___criteria_pb2___PlacementInfo,
    YouTubeChannelInfo as google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo,
)
from google.ads.google_ads.v6.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    shared_set: typing___Text = ...
    criterion_id: builtin___int = ...
    type: google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue = ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___KeywordInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo: ...
    @property
    def placement(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        shared_set: typing___Optional[typing___Text] = None,
        criterion_id: typing___Optional[builtin___int] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue
        ] = None,
        keyword: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___KeywordInfo
        ] = None,
        youtube_video: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo
        ] = None,
        youtube_channel: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo
        ] = None,
        placement: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___PlacementInfo
        ] = None,
        mobile_app_category: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo
        ] = None,
        mobile_application: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "shared_set",
            b"shared_set",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "resource_name",
            b"resource_name",
            "shared_set",
            b"shared_set",
            "type",
            b"type",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_criterion_id", b"_criterion_id"],
    ) -> typing_extensions___Literal["criterion_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_shared_set", b"_shared_set"]
    ) -> typing_extensions___Literal["shared_set"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal[
        "keyword",
        "youtube_video",
        "youtube_channel",
        "placement",
        "mobile_app_category",
        "mobile_application",
    ]: ...

type___SharedCriterion = SharedCriterion
