# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTargetDeviceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemTargetDeviceValue = typing___NewType(
        "FeedItemTargetDeviceValue", builtin___int
    )
    type___FeedItemTargetDeviceValue = FeedItemTargetDeviceValue
    FeedItemTargetDevice: _FeedItemTargetDevice
    class _FeedItemTargetDevice(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 0
        )
        UNKNOWN = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 1)
        MOBILE = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 2)
    UNSPECIFIED = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 0)
    UNKNOWN = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 1)
    MOBILE = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 2)
    type___FeedItemTargetDevice = FeedItemTargetDevice
    def __init__(self,) -> None: ...

type___FeedItemTargetDeviceEnum = FeedItemTargetDeviceEnum
