# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ThirdPartyAppAnalyticsLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ThirdPartyAppAnalyticsLinkErrorValue = typing___NewType(
        "ThirdPartyAppAnalyticsLinkErrorValue", builtin___int
    )
    type___ThirdPartyAppAnalyticsLinkErrorValue = ThirdPartyAppAnalyticsLinkErrorValue
    ThirdPartyAppAnalyticsLinkError: _ThirdPartyAppAnalyticsLinkError
    class _ThirdPartyAppAnalyticsLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 1
        )
        INVALID_ANALYTICS_PROVIDER_ID = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 2
        )
        INVALID_MOBILE_APP_ID = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 3
        )
        MOBILE_APP_IS_NOT_ENABLED = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 4
        )
        CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 5
        )
    UNSPECIFIED = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 0
    )
    UNKNOWN = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 1
    )
    INVALID_ANALYTICS_PROVIDER_ID = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 2
    )
    INVALID_MOBILE_APP_ID = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 3
    )
    MOBILE_APP_IS_NOT_ENABLED = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 4
    )
    CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 5
    )
    type___ThirdPartyAppAnalyticsLinkError = ThirdPartyAppAnalyticsLinkError
    def __init__(self,) -> None: ...

type___ThirdPartyAppAnalyticsLinkErrorEnum = ThirdPartyAppAnalyticsLinkErrorEnum
