# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionCategoryChannelAvailabilityModeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionCategoryChannelAvailabilityModeValue = typing___NewType(
        "CriterionCategoryChannelAvailabilityModeValue", builtin___int
    )
    type___CriterionCategoryChannelAvailabilityModeValue = (
        CriterionCategoryChannelAvailabilityModeValue
    )
    CriterionCategoryChannelAvailabilityMode: _CriterionCategoryChannelAvailabilityMode
    class _CriterionCategoryChannelAvailabilityMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            0,
        )
        UNKNOWN = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            1,
        )
        ALL_CHANNELS = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            2,
        )
        CHANNEL_TYPE_AND_ALL_SUBTYPES = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            3,
        )
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            4,
        )
    UNSPECIFIED = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        0,
    )
    UNKNOWN = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        1,
    )
    ALL_CHANNELS = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        2,
    )
    CHANNEL_TYPE_AND_ALL_SUBTYPES = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        3,
    )
    CHANNEL_TYPE_AND_SUBSET_SUBTYPES = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        4,
    )
    type___CriterionCategoryChannelAvailabilityMode = (
        CriterionCategoryChannelAvailabilityMode
    )
    def __init__(self,) -> None: ...

type___CriterionCategoryChannelAvailabilityModeEnum = (
    CriterionCategoryChannelAvailabilityModeEnum
)
