# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class EducationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    EducationPlaceholderFieldValue = typing___NewType(
        "EducationPlaceholderFieldValue", builtin___int
    )
    type___EducationPlaceholderFieldValue = EducationPlaceholderFieldValue
    EducationPlaceholderField: _EducationPlaceholderField
    class _EducationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 1
        )
        PROGRAM_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 2
        )
        LOCATION_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 3
        )
        PROGRAM_NAME = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 4
        )
        AREA_OF_STUDY = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 5
        )
        PROGRAM_DESCRIPTION = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 6
        )
        SCHOOL_NAME = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 7
        )
        ADDRESS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 8
        )
        THUMBNAIL_IMAGE_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 9
        )
        ALTERNATIVE_THUMBNAIL_IMAGE_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 10
        )
        FINAL_URLS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 11
        )
        FINAL_MOBILE_URLS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 12
        )
        TRACKING_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 13
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 14
        )
        ANDROID_APP_LINK = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 15
        )
        SIMILAR_PROGRAM_IDS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 16
        )
        IOS_APP_LINK = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 17
        )
        IOS_APP_STORE_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 18
        )
    UNSPECIFIED = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 1
    )
    PROGRAM_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 2
    )
    LOCATION_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 3
    )
    PROGRAM_NAME = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 4
    )
    AREA_OF_STUDY = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 5
    )
    PROGRAM_DESCRIPTION = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 6
    )
    SCHOOL_NAME = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 7
    )
    ADDRESS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 8
    )
    THUMBNAIL_IMAGE_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 9
    )
    ALTERNATIVE_THUMBNAIL_IMAGE_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 10
    )
    FINAL_URLS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 11
    )
    FINAL_MOBILE_URLS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 12
    )
    TRACKING_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 13
    )
    CONTEXTUAL_KEYWORDS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 14
    )
    ANDROID_APP_LINK = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 15
    )
    SIMILAR_PROGRAM_IDS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 16
    )
    IOS_APP_LINK = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 17
    )
    IOS_APP_STORE_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 18
    )
    type___EducationPlaceholderField = EducationPlaceholderField
    def __init__(self,) -> None: ...

type___EducationPlaceholderFieldEnum = EducationPlaceholderFieldEnum
