# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ParentalStatusTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ParentalStatusTypeValue = typing___NewType("ParentalStatusTypeValue", builtin___int)
    type___ParentalStatusTypeValue = ParentalStatusTypeValue
    ParentalStatusType: _ParentalStatusType
    class _ParentalStatusType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ParentalStatusTypeEnum.ParentalStatusTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 0)
        UNKNOWN = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 1)
        PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 300)
        NOT_A_PARENT = typing___cast(
            ParentalStatusTypeEnum.ParentalStatusTypeValue, 301
        )
        UNDETERMINED = typing___cast(
            ParentalStatusTypeEnum.ParentalStatusTypeValue, 302
        )
    UNSPECIFIED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 0)
    UNKNOWN = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 1)
    PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 300)
    NOT_A_PARENT = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 301)
    UNDETERMINED = typing___cast(ParentalStatusTypeEnum.ParentalStatusTypeValue, 302)
    type___ParentalStatusType = ParentalStatusType
    def __init__(self,) -> None: ...

type___ParentalStatusTypeEnum = ParentalStatusTypeEnum
