# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionOrAdjustmentLagBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionOrAdjustmentLagBucketValue = typing___NewType(
        "ConversionOrAdjustmentLagBucketValue", builtin___int
    )
    type___ConversionOrAdjustmentLagBucketValue = ConversionOrAdjustmentLagBucketValue
    ConversionOrAdjustmentLagBucket: _ConversionOrAdjustmentLagBucket
    class _ConversionOrAdjustmentLagBucket(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 0
        )
        UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 1
        )
        CONVERSION_LESS_THAN_ONE_DAY = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 2
        )
        CONVERSION_ONE_TO_TWO_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 3
        )
        CONVERSION_TWO_TO_THREE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 4
        )
        CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 5
        )
        CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 6
        )
        CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 7
        )
        CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 8
        )
        CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 9
        )
        CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 10
        )
        CONVERSION_NINE_TO_TEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 11
        )
        CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 12
        )
        CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 13
        )
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 14
        )
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 15
        )
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 16
        )
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 17
        )
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 18
        )
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 19
        )
        CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 20
        )
        ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 21
        )
        ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 22
        )
        ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 23
        )
        ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 24
        )
        ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 25
        )
        ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 26
        )
        ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 27
        )
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 28
        )
        ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 29
        )
        ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 30
        )
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 31
        )
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 32
        )
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 33
        )
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 34
        )
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 35
        )
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 36
        )
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 37
        )
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 38
        )
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 39
        )
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 40
        )
        CONVERSION_UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 41
        )
        ADJUSTMENT_UNKNOWN = typing___cast(
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 42
        )
    UNSPECIFIED = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 0
    )
    UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 1
    )
    CONVERSION_LESS_THAN_ONE_DAY = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 2
    )
    CONVERSION_ONE_TO_TWO_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 3
    )
    CONVERSION_TWO_TO_THREE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 4
    )
    CONVERSION_THREE_TO_FOUR_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 5
    )
    CONVERSION_FOUR_TO_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 6
    )
    CONVERSION_FIVE_TO_SIX_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 7
    )
    CONVERSION_SIX_TO_SEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 8
    )
    CONVERSION_SEVEN_TO_EIGHT_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 9
    )
    CONVERSION_EIGHT_TO_NINE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 10
    )
    CONVERSION_NINE_TO_TEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 11
    )
    CONVERSION_TEN_TO_ELEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 12
    )
    CONVERSION_ELEVEN_TO_TWELVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 13
    )
    CONVERSION_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 14
    )
    CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 15
    )
    CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 16
    )
    CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 17
    )
    CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 18
    )
    CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 19
    )
    CONVERSION_SIXTY_TO_NINETY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 20
    )
    ADJUSTMENT_LESS_THAN_ONE_DAY = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 21
    )
    ADJUSTMENT_ONE_TO_TWO_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 22
    )
    ADJUSTMENT_TWO_TO_THREE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 23
    )
    ADJUSTMENT_THREE_TO_FOUR_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 24
    )
    ADJUSTMENT_FOUR_TO_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 25
    )
    ADJUSTMENT_FIVE_TO_SIX_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 26
    )
    ADJUSTMENT_SIX_TO_SEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 27
    )
    ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 28
    )
    ADJUSTMENT_EIGHT_TO_NINE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 29
    )
    ADJUSTMENT_NINE_TO_TEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 30
    )
    ADJUSTMENT_TEN_TO_ELEVEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 31
    )
    ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 32
    )
    ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 33
    )
    ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 34
    )
    ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 35
    )
    ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 36
    )
    ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 37
    )
    ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 38
    )
    ADJUSTMENT_SIXTY_TO_NINETY_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 39
    )
    ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 40
    )
    CONVERSION_UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 41
    )
    ADJUSTMENT_UNKNOWN = typing___cast(
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucketValue, 42
    )
    type___ConversionOrAdjustmentLagBucket = ConversionOrAdjustmentLagBucket
    def __init__(self,) -> None: ...

type___ConversionOrAdjustmentLagBucketEnum = ConversionOrAdjustmentLagBucketEnum
