# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateJobStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MutateJobStatusValue = typing___NewType("MutateJobStatusValue", builtin___int)
    type___MutateJobStatusValue = MutateJobStatusValue
    MutateJobStatus: _MutateJobStatus
    class _MutateJobStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MutateJobStatusEnum.MutateJobStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 0)
        UNKNOWN = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 1)
        PENDING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 2)
        RUNNING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 3)
        DONE = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 4)
    UNSPECIFIED = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 0)
    UNKNOWN = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 1)
    PENDING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 2)
    RUNNING = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 3)
    DONE = typing___cast(MutateJobStatusEnum.MutateJobStatusValue, 4)
    type___MutateJobStatus = MutateJobStatus
    def __init__(self,) -> None: ...

type___MutateJobStatusEnum = MutateJobStatusEnum
