# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DisplayUploadProductTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DisplayUploadProductTypeValue = typing___NewType(
        "DisplayUploadProductTypeValue", builtin___int
    )
    type___DisplayUploadProductTypeValue = DisplayUploadProductTypeValue
    DisplayUploadProductType: _DisplayUploadProductType
    class _DisplayUploadProductType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 0
        )
        UNKNOWN = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 1
        )
        HTML5_UPLOAD_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 2
        )
        DYNAMIC_HTML5_EDUCATION_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 3
        )
        DYNAMIC_HTML5_FLIGHT_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 4
        )
        DYNAMIC_HTML5_HOTEL_RENTAL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 5
        )
        DYNAMIC_HTML5_JOB_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 6
        )
        DYNAMIC_HTML5_LOCAL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 7
        )
        DYNAMIC_HTML5_REAL_ESTATE_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 8
        )
        DYNAMIC_HTML5_CUSTOM_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 9
        )
        DYNAMIC_HTML5_TRAVEL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 10
        )
        DYNAMIC_HTML5_HOTEL_AD = typing___cast(
            DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 11
        )
    UNSPECIFIED = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 0
    )
    UNKNOWN = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 1
    )
    HTML5_UPLOAD_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 2
    )
    DYNAMIC_HTML5_EDUCATION_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 3
    )
    DYNAMIC_HTML5_FLIGHT_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 4
    )
    DYNAMIC_HTML5_HOTEL_RENTAL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 5
    )
    DYNAMIC_HTML5_JOB_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 6
    )
    DYNAMIC_HTML5_LOCAL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 7
    )
    DYNAMIC_HTML5_REAL_ESTATE_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 8
    )
    DYNAMIC_HTML5_CUSTOM_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 9
    )
    DYNAMIC_HTML5_TRAVEL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 10
    )
    DYNAMIC_HTML5_HOTEL_AD = typing___cast(
        DisplayUploadProductTypeEnum.DisplayUploadProductTypeValue, 11
    )
    type___DisplayUploadProductType = DisplayUploadProductType
    def __init__(self,) -> None: ...

type___DisplayUploadProductTypeEnum = DisplayUploadProductTypeEnum
