from typing import Any

class FeedMappingServiceStub:
    GetFeedMapping: Any = ...
    MutateFeedMappings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedMappingServiceServicer:
    def GetFeedMapping(self, request: Any, context: Any) -> None: ...
    def MutateFeedMappings(self, request: Any, context: Any) -> None: ...

def add_FeedMappingServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
