from typing import Any

class CampaignFeedServiceStub:
    GetCampaignFeed: Any = ...
    MutateCampaignFeeds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignFeedServiceServicer:
    def GetCampaignFeed(self, request: Any, context: Any) -> None: ...
    def MutateCampaignFeeds(self, request: Any, context: Any) -> None: ...

def add_CampaignFeedServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
