# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TrackingCodeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TrackingCodeTypeValue = typing___NewType("TrackingCodeTypeValue", builtin___int)
    type___TrackingCodeTypeValue = TrackingCodeTypeValue
    TrackingCodeType: _TrackingCodeType
    class _TrackingCodeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TrackingCodeTypeEnum.TrackingCodeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 0)
        UNKNOWN = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 1)
        WEBPAGE = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 2)
        WEBPAGE_ONCLICK = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 3)
        CLICK_TO_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 4)
        WEBSITE_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 5)
    UNSPECIFIED = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 0)
    UNKNOWN = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 1)
    WEBPAGE = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 2)
    WEBPAGE_ONCLICK = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 3)
    CLICK_TO_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 4)
    WEBSITE_CALL = typing___cast(TrackingCodeTypeEnum.TrackingCodeTypeValue, 5)
    type___TrackingCodeType = TrackingCodeType
    def __init__(self,) -> None: ...

type___TrackingCodeTypeEnum = TrackingCodeTypeEnum
