# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FrequencyCapLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FrequencyCapLevelValue = typing___NewType("FrequencyCapLevelValue", builtin___int)
    type___FrequencyCapLevelValue = FrequencyCapLevelValue
    FrequencyCapLevel: _FrequencyCapLevel
    class _FrequencyCapLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FrequencyCapLevelEnum.FrequencyCapLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 0)
        UNKNOWN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 1)
        AD_GROUP_AD = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 2)
        AD_GROUP = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 3)
        CAMPAIGN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 4)
    UNSPECIFIED = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 0)
    UNKNOWN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 1)
    AD_GROUP_AD = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 2)
    AD_GROUP = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 3)
    CAMPAIGN = typing___cast(FrequencyCapLevelEnum.FrequencyCapLevelValue, 4)
    type___FrequencyCapLevel = FrequencyCapLevel
    def __init__(self,) -> None: ...

type___FrequencyCapLevelEnum = FrequencyCapLevelEnum
