# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OptimizationGoalTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OptimizationGoalTypeValue = typing___NewType(
        "OptimizationGoalTypeValue", builtin___int
    )
    type___OptimizationGoalTypeValue = OptimizationGoalTypeValue
    OptimizationGoalType: _OptimizationGoalType
    class _OptimizationGoalType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 0
        )
        UNKNOWN = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 1)
        CALL_CLICKS = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 2
        )
        DRIVING_DIRECTIONS = typing___cast(
            OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 3
        )
    UNSPECIFIED = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 0)
    UNKNOWN = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 1)
    CALL_CLICKS = typing___cast(OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 2)
    DRIVING_DIRECTIONS = typing___cast(
        OptimizationGoalTypeEnum.OptimizationGoalTypeValue, 3
    )
    type___OptimizationGoalType = OptimizationGoalType
    def __init__(self,) -> None: ...

type___OptimizationGoalTypeEnum = OptimizationGoalTypeEnum
