# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerMatchUploadKeyTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerMatchUploadKeyTypeValue = typing___NewType(
        "CustomerMatchUploadKeyTypeValue", builtin___int
    )
    type___CustomerMatchUploadKeyTypeValue = CustomerMatchUploadKeyTypeValue
    CustomerMatchUploadKeyType: _CustomerMatchUploadKeyType
    class _CustomerMatchUploadKeyType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 1
        )
        CONTACT_INFO = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 2
        )
        CRM_ID = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 3
        )
        MOBILE_ADVERTISING_ID = typing___cast(
            CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 4
        )
    UNSPECIFIED = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 0
    )
    UNKNOWN = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 1
    )
    CONTACT_INFO = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 2
    )
    CRM_ID = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 3
    )
    MOBILE_ADVERTISING_ID = typing___cast(
        CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyTypeValue, 4
    )
    type___CustomerMatchUploadKeyType = CustomerMatchUploadKeyType
    def __init__(self,) -> None: ...

type___CustomerMatchUploadKeyTypeEnum = CustomerMatchUploadKeyTypeEnum
