# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaFileErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaFileErrorValue = typing___NewType("MediaFileErrorValue", builtin___int)
    type___MediaFileErrorValue = MediaFileErrorValue
    MediaFileError: _MediaFileError
    class _MediaFileError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaFileErrorEnum.MediaFileErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 0)
        UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 1)
        CANNOT_CREATE_STANDARD_ICON = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 2
        )
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 3
        )
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 4
        )
        DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 5)
        EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 7
        )
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 8
        )
        INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 9)
        INVALID_MEDIA_SUB_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 10
        )
        INVALID_MEDIA_FILE_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 11
        )
        INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 12)
        INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 13)
        INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 14)
        MEDIA_FILE_FAILED_TRANSCODING = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 15
        )
        MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 17
        )
        NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 19
        )
        TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 20)
        UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 21)
        YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 22
        )
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 23
        )
        YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(
            MediaFileErrorEnum.MediaFileErrorValue, 24
        )
    UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 0)
    UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 1)
    CANNOT_CREATE_STANDARD_ICON = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 2
    )
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 3
    )
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 4
    )
    DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 5)
    EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 7
    )
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 8
    )
    INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 9)
    INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 10)
    INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 11)
    INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 12)
    INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 13)
    INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 14)
    MEDIA_FILE_FAILED_TRANSCODING = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 15
    )
    MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 17
    )
    NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 19
    )
    TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 20)
    UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 21)
    YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 22
    )
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(
        MediaFileErrorEnum.MediaFileErrorValue, 23
    )
    YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileErrorValue, 24)
    type___MediaFileError = MediaFileError
    def __init__(self,) -> None: ...

type___MediaFileErrorEnum = MediaFileErrorEnum
