# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PlaceholderTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PlaceholderTypeValue = typing___NewType("PlaceholderTypeValue", builtin___int)
    type___PlaceholderTypeValue = PlaceholderTypeValue
    PlaceholderType: _PlaceholderType
    class _PlaceholderType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PlaceholderTypeEnum.PlaceholderTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 0)
        UNKNOWN = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 1)
        SITELINK = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 2)
        CALL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 3)
        APP = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 4)
        LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 5)
        AFFILIATE_LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 6)
        CALLOUT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 7)
        STRUCTURED_SNIPPET = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 8)
        MESSAGE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 9)
        PRICE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 10)
        PROMOTION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 11)
        AD_CUSTOMIZER = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 12)
        DYNAMIC_EDUCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 13)
        DYNAMIC_FLIGHT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 14)
        DYNAMIC_CUSTOM = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 15)
        DYNAMIC_HOTEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 16)
        DYNAMIC_REAL_ESTATE = typing___cast(
            PlaceholderTypeEnum.PlaceholderTypeValue, 17
        )
        DYNAMIC_TRAVEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 18)
        DYNAMIC_LOCAL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 19)
        DYNAMIC_JOB = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 20)
    UNSPECIFIED = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 0)
    UNKNOWN = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 1)
    SITELINK = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 2)
    CALL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 3)
    APP = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 4)
    LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 5)
    AFFILIATE_LOCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 6)
    CALLOUT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 7)
    STRUCTURED_SNIPPET = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 8)
    MESSAGE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 9)
    PRICE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 10)
    PROMOTION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 11)
    AD_CUSTOMIZER = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 12)
    DYNAMIC_EDUCATION = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 13)
    DYNAMIC_FLIGHT = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 14)
    DYNAMIC_CUSTOM = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 15)
    DYNAMIC_HOTEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 16)
    DYNAMIC_REAL_ESTATE = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 17)
    DYNAMIC_TRAVEL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 18)
    DYNAMIC_LOCAL = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 19)
    DYNAMIC_JOB = typing___cast(PlaceholderTypeEnum.PlaceholderTypeValue, 20)
    type___PlaceholderType = PlaceholderType
    def __init__(self,) -> None: ...

type___PlaceholderTypeEnum = PlaceholderTypeEnum
