from typing import Any

class FeedPlaceholderViewServiceStub:
    GetFeedPlaceholderView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedPlaceholderViewServiceServicer:
    def GetFeedPlaceholderView(self, request: Any, context: Any) -> None: ...

def add_FeedPlaceholderViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
