from typing import Any

class UserDataServiceStub:
    UploadUserData: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserDataServiceServicer:
    def UploadUserData(self, request: Any, context: Any) -> None: ...

def add_UserDataServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
