from typing import Any

class GoogleAdsFieldServiceStub:
    GetGoogleAdsField: Any = ...
    SearchGoogleAdsFields: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GoogleAdsFieldServiceServicer:
    def GetGoogleAdsField(self, request: Any, context: Any) -> None: ...
    def SearchGoogleAdsFields(self, request: Any, context: Any) -> None: ...

def add_GoogleAdsFieldServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
