# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LeadFormFieldUserInputTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LeadFormFieldUserInputTypeValue = typing___NewType(
        "LeadFormFieldUserInputTypeValue", builtin___int
    )
    type___LeadFormFieldUserInputTypeValue = LeadFormFieldUserInputTypeValue
    LeadFormFieldUserInputType: _LeadFormFieldUserInputType
    class _LeadFormFieldUserInputType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 0
        )
        UNKNOWN = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1
        )
        FULL_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 2
        )
        GIVEN_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 6
        )
        FAMILY_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 7
        )
        EMAIL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 3
        )
        PHONE_NUMBER = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 4
        )
        POSTAL_CODE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 5
        )
        CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 9
        )
        REGION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 10
        )
        COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 11
        )
        WORK_EMAIL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 12
        )
        COMPANY_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 13
        )
        WORK_PHONE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 14
        )
        JOB_TITLE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 15
        )
        VEHICLE_MODEL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1001
        )
        VEHICLE_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1002
        )
        PREFERRED_DEALERSHIP = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1003
        )
        VEHICLE_PURCHASE_TIMELINE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1004
        )
        VEHICLE_OWNERSHIP = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1005
        )
        VEHICLE_PAYMENT_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1009
        )
        VEHICLE_CONDITION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1010
        )
        COMPANY_SIZE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1006
        )
        ANNUAL_SALES = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1007
        )
        YEARS_IN_BUSINESS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1008
        )
        JOB_DEPARTMENT = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1011
        )
        JOB_ROLE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1012
        )
        EDUCATION_PROGRAM = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1013
        )
        EDUCATION_COURSE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1014
        )
        PRODUCT = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1016
        )
        SERVICE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1017
        )
        OFFER = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1018
        )
        CATEGORY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1019
        )
        PREFERRED_CONTACT_METHOD = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1020
        )
        PREFERRED_LOCATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1021
        )
        PREFERRED_CONTACT_TIME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1022
        )
        PURCHASE_TIMELINE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1023
        )
        YEARS_OF_EXPERIENCE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1048
        )
        JOB_INDUSTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1049
        )
        LEVEL_OF_EDUCATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1050
        )
        PROPERTY_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1024
        )
        REALTOR_HELP_GOAL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1025
        )
        PROPERTY_COMMUNITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1026
        )
        PRICE_RANGE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1027
        )
        NUMBER_OF_BEDROOMS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1028
        )
        FURNISHED_PROPERTY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1029
        )
        PETS_ALLOWED_PROPERTY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1030
        )
        NEXT_PLANNED_PURCHASE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1031
        )
        EVENT_SIGNUP_INTEREST = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1033
        )
        PREFERRED_SHOPPING_PLACES = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1034
        )
        FAVORITE_BRAND = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1035
        )
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1036
        )
        EVENT_BOOKING_INTEREST = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1038
        )
        DESTINATION_COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1039
        )
        DESTINATION_CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1040
        )
        DEPARTURE_COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1041
        )
        DEPARTURE_CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1042
        )
        DEPARTURE_DATE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1043
        )
        RETURN_DATE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1044
        )
        NUMBER_OF_TRAVELERS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1045
        )
        TRAVEL_BUDGET = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1046
        )
        TRAVEL_ACCOMMODATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1047
        )
    UNSPECIFIED = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 0
    )
    UNKNOWN = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1
    )
    FULL_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 2
    )
    GIVEN_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 6
    )
    FAMILY_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 7
    )
    EMAIL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 3
    )
    PHONE_NUMBER = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 4
    )
    POSTAL_CODE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 5
    )
    CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 9
    )
    REGION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 10
    )
    COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 11
    )
    WORK_EMAIL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 12
    )
    COMPANY_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 13
    )
    WORK_PHONE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 14
    )
    JOB_TITLE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 15
    )
    VEHICLE_MODEL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1001
    )
    VEHICLE_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1002
    )
    PREFERRED_DEALERSHIP = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1003
    )
    VEHICLE_PURCHASE_TIMELINE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1004
    )
    VEHICLE_OWNERSHIP = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1005
    )
    VEHICLE_PAYMENT_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1009
    )
    VEHICLE_CONDITION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1010
    )
    COMPANY_SIZE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1006
    )
    ANNUAL_SALES = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1007
    )
    YEARS_IN_BUSINESS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1008
    )
    JOB_DEPARTMENT = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1011
    )
    JOB_ROLE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1012
    )
    EDUCATION_PROGRAM = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1013
    )
    EDUCATION_COURSE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1014
    )
    PRODUCT = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1016
    )
    SERVICE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1017
    )
    OFFER = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1018
    )
    CATEGORY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1019
    )
    PREFERRED_CONTACT_METHOD = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1020
    )
    PREFERRED_LOCATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1021
    )
    PREFERRED_CONTACT_TIME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1022
    )
    PURCHASE_TIMELINE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1023
    )
    YEARS_OF_EXPERIENCE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1048
    )
    JOB_INDUSTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1049
    )
    LEVEL_OF_EDUCATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1050
    )
    PROPERTY_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1024
    )
    REALTOR_HELP_GOAL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1025
    )
    PROPERTY_COMMUNITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1026
    )
    PRICE_RANGE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1027
    )
    NUMBER_OF_BEDROOMS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1028
    )
    FURNISHED_PROPERTY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1029
    )
    PETS_ALLOWED_PROPERTY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1030
    )
    NEXT_PLANNED_PURCHASE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1031
    )
    EVENT_SIGNUP_INTEREST = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1033
    )
    PREFERRED_SHOPPING_PLACES = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1034
    )
    FAVORITE_BRAND = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1035
    )
    TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1036
    )
    EVENT_BOOKING_INTEREST = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1038
    )
    DESTINATION_COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1039
    )
    DESTINATION_CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1040
    )
    DEPARTURE_COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1041
    )
    DEPARTURE_CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1042
    )
    DEPARTURE_DATE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1043
    )
    RETURN_DATE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1044
    )
    NUMBER_OF_TRAVELERS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1045
    )
    TRAVEL_BUDGET = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1046
    )
    TRAVEL_ACCOMMODATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1047
    )
    type___LeadFormFieldUserInputType = LeadFormFieldUserInputType
    def __init__(self,) -> None: ...

type___LeadFormFieldUserInputTypeEnum = LeadFormFieldUserInputTypeEnum
