from typing import Any

class AccountBudgetProposalServiceStub:
    GetAccountBudgetProposal: Any = ...
    MutateAccountBudgetProposal: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountBudgetProposalServiceServicer:
    def GetAccountBudgetProposal(self, request: Any, context: Any) -> None: ...
    def MutateAccountBudgetProposal(self, request: Any, context: Any) -> None: ...

def add_AccountBudgetProposalServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
