from typing import Any

class CampaignBidModifierServiceStub:
    GetCampaignBidModifier: Any = ...
    MutateCampaignBidModifiers: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignBidModifierServiceServicer:
    def GetCampaignBidModifier(self, request: Any, context: Any) -> None: ...
    def MutateCampaignBidModifiers(self, request: Any, context: Any) -> None: ...

def add_CampaignBidModifierServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
