# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.placement_type_pb2 import (
    PlacementTypeEnum as google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GroupPlacementView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    placement_type: google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum.PlacementTypeValue = ...
    @property
    def placement(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def display_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def target_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        placement: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        display_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        target_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        placement_type: typing___Optional[
            google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum.PlacementTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...

type___GroupPlacementView = GroupPlacementView
