# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BidModifierSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___BidModifierSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpcBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpvBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___TargetCpaSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class TargetRoasSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetRoasSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___TargetRoasSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___TargetRoasSimulationPointList = TargetRoasSimulationPointList

class PercentCpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PercentCpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___PercentCpcBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___PercentCpcBidSimulationPointList = PercentCpcBidSimulationPointList

class BidModifierSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    bid_modifier: builtin___float = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    parent_biddable_conversions: builtin___float = ...
    parent_biddable_conversions_value: builtin___float = ...
    parent_clicks: builtin___int = ...
    parent_cost_micros: builtin___int = ...
    parent_impressions: builtin___int = ...
    parent_top_slot_impressions: builtin___int = ...
    parent_required_budget_micros: builtin___int = ...
    def __init__(
        self,
        *,
        bid_modifier: typing___Optional[builtin___float] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
        parent_biddable_conversions: typing___Optional[builtin___float] = None,
        parent_biddable_conversions_value: typing___Optional[builtin___float] = None,
        parent_clicks: typing___Optional[builtin___int] = None,
        parent_cost_micros: typing___Optional[builtin___int] = None,
        parent_impressions: typing___Optional[builtin___int] = None,
        parent_top_slot_impressions: typing___Optional[builtin___int] = None,
        parent_required_budget_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_bid_modifier", b"_bid_modifier"],
    ) -> typing_extensions___Literal["bid_modifier"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_biddable_conversions", b"_parent_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["parent_biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_biddable_conversions_value", b"_parent_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["parent_biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_parent_clicks", b"_parent_clicks"],
    ) -> typing_extensions___Literal["parent_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_cost_micros", b"_parent_cost_micros"
        ],
    ) -> typing_extensions___Literal["parent_cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_impressions", b"_parent_impressions"
        ],
    ) -> typing_extensions___Literal["parent_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_required_budget_micros", b"_parent_required_budget_micros"
        ],
    ) -> typing_extensions___Literal["parent_required_budget_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_top_slot_impressions", b"_parent_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["parent_top_slot_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cpc_bid_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        cpc_bid_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions___Literal["cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cpv_bid_micros: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    views: builtin___int = ...
    def __init__(
        self,
        *,
        cpv_bid_micros: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        views: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions___Literal["cpv_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_views", b"_views"]
    ) -> typing_extensions___Literal["views"]: ...

type___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_cpa_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions___Literal["target_cpa_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___TargetCpaSimulationPoint = TargetCpaSimulationPoint

class TargetRoasSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_roas: builtin___float = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        target_roas: typing___Optional[builtin___float] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions___Literal["target_roas"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___TargetRoasSimulationPoint = TargetRoasSimulationPoint

class PercentCpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    percent_cpc_bid_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        percent_cpc_bid_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions___Literal["percent_cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___PercentCpcBidSimulationPoint = PercentCpcBidSimulationPoint
