# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdErrorValue = typing___NewType("AdErrorValue", builtin___int)
    type___AdErrorValue = AdErrorValue
    AdError: _AdError
    class _AdError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdErrorEnum.AdErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 0)
        UNKNOWN = typing___cast(AdErrorEnum.AdErrorValue, 1)
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 2
        )
        APPROXIMATELY_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 3)
        APPROXIMATELY_TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 4)
        BAD_SNIPPET = typing___cast(AdErrorEnum.AdErrorValue, 5)
        CANNOT_MODIFY_AD = typing___cast(AdErrorEnum.AdErrorValue, 6)
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET = typing___cast(AdErrorEnum.AdErrorValue, 7)
        CANNOT_SET_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 8)
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = typing___cast(
            AdErrorEnum.AdErrorValue, 9
        )
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = typing___cast(
            AdErrorEnum.AdErrorValue, 10
        )
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = typing___cast(
            AdErrorEnum.AdErrorValue, 11
        )
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = typing___cast(
            AdErrorEnum.AdErrorValue, 12
        )
        CANNOT_SET_URL = typing___cast(AdErrorEnum.AdErrorValue, 13)
        CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 14)
        CANNOT_SET_WITH_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 15)
        CANNOT_SET_WITH_URL_DATA = typing___cast(AdErrorEnum.AdErrorValue, 17)
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = typing___cast(
            AdErrorEnum.AdErrorValue, 18
        )
        CUSTOMER_NOT_APPROVED_MOBILEADS = typing___cast(AdErrorEnum.AdErrorValue, 19)
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = typing___cast(
            AdErrorEnum.AdErrorValue, 20
        )
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = typing___cast(
            AdErrorEnum.AdErrorValue, 21
        )
        CUSTOMER_NOT_ELIGIBLE = typing___cast(AdErrorEnum.AdErrorValue, 22)
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = typing___cast(
            AdErrorEnum.AdErrorValue, 23
        )
        DIMENSION_ALREADY_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 24)
        DIMENSION_MUST_BE_SET = typing___cast(AdErrorEnum.AdErrorValue, 25)
        DIMENSION_NOT_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 26)
        DISPLAY_URL_CANNOT_BE_SPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 27)
        DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 28)
        EMERGENCY_PHONE_NUMBER = typing___cast(AdErrorEnum.AdErrorValue, 29)
        EMPTY_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 30)
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 31
        )
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = typing___cast(
            AdErrorEnum.AdErrorValue, 32
        )
        ILLEGAL_AD_CUSTOMIZER_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 33)
        ILLEGAL_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 34)
        INCONSISTENT_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 35)
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION = typing___cast(
            AdErrorEnum.AdErrorValue, 36
        )
        INCORRECT_LENGTH = typing___cast(AdErrorEnum.AdErrorValue, 37)
        INELIGIBLE_FOR_UPGRADE = typing___cast(AdErrorEnum.AdErrorValue, 38)
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 39)
        INVALID_AD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 40)
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = typing___cast(
            AdErrorEnum.AdErrorValue, 41
        )
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 42)
        INVALID_CALL_TO_ACTION_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 43)
        INVALID_CHARACTER_FOR_URL = typing___cast(AdErrorEnum.AdErrorValue, 44)
        INVALID_COUNTRY_CODE = typing___cast(AdErrorEnum.AdErrorValue, 45)
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
            AdErrorEnum.AdErrorValue, 47
        )
        INVALID_INPUT = typing___cast(AdErrorEnum.AdErrorValue, 48)
        INVALID_MARKUP_LANGUAGE = typing___cast(AdErrorEnum.AdErrorValue, 49)
        INVALID_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 50)
        INVALID_MOBILE_CARRIER_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 51)
        INVALID_NUMBER_OF_ELEMENTS = typing___cast(AdErrorEnum.AdErrorValue, 52)
        INVALID_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 53)
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 54
        )
        INVALID_TEMPLATE_DATA = typing___cast(AdErrorEnum.AdErrorValue, 55)
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 56
        )
        INVALID_TEMPLATE_ID = typing___cast(AdErrorEnum.AdErrorValue, 57)
        LINE_TOO_WIDE = typing___cast(AdErrorEnum.AdErrorValue, 58)
        MISSING_AD_CUSTOMIZER_MAPPING = typing___cast(AdErrorEnum.AdErrorValue, 59)
        MISSING_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 60)
        MISSING_ADVERTISEMENT_NAME = typing___cast(AdErrorEnum.AdErrorValue, 61)
        MISSING_BUSINESS_NAME = typing___cast(AdErrorEnum.AdErrorValue, 62)
        MISSING_DESCRIPTION1 = typing___cast(AdErrorEnum.AdErrorValue, 63)
        MISSING_DESCRIPTION2 = typing___cast(AdErrorEnum.AdErrorValue, 64)
        MISSING_DESTINATION_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 65)
        MISSING_LANDING_PAGE_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 66)
        MISSING_DIMENSION = typing___cast(AdErrorEnum.AdErrorValue, 67)
        MISSING_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 68)
        MISSING_HEADLINE = typing___cast(AdErrorEnum.AdErrorValue, 69)
        MISSING_HEIGHT = typing___cast(AdErrorEnum.AdErrorValue, 70)
        MISSING_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 71)
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = typing___cast(
            AdErrorEnum.AdErrorValue, 72
        )
        MISSING_MARKUP_LANGUAGES = typing___cast(AdErrorEnum.AdErrorValue, 73)
        MISSING_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 74)
        MISSING_PHONE = typing___cast(AdErrorEnum.AdErrorValue, 75)
        MISSING_REQUIRED_TEMPLATE_FIELDS = typing___cast(AdErrorEnum.AdErrorValue, 76)
        MISSING_TEMPLATE_FIELD_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 77)
        MISSING_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 78)
        MISSING_VISIBLE_URL = typing___cast(AdErrorEnum.AdErrorValue, 79)
        MISSING_WIDTH = typing___cast(AdErrorEnum.AdErrorValue, 80)
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = typing___cast(
            AdErrorEnum.AdErrorValue, 81
        )
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD = typing___cast(AdErrorEnum.AdErrorValue, 82)
        TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 83)
        TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 84)
        UNION_DIMENSIONS_CANNOT_CHANGE = typing___cast(AdErrorEnum.AdErrorValue, 85)
        UNKNOWN_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 86)
        UNKNOWN_FIELD_NAME = typing___cast(AdErrorEnum.AdErrorValue, 87)
        UNKNOWN_UNIQUE_NAME = typing___cast(AdErrorEnum.AdErrorValue, 88)
        UNSUPPORTED_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 89)
        URL_INVALID_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 90)
        URL_INVALID_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 91)
        URL_MALFORMED = typing___cast(AdErrorEnum.AdErrorValue, 92)
        URL_NO_HOST = typing___cast(AdErrorEnum.AdErrorValue, 93)
        URL_NOT_EQUIVALENT = typing___cast(AdErrorEnum.AdErrorValue, 94)
        URL_HOST_NAME_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 95)
        URL_NO_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 96)
        URL_NO_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 97)
        URL_PATH_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 98)
        URL_PORT_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 99)
        URL_QUERY_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 100)
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
            AdErrorEnum.AdErrorValue, 102
        )
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = typing___cast(
            AdErrorEnum.AdErrorValue, 103
        )
        INCONSISTENT_EXPANDABLE_SETTINGS = typing___cast(AdErrorEnum.AdErrorValue, 104)
        INVALID_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 105)
        INVALID_FIELD_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 106)
        ELEMENT_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 107)
        IMAGE_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 108)
        VALUE_NOT_IN_RANGE = typing___cast(AdErrorEnum.AdErrorValue, 109)
        FIELD_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 110)
        ADDRESS_NOT_COMPLETE = typing___cast(AdErrorEnum.AdErrorValue, 111)
        ADDRESS_INVALID = typing___cast(AdErrorEnum.AdErrorValue, 112)
        VIDEO_RETRIEVAL_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 113)
        AUDIO_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 114)
        INVALID_YOUTUBE_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 115)
        TOO_MANY_PRODUCT_IMAGES = typing___cast(AdErrorEnum.AdErrorValue, 116)
        TOO_MANY_PRODUCT_VIDEOS = typing___cast(AdErrorEnum.AdErrorValue, 117)
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = typing___cast(
            AdErrorEnum.AdErrorValue, 118
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 119
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
            AdErrorEnum.AdErrorValue, 120
        )
        DISALLOWED_NUMBER_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 121)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 122
        )
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
            AdErrorEnum.AdErrorValue, 123
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 124)
        VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 125)
        INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(AdErrorEnum.AdErrorValue, 126)
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = typing___cast(
            AdErrorEnum.AdErrorValue, 127
        )
        CANNOT_SET_PATH2_WITHOUT_PATH1 = typing___cast(AdErrorEnum.AdErrorValue, 128)
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = typing___cast(
            AdErrorEnum.AdErrorValue, 129
        )
        INCOMPATIBLE_WITH_RESTRICTION_TYPE = typing___cast(
            AdErrorEnum.AdErrorValue, 130
        )
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
            AdErrorEnum.AdErrorValue, 131
        )
        MISSING_IMAGE_OR_MEDIA_BUNDLE = typing___cast(AdErrorEnum.AdErrorValue, 132)
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = typing___cast(
            AdErrorEnum.AdErrorValue, 133
        )
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 134
        )
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 135
        )
        PLACEHOLDER_DEFAULT_VALUE_MISSING = typing___cast(AdErrorEnum.AdErrorValue, 136)
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = typing___cast(
            AdErrorEnum.AdErrorValue, 137
        )
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = typing___cast(
            AdErrorEnum.AdErrorValue, 138
        )
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = typing___cast(
            AdErrorEnum.AdErrorValue, 139
        )
    UNSPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 0)
    UNKNOWN = typing___cast(AdErrorEnum.AdErrorValue, 1)
    AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = typing___cast(
        AdErrorEnum.AdErrorValue, 2
    )
    APPROXIMATELY_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 3)
    APPROXIMATELY_TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 4)
    BAD_SNIPPET = typing___cast(AdErrorEnum.AdErrorValue, 5)
    CANNOT_MODIFY_AD = typing___cast(AdErrorEnum.AdErrorValue, 6)
    CANNOT_SET_BUSINESS_NAME_IF_URL_SET = typing___cast(AdErrorEnum.AdErrorValue, 7)
    CANNOT_SET_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 8)
    CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = typing___cast(AdErrorEnum.AdErrorValue, 9)
    CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = typing___cast(
        AdErrorEnum.AdErrorValue, 10
    )
    CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = typing___cast(AdErrorEnum.AdErrorValue, 11)
    CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = typing___cast(
        AdErrorEnum.AdErrorValue, 12
    )
    CANNOT_SET_URL = typing___cast(AdErrorEnum.AdErrorValue, 13)
    CANNOT_SET_WITHOUT_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 14)
    CANNOT_SET_WITH_FINAL_URLS = typing___cast(AdErrorEnum.AdErrorValue, 15)
    CANNOT_SET_WITH_URL_DATA = typing___cast(AdErrorEnum.AdErrorValue, 17)
    CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = typing___cast(AdErrorEnum.AdErrorValue, 18)
    CUSTOMER_NOT_APPROVED_MOBILEADS = typing___cast(AdErrorEnum.AdErrorValue, 19)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = typing___cast(AdErrorEnum.AdErrorValue, 20)
    CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = typing___cast(
        AdErrorEnum.AdErrorValue, 21
    )
    CUSTOMER_NOT_ELIGIBLE = typing___cast(AdErrorEnum.AdErrorValue, 22)
    CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = typing___cast(
        AdErrorEnum.AdErrorValue, 23
    )
    DIMENSION_ALREADY_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 24)
    DIMENSION_MUST_BE_SET = typing___cast(AdErrorEnum.AdErrorValue, 25)
    DIMENSION_NOT_IN_UNION = typing___cast(AdErrorEnum.AdErrorValue, 26)
    DISPLAY_URL_CANNOT_BE_SPECIFIED = typing___cast(AdErrorEnum.AdErrorValue, 27)
    DOMESTIC_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 28)
    EMERGENCY_PHONE_NUMBER = typing___cast(AdErrorEnum.AdErrorValue, 29)
    EMPTY_FIELD = typing___cast(AdErrorEnum.AdErrorValue, 30)
    FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 31
    )
    FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = typing___cast(AdErrorEnum.AdErrorValue, 32)
    ILLEGAL_AD_CUSTOMIZER_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 33)
    ILLEGAL_TAG_USE = typing___cast(AdErrorEnum.AdErrorValue, 34)
    INCONSISTENT_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 35)
    INCONSISTENT_STATUS_IN_TEMPLATE_UNION = typing___cast(AdErrorEnum.AdErrorValue, 36)
    INCORRECT_LENGTH = typing___cast(AdErrorEnum.AdErrorValue, 37)
    INELIGIBLE_FOR_UPGRADE = typing___cast(AdErrorEnum.AdErrorValue, 38)
    INVALID_AD_ADDRESS_CAMPAIGN_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 39)
    INVALID_AD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 40)
    INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 41)
    INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 42)
    INVALID_CALL_TO_ACTION_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 43)
    INVALID_CHARACTER_FOR_URL = typing___cast(AdErrorEnum.AdErrorValue, 44)
    INVALID_COUNTRY_CODE = typing___cast(AdErrorEnum.AdErrorValue, 45)
    INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(AdErrorEnum.AdErrorValue, 47)
    INVALID_INPUT = typing___cast(AdErrorEnum.AdErrorValue, 48)
    INVALID_MARKUP_LANGUAGE = typing___cast(AdErrorEnum.AdErrorValue, 49)
    INVALID_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 50)
    INVALID_MOBILE_CARRIER_TARGET = typing___cast(AdErrorEnum.AdErrorValue, 51)
    INVALID_NUMBER_OF_ELEMENTS = typing___cast(AdErrorEnum.AdErrorValue, 52)
    INVALID_PHONE_NUMBER_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 53)
    INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 54
    )
    INVALID_TEMPLATE_DATA = typing___cast(AdErrorEnum.AdErrorValue, 55)
    INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 56)
    INVALID_TEMPLATE_ID = typing___cast(AdErrorEnum.AdErrorValue, 57)
    LINE_TOO_WIDE = typing___cast(AdErrorEnum.AdErrorValue, 58)
    MISSING_AD_CUSTOMIZER_MAPPING = typing___cast(AdErrorEnum.AdErrorValue, 59)
    MISSING_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 60)
    MISSING_ADVERTISEMENT_NAME = typing___cast(AdErrorEnum.AdErrorValue, 61)
    MISSING_BUSINESS_NAME = typing___cast(AdErrorEnum.AdErrorValue, 62)
    MISSING_DESCRIPTION1 = typing___cast(AdErrorEnum.AdErrorValue, 63)
    MISSING_DESCRIPTION2 = typing___cast(AdErrorEnum.AdErrorValue, 64)
    MISSING_DESTINATION_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 65)
    MISSING_LANDING_PAGE_URL_TAG = typing___cast(AdErrorEnum.AdErrorValue, 66)
    MISSING_DIMENSION = typing___cast(AdErrorEnum.AdErrorValue, 67)
    MISSING_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 68)
    MISSING_HEADLINE = typing___cast(AdErrorEnum.AdErrorValue, 69)
    MISSING_HEIGHT = typing___cast(AdErrorEnum.AdErrorValue, 70)
    MISSING_IMAGE = typing___cast(AdErrorEnum.AdErrorValue, 71)
    MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = typing___cast(
        AdErrorEnum.AdErrorValue, 72
    )
    MISSING_MARKUP_LANGUAGES = typing___cast(AdErrorEnum.AdErrorValue, 73)
    MISSING_MOBILE_CARRIER = typing___cast(AdErrorEnum.AdErrorValue, 74)
    MISSING_PHONE = typing___cast(AdErrorEnum.AdErrorValue, 75)
    MISSING_REQUIRED_TEMPLATE_FIELDS = typing___cast(AdErrorEnum.AdErrorValue, 76)
    MISSING_TEMPLATE_FIELD_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 77)
    MISSING_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 78)
    MISSING_VISIBLE_URL = typing___cast(AdErrorEnum.AdErrorValue, 79)
    MISSING_WIDTH = typing___cast(AdErrorEnum.AdErrorValue, 80)
    MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = typing___cast(AdErrorEnum.AdErrorValue, 81)
    MUST_USE_TEMP_AD_UNION_ID_ON_ADD = typing___cast(AdErrorEnum.AdErrorValue, 82)
    TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 83)
    TOO_SHORT = typing___cast(AdErrorEnum.AdErrorValue, 84)
    UNION_DIMENSIONS_CANNOT_CHANGE = typing___cast(AdErrorEnum.AdErrorValue, 85)
    UNKNOWN_ADDRESS_COMPONENT = typing___cast(AdErrorEnum.AdErrorValue, 86)
    UNKNOWN_FIELD_NAME = typing___cast(AdErrorEnum.AdErrorValue, 87)
    UNKNOWN_UNIQUE_NAME = typing___cast(AdErrorEnum.AdErrorValue, 88)
    UNSUPPORTED_DIMENSIONS = typing___cast(AdErrorEnum.AdErrorValue, 89)
    URL_INVALID_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 90)
    URL_INVALID_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 91)
    URL_MALFORMED = typing___cast(AdErrorEnum.AdErrorValue, 92)
    URL_NO_HOST = typing___cast(AdErrorEnum.AdErrorValue, 93)
    URL_NOT_EQUIVALENT = typing___cast(AdErrorEnum.AdErrorValue, 94)
    URL_HOST_NAME_TOO_LONG = typing___cast(AdErrorEnum.AdErrorValue, 95)
    URL_NO_SCHEME = typing___cast(AdErrorEnum.AdErrorValue, 96)
    URL_NO_TOP_LEVEL_DOMAIN = typing___cast(AdErrorEnum.AdErrorValue, 97)
    URL_PATH_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 98)
    URL_PORT_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 99)
    URL_QUERY_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 100)
    URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = typing___cast(
        AdErrorEnum.AdErrorValue, 102
    )
    USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = typing___cast(AdErrorEnum.AdErrorValue, 103)
    INCONSISTENT_EXPANDABLE_SETTINGS = typing___cast(AdErrorEnum.AdErrorValue, 104)
    INVALID_FORMAT = typing___cast(AdErrorEnum.AdErrorValue, 105)
    INVALID_FIELD_TEXT = typing___cast(AdErrorEnum.AdErrorValue, 106)
    ELEMENT_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 107)
    IMAGE_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 108)
    VALUE_NOT_IN_RANGE = typing___cast(AdErrorEnum.AdErrorValue, 109)
    FIELD_NOT_PRESENT = typing___cast(AdErrorEnum.AdErrorValue, 110)
    ADDRESS_NOT_COMPLETE = typing___cast(AdErrorEnum.AdErrorValue, 111)
    ADDRESS_INVALID = typing___cast(AdErrorEnum.AdErrorValue, 112)
    VIDEO_RETRIEVAL_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 113)
    AUDIO_ERROR = typing___cast(AdErrorEnum.AdErrorValue, 114)
    INVALID_YOUTUBE_DISPLAY_URL = typing___cast(AdErrorEnum.AdErrorValue, 115)
    TOO_MANY_PRODUCT_IMAGES = typing___cast(AdErrorEnum.AdErrorValue, 116)
    TOO_MANY_PRODUCT_VIDEOS = typing___cast(AdErrorEnum.AdErrorValue, 117)
    INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = typing___cast(
        AdErrorEnum.AdErrorValue, 118
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 119
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = typing___cast(
        AdErrorEnum.AdErrorValue, 120
    )
    DISALLOWED_NUMBER_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 121)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 122
    )
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = typing___cast(
        AdErrorEnum.AdErrorValue, 123
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 124)
    VANITY_PHONE_NUMBER_NOT_ALLOWED = typing___cast(AdErrorEnum.AdErrorValue, 125)
    INVALID_CALL_CONVERSION_TYPE_ID = typing___cast(AdErrorEnum.AdErrorValue, 126)
    CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = typing___cast(
        AdErrorEnum.AdErrorValue, 127
    )
    CANNOT_SET_PATH2_WITHOUT_PATH1 = typing___cast(AdErrorEnum.AdErrorValue, 128)
    MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = typing___cast(
        AdErrorEnum.AdErrorValue, 129
    )
    INCOMPATIBLE_WITH_RESTRICTION_TYPE = typing___cast(AdErrorEnum.AdErrorValue, 130)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = typing___cast(
        AdErrorEnum.AdErrorValue, 131
    )
    MISSING_IMAGE_OR_MEDIA_BUNDLE = typing___cast(AdErrorEnum.AdErrorValue, 132)
    PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = typing___cast(
        AdErrorEnum.AdErrorValue, 133
    )
    PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = typing___cast(
        AdErrorEnum.AdErrorValue, 134
    )
    PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = typing___cast(
        AdErrorEnum.AdErrorValue, 135
    )
    PLACEHOLDER_DEFAULT_VALUE_MISSING = typing___cast(AdErrorEnum.AdErrorValue, 136)
    UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = typing___cast(AdErrorEnum.AdErrorValue, 137)
    AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = typing___cast(AdErrorEnum.AdErrorValue, 138)
    UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = typing___cast(
        AdErrorEnum.AdErrorValue, 139
    )
    type___AdError = AdError
    def __init__(self,) -> None: ...

type___AdErrorEnum = AdErrorEnum
