from typing import Any

class VideoServiceStub:
    GetVideo: Any = ...
    def __init__(self, channel: Any) -> None: ...

class VideoServiceServicer:
    def GetVideo(self, request: Any, context: Any) -> None: ...

def add_VideoServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
