from typing import Any

class GeoTargetConstantServiceStub:
    GetGeoTargetConstant: Any = ...
    SuggestGeoTargetConstants: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GeoTargetConstantServiceServicer:
    def GetGeoTargetConstant(self, request: Any, context: Any) -> None: ...
    def SuggestGeoTargetConstants(self, request: Any, context: Any) -> None: ...

def add_GeoTargetConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
