from typing import Any

class UserLocationViewServiceStub:
    GetUserLocationView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserLocationViewServiceServicer:
    def GetUserLocationView(self, request: Any, context: Any) -> None: ...

def add_UserLocationViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
