from typing import Any

class LandingPageViewServiceStub:
    GetLandingPageView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LandingPageViewServiceServicer:
    def GetLandingPageView(self, request: Any, context: Any) -> None: ...

def add_LandingPageViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
