from typing import Any

class CustomerClientLinkServiceStub:
    GetCustomerClientLink: Any = ...
    MutateCustomerClientLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientLinkServiceServicer:
    def GetCustomerClientLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerClientLink(self, request: Any, context: Any) -> None: ...

def add_CustomerClientLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
