# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExtensionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ExtensionTypeValue = typing___NewType("ExtensionTypeValue", builtin___int)
    type___ExtensionTypeValue = ExtensionTypeValue
    ExtensionType: _ExtensionType
    class _ExtensionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ExtensionTypeEnum.ExtensionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 0)
        UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 1)
        NONE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 2)
        APP = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 3)
        CALL = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 4)
        CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 5)
        MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 6)
        PRICE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 7)
        PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 8)
        SITELINK = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 10)
        STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 11)
        LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 12)
        AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 13)
        HOTEL_CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 15)
        IMAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 16)
    UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 0)
    UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 1)
    NONE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 2)
    APP = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 3)
    CALL = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 4)
    CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 5)
    MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 6)
    PRICE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 7)
    PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 8)
    SITELINK = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 10)
    STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 11)
    LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 12)
    AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 13)
    HOTEL_CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 15)
    IMAGE = typing___cast(ExtensionTypeEnum.ExtensionTypeValue, 16)
    type___ExtensionType = ExtensionType
    def __init__(self,) -> None: ...

type___ExtensionTypeEnum = ExtensionTypeEnum
