# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MonthOfYearEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MonthOfYearValue = typing___NewType("MonthOfYearValue", builtin___int)
    type___MonthOfYearValue = MonthOfYearValue
    MonthOfYear: _MonthOfYear
    class _MonthOfYear(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MonthOfYearEnum.MonthOfYearValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYearValue, 0)
        UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYearValue, 1)
        JANUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 2)
        FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 3)
        MARCH = typing___cast(MonthOfYearEnum.MonthOfYearValue, 4)
        APRIL = typing___cast(MonthOfYearEnum.MonthOfYearValue, 5)
        MAY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 6)
        JUNE = typing___cast(MonthOfYearEnum.MonthOfYearValue, 7)
        JULY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 8)
        AUGUST = typing___cast(MonthOfYearEnum.MonthOfYearValue, 9)
        SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 10)
        OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 11)
        NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 12)
        DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 13)
    UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYearValue, 0)
    UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYearValue, 1)
    JANUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 2)
    FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 3)
    MARCH = typing___cast(MonthOfYearEnum.MonthOfYearValue, 4)
    APRIL = typing___cast(MonthOfYearEnum.MonthOfYearValue, 5)
    MAY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 6)
    JUNE = typing___cast(MonthOfYearEnum.MonthOfYearValue, 7)
    JULY = typing___cast(MonthOfYearEnum.MonthOfYearValue, 8)
    AUGUST = typing___cast(MonthOfYearEnum.MonthOfYearValue, 9)
    SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 10)
    OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 11)
    NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 12)
    DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYearValue, 13)
    type___MonthOfYear = MonthOfYear
    def __init__(self,) -> None: ...

type___MonthOfYearEnum = MonthOfYearEnum
