from typing import Any

class AdGroupCriterionServiceStub:
    GetAdGroupCriterion: Any = ...
    MutateAdGroupCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupCriterionServiceServicer:
    def GetAdGroupCriterion(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupCriteria(self, request: Any, context: Any) -> None: ...

def add_AdGroupCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
