# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2 import (
    ProductBiddingCategoryLevelEnum as google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum,
)
from google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2 import (
    ProductBiddingCategoryStatusEnum as google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductBiddingCategoryConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    country_code: typing___Text = ...
    product_bidding_category_constant_parent: typing___Text = ...
    level: google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue = ...
    status: google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatusValue = ...
    language_code: typing___Text = ...
    localized_name: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        country_code: typing___Optional[typing___Text] = None,
        product_bidding_category_constant_parent: typing___Optional[
            typing___Text
        ] = None,
        level: typing___Optional[
            google___ads___googleads___v6___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___product_bidding_category_status_pb2___ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatusValue
        ] = None,
        language_code: typing___Optional[typing___Text] = None,
        localized_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "level",
            b"level",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_country_code", b"_country_code"],
    ) -> typing_extensions___Literal["country_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_language_code", b"_language_code"],
    ) -> typing_extensions___Literal["language_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_localized_name", b"_localized_name"],
    ) -> typing_extensions___Literal["localized_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
        ],
    ) -> typing_extensions___Literal["product_bidding_category_constant_parent"]: ...

type___ProductBiddingCategoryConstant = ProductBiddingCategoryConstant
