from typing import Any

class UserInterestServiceStub:
    GetUserInterest: Any = ...
    def __init__(self, channel: Any) -> None: ...

class UserInterestServiceServicer:
    def GetUserInterest(self, request: Any, context: Any) -> None: ...

def add_UserInterestServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
