from typing import Any

class TopicViewServiceStub:
    GetTopicView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class TopicViewServiceServicer:
    def GetTopicView(self, request: Any, context: Any) -> None: ...

def add_TopicViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
