# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TargetingDimensionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TargetingDimensionValue = typing___NewType("TargetingDimensionValue", builtin___int)
    type___TargetingDimensionValue = TargetingDimensionValue
    TargetingDimension: _TargetingDimension
    class _TargetingDimension(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TargetingDimensionEnum.TargetingDimensionValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 0)
        UNKNOWN = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 1)
        KEYWORD = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 2)
        AUDIENCE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 3)
        TOPIC = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 4)
        GENDER = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 5)
        AGE_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 6)
        PLACEMENT = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 7)
        PARENTAL_STATUS = typing___cast(
            TargetingDimensionEnum.TargetingDimensionValue, 8
        )
        INCOME_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 9)
    UNSPECIFIED = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 0)
    UNKNOWN = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 1)
    KEYWORD = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 2)
    AUDIENCE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 3)
    TOPIC = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 4)
    GENDER = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 5)
    AGE_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 6)
    PLACEMENT = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 7)
    PARENTAL_STATUS = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 8)
    INCOME_RANGE = typing___cast(TargetingDimensionEnum.TargetingDimensionValue, 9)
    type___TargetingDimension = TargetingDimension
    def __init__(self,) -> None: ...

type___TargetingDimensionEnum = TargetingDimensionEnum
