from typing import Any

class DetailPlacementViewServiceStub:
    GetDetailPlacementView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DetailPlacementViewServiceServicer:
    def GetDetailPlacementView(self, request: Any, context: Any) -> None: ...

def add_DetailPlacementViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
