# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AppPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AppPlaceholderFieldValue = typing___NewType(
        "AppPlaceholderFieldValue", builtin___int
    )
    type___AppPlaceholderFieldValue = AppPlaceholderFieldValue
    AppPlaceholderField: _AppPlaceholderField
    class _AppPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 0)
        UNKNOWN = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 1)
        STORE = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 2)
        ID = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 3)
        LINK_TEXT = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 4)
        URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 5)
        FINAL_URLS = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 6)
        FINAL_MOBILE_URLS = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 7
        )
        TRACKING_URL = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 8
        )
        FINAL_URL_SUFFIX = typing___cast(
            AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 9
        )
    UNSPECIFIED = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 1)
    STORE = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 2)
    ID = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 3)
    LINK_TEXT = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 4)
    URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 5)
    FINAL_URLS = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 6)
    FINAL_MOBILE_URLS = typing___cast(
        AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 7
    )
    TRACKING_URL = typing___cast(AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 8)
    FINAL_URL_SUFFIX = typing___cast(
        AppPlaceholderFieldEnum.AppPlaceholderFieldValue, 9
    )
    type___AppPlaceholderField = AppPlaceholderField
    def __init__(self,) -> None: ...

type___AppPlaceholderFieldEnum = AppPlaceholderFieldEnum
