# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListAccessStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListAccessStatusValue = typing___NewType(
        "UserListAccessStatusValue", builtin___int
    )
    type___UserListAccessStatusValue = UserListAccessStatusValue
    UserListAccessStatus: _UserListAccessStatus
    class _UserListAccessStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListAccessStatusEnum.UserListAccessStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            UserListAccessStatusEnum.UserListAccessStatusValue, 0
        )
        UNKNOWN = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 1)
        ENABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 2)
        DISABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 3)
    UNSPECIFIED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 0)
    UNKNOWN = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 1)
    ENABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 2)
    DISABLED = typing___cast(UserListAccessStatusEnum.UserListAccessStatusValue, 3)
    type___UserListAccessStatus = UserListAccessStatus
    def __init__(self,) -> None: ...

type___UserListAccessStatusEnum = UserListAccessStatusEnum
