from typing import Any

class CampaignExtensionSettingServiceStub:
    GetCampaignExtensionSetting: Any = ...
    MutateCampaignExtensionSettings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignExtensionSettingServiceServicer:
    def GetCampaignExtensionSetting(self, request: Any, context: Any) -> None: ...
    def MutateCampaignExtensionSettings(self, request: Any, context: Any) -> None: ...

def add_CampaignExtensionSettingServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
