# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PromotionPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PromotionPlaceholderFieldValue = typing___NewType(
        "PromotionPlaceholderFieldValue", builtin___int
    )
    type___PromotionPlaceholderFieldValue = PromotionPlaceholderFieldValue
    PromotionPlaceholderField: _PromotionPlaceholderField
    class _PromotionPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 1
        )
        PROMOTION_TARGET = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 2
        )
        DISCOUNT_MODIFIER = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 3
        )
        PERCENT_OFF = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 4
        )
        MONEY_AMOUNT_OFF = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 5
        )
        PROMOTION_CODE = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 6
        )
        ORDERS_OVER_AMOUNT = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 7
        )
        PROMOTION_START = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 8
        )
        PROMOTION_END = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 9
        )
        OCCASION = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 10
        )
        FINAL_URLS = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 11
        )
        FINAL_MOBILE_URLS = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 12
        )
        TRACKING_URL = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 13
        )
        LANGUAGE = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 14
        )
        FINAL_URL_SUFFIX = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 15
        )
    UNSPECIFIED = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 1
    )
    PROMOTION_TARGET = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 2
    )
    DISCOUNT_MODIFIER = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 3
    )
    PERCENT_OFF = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 4
    )
    MONEY_AMOUNT_OFF = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 5
    )
    PROMOTION_CODE = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 6
    )
    ORDERS_OVER_AMOUNT = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 7
    )
    PROMOTION_START = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 8
    )
    PROMOTION_END = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 9
    )
    OCCASION = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 10
    )
    FINAL_URLS = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 11
    )
    FINAL_MOBILE_URLS = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 12
    )
    TRACKING_URL = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 13
    )
    LANGUAGE = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 14
    )
    FINAL_URL_SUFFIX = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 15
    )
    type___PromotionPlaceholderField = PromotionPlaceholderField
    def __init__(self,) -> None: ...

type___PromotionPlaceholderFieldEnum = PromotionPlaceholderFieldEnum
