from typing import Any

class LocationViewServiceStub:
    GetLocationView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LocationViewServiceServicer:
    def GetLocationView(self, request: Any, context: Any) -> None: ...

def add_LocationViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
