# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TravelPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TravelPlaceholderFieldValue = typing___NewType(
        "TravelPlaceholderFieldValue", builtin___int
    )
    type___TravelPlaceholderFieldValue = TravelPlaceholderFieldValue
    TravelPlaceholderField: _TravelPlaceholderField
    class _TravelPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 1
        )
        DESTINATION_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 2
        )
        ORIGIN_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 3
        )
        TITLE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 4)
        DESTINATION_NAME = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 5
        )
        ORIGIN_NAME = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 6
        )
        PRICE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 7)
        FORMATTED_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 8
        )
        SALE_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 9
        )
        FORMATTED_SALE_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 10
        )
        IMAGE_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 11
        )
        CATEGORY = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 12
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 13
        )
        DESTINATION_ADDRESS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 14
        )
        FINAL_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 15
        )
        FINAL_MOBILE_URLS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 16
        )
        TRACKING_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 17
        )
        ANDROID_APP_LINK = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 18
        )
        SIMILAR_DESTINATION_IDS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 19
        )
        IOS_APP_LINK = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 20
        )
        IOS_APP_STORE_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 21
        )
    UNSPECIFIED = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 1)
    DESTINATION_ID = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 2
    )
    ORIGIN_ID = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 3)
    TITLE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 4)
    DESTINATION_NAME = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 5
    )
    ORIGIN_NAME = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 6
    )
    PRICE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 7)
    FORMATTED_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 8
    )
    SALE_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 9
    )
    FORMATTED_SALE_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 10
    )
    IMAGE_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 11
    )
    CATEGORY = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 12)
    CONTEXTUAL_KEYWORDS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 13
    )
    DESTINATION_ADDRESS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 14
    )
    FINAL_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 15
    )
    FINAL_MOBILE_URLS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 16
    )
    TRACKING_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 17
    )
    ANDROID_APP_LINK = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 18
    )
    SIMILAR_DESTINATION_IDS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 19
    )
    IOS_APP_LINK = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 20
    )
    IOS_APP_STORE_ID = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 21
    )
    type___TravelPlaceholderField = TravelPlaceholderField
    def __init__(self,) -> None: ...

type___TravelPlaceholderFieldEnum = TravelPlaceholderFieldEnum
