from typing import Any

class FeedItemTargetServiceStub:
    GetFeedItemTarget: Any = ...
    MutateFeedItemTargets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedItemTargetServiceServicer:
    def GetFeedItemTarget(self, request: Any, context: Any) -> None: ...
    def MutateFeedItemTargets(self, request: Any, context: Any) -> None: ...

def add_FeedItemTargetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
