from typing import Any

class CurrencyConstantServiceStub:
    GetCurrencyConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CurrencyConstantServiceServicer:
    def GetCurrencyConstant(self, request: Any, context: Any) -> None: ...

def add_CurrencyConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
