# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListSizeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListSizeRangeValue = typing___NewType("UserListSizeRangeValue", builtin___int)
    type___UserListSizeRangeValue = UserListSizeRangeValue
    UserListSizeRange: _UserListSizeRange
    class _UserListSizeRange(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListSizeRangeEnum.UserListSizeRangeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 0)
        UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 1)
        LESS_THAN_FIVE_HUNDRED = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 2
        )
        LESS_THAN_ONE_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 3
        )
        ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 4
        )
        TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 5
        )
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 6
        )
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 7
        )
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 8
        )
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 9
        )
        ONE_MILLION_TO_TWO_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 10
        )
        TWO_MILLION_TO_THREE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 11
        )
        THREE_MILLION_TO_FIVE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 12
        )
        FIVE_MILLION_TO_TEN_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 13
        )
        TEN_MILLION_TO_TWENTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 14
        )
        TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 15
        )
        THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 16
        )
        OVER_FIFTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 17
        )
    UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 0)
    UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 1)
    LESS_THAN_FIVE_HUNDRED = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 2
    )
    LESS_THAN_ONE_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 3
    )
    ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 4
    )
    TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 5
    )
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 6
    )
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 7
    )
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 8
    )
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 9
    )
    ONE_MILLION_TO_TWO_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 10
    )
    TWO_MILLION_TO_THREE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 11
    )
    THREE_MILLION_TO_FIVE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 12
    )
    FIVE_MILLION_TO_TEN_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 13
    )
    TEN_MILLION_TO_TWENTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 14
    )
    TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 15
    )
    THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 16
    )
    OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 17)
    type___UserListSizeRange = UserListSizeRange
    def __init__(self,) -> None: ...

type___UserListSizeRangeEnum = UserListSizeRangeEnum
