# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.resources.batch_job_pb2 import (
    BatchJob as google___ads___googleads___v6___resources___batch_job_pb2___BatchJob,
)
from google.ads.google_ads.v6.proto.services.google_ads_service_pb2 import (
    MutateOperation as google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation,
    MutateOperationResponse as google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operation(self) -> type___BatchJobOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operation: typing___Optional[type___BatchJobOperation] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["operation", b"operation"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

type___MutateBatchJobRequest = MutateBatchJobRequest

class BatchJobOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v6___resources___batch_job_pb2___BatchJob: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v6___resources___batch_job_pb2___BatchJob
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create"]: ...

type___BatchJobOperation = BatchJobOperation

class MutateBatchJobResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def result(self) -> type___MutateBatchJobResult: ...
    def __init__(
        self, *, result: typing___Optional[type___MutateBatchJobResult] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> None: ...

type___MutateBatchJobResponse = MutateBatchJobResponse

class MutateBatchJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateBatchJobResult = MutateBatchJobResult

class GetBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetBatchJobRequest = GetBatchJobRequest

class RunBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___RunBatchJobRequest = RunBatchJobRequest

class AddBatchJobOperationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    sequence_token: typing___Text = ...
    @property
    def mutate_operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        sequence_token: typing___Optional[typing___Text] = None,
        mutate_operations: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operations",
            b"mutate_operations",
            "resource_name",
            b"resource_name",
            "sequence_token",
            b"sequence_token",
        ],
    ) -> None: ...

type___AddBatchJobOperationsRequest = AddBatchJobOperationsRequest

class AddBatchJobOperationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    total_operations: builtin___int = ...
    next_sequence_token: typing___Text = ...
    def __init__(
        self,
        *,
        total_operations: typing___Optional[builtin___int] = None,
        next_sequence_token: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_sequence_token",
            b"next_sequence_token",
            "total_operations",
            b"total_operations",
        ],
    ) -> None: ...

type___AddBatchJobOperationsResponse = AddBatchJobOperationsResponse

class ListBatchJobResultsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    page_token: typing___Text = ...
    page_size: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        page_token: typing___Optional[typing___Text] = None,
        page_size: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___ListBatchJobResultsRequest = ListBatchJobResultsRequest

class ListBatchJobResultsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token: typing___Text = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___BatchJobResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[typing___Iterable[type___BatchJobResult]] = None,
        next_page_token: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_page_token", b"next_page_token", "results", b"results"
        ],
    ) -> None: ...

type___ListBatchJobResultsResponse = ListBatchJobResultsResponse

class BatchJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operation_index: builtin___int = ...
    @property
    def mutate_operation_response(
        self,
    ) -> google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse: ...
    @property
    def status(self) -> google___rpc___status_pb2___Status: ...
    def __init__(
        self,
        *,
        operation_index: typing___Optional[builtin___int] = None,
        mutate_operation_response: typing___Optional[
            google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse
        ] = None,
        status: typing___Optional[google___rpc___status_pb2___Status] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "status",
            b"status",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "operation_index",
            b"operation_index",
            "status",
            b"status",
        ],
    ) -> None: ...

type___BatchJobResult = BatchJobResult
