# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupErrorValue = typing___NewType("AdGroupErrorValue", builtin___int)
    type___AdGroupErrorValue = AdGroupErrorValue
    AdGroupError: _AdGroupError
    class _AdGroupError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupErrorEnum.AdGroupErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 0)
        UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 1)
        DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 2)
        INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 3)
        ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 5
        )
        BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 6)
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 7
        )
        MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 8)
        ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 9
        )
        ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 10
        )
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 11
        )
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 12
        )
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 13
        )
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 14
        )
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
            AdGroupErrorEnum.AdGroupErrorValue, 15
        )
    UNSPECIFIED = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 0)
    UNKNOWN = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 1)
    DUPLICATE_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 2)
    INVALID_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 3)
    ADVERTISER_NOT_ON_CONTENT_NETWORK = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 5
    )
    BID_TOO_BIG = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 6)
    BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 7
    )
    MISSING_ADGROUP_NAME = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 8)
    ADGROUP_LABEL_DOES_NOT_EXIST = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 9)
    ADGROUP_LABEL_ALREADY_EXISTS = typing___cast(AdGroupErrorEnum.AdGroupErrorValue, 10)
    INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 11
    )
    AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 12
    )
    ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 13
    )
    CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 14
    )
    PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(
        AdGroupErrorEnum.AdGroupErrorValue, 15
    )
    type___AdGroupError = AdGroupError
    def __init__(self,) -> None: ...

type___AdGroupErrorEnum = AdGroupErrorEnum
