# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetPerformanceLabelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetPerformanceLabelValue = typing___NewType(
        "AssetPerformanceLabelValue", builtin___int
    )
    type___AssetPerformanceLabelValue = AssetPerformanceLabelValue
    AssetPerformanceLabel: _AssetPerformanceLabel
    class _AssetPerformanceLabel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 0
        )
        UNKNOWN = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 1)
        PENDING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 2)
        LEARNING = typing___cast(
            AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 3
        )
        LOW = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 4)
        GOOD = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 5)
        BEST = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 6)
    UNSPECIFIED = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 0)
    UNKNOWN = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 1)
    PENDING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 2)
    LEARNING = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 3)
    LOW = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 4)
    GOOD = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 5)
    BEST = typing___cast(AssetPerformanceLabelEnum.AssetPerformanceLabelValue, 6)
    type___AssetPerformanceLabel = AssetPerformanceLabel
    def __init__(self,) -> None: ...

type___AssetPerformanceLabelEnum = AssetPerformanceLabelEnum
