# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.offline_user_data_pb2 import (
    CustomerMatchUserListMetadata as google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata,
    StoreSalesMetadata as google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_failure_reason_pb2 import (
    OfflineUserDataJobFailureReasonEnum as google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_status_pb2 import (
    OfflineUserDataJobStatusEnum as google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.offline_user_data_job_type_pb2 import (
    OfflineUserDataJobTypeEnum as google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserDataJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    type: google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum.OfflineUserDataJobTypeValue = ...
    status: google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum.OfflineUserDataJobStatusValue = ...
    failure_reason: google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReasonValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def external_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata: ...
    @property
    def store_sales_metadata(
        self,
    ) -> google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        external_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_type_pb2___OfflineUserDataJobTypeEnum.OfflineUserDataJobTypeValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_status_pb2___OfflineUserDataJobStatusEnum.OfflineUserDataJobStatusValue
        ] = None,
        failure_reason: typing___Optional[
            google___ads___googleads___v3___enums___offline_user_data_job_failure_reason_pb2___OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReasonValue
        ] = None,
        customer_match_user_list_metadata: typing___Optional[
            google___ads___googleads___v3___common___offline_user_data_pb2___CustomerMatchUserListMetadata
        ] = None,
        store_sales_metadata: typing___Optional[
            google___ads___googleads___v3___common___offline_user_data_pb2___StoreSalesMetadata
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "store_sales_metadata",
            b"store_sales_metadata",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "external_id",
            b"external_id",
            "failure_reason",
            b"failure_reason",
            "id",
            b"id",
            "metadata",
            b"metadata",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "store_sales_metadata",
            b"store_sales_metadata",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["metadata", b"metadata"]
    ) -> typing_extensions___Literal[
        "customer_match_user_list_metadata", "store_sales_metadata"
    ]: ...

type___OfflineUserDataJob = OfflineUserDataJob
