from typing import Any

class MediaFileServiceStub:
    GetMediaFile: Any = ...
    MutateMediaFiles: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MediaFileServiceServicer:
    def GetMediaFile(self, request: Any, context: Any) -> None: ...
    def MutateMediaFiles(self, request: Any, context: Any) -> None: ...

def add_MediaFileServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
