# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def search_term(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def headline(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def landing_page(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def page_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def has_negative_keyword(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_matching_keyword(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_negative_url(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        search_term: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        headline: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        landing_page: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        page_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        has_negative_keyword: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_matching_keyword: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_negative_url: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

type___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView
