from typing import Any

class ShoppingPerformanceViewServiceStub:
    GetShoppingPerformanceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ShoppingPerformanceViewServiceServicer:
    def GetShoppingPerformanceView(self, request: Any, context: Any) -> None: ...

def add_ShoppingPerformanceViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
