# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2 import (
    FeedItemSetStringFilterTypeEnum as google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DynamicLocationSetFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    labels: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def business_name_filter(self) -> type___BusinessNameFilter: ...
    def __init__(
        self,
        *,
        labels: typing___Optional[typing___Iterable[typing___Text]] = None,
        business_name_filter: typing___Optional[type___BusinessNameFilter] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "business_name_filter", b"business_name_filter"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "business_name_filter", b"business_name_filter", "labels", b"labels"
        ],
    ) -> None: ...

type___DynamicLocationSetFilter = DynamicLocationSetFilter

class BusinessNameFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    business_name: typing___Text = ...
    filter_type: google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterTypeValue = ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[typing___Text] = None,
        filter_type: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "business_name", b"business_name", "filter_type", b"filter_type"
        ],
    ) -> None: ...

type___BusinessNameFilter = BusinessNameFilter

class DynamicAffiliateLocationSetFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    chain_ids: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        builtin___int
    ] = ...
    def __init__(
        self, *, chain_ids: typing___Optional[typing___Iterable[builtin___int]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["chain_ids", b"chain_ids"]
    ) -> None: ...

type___DynamicAffiliateLocationSetFilter = DynamicAffiliateLocationSetFilter
