# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResponseContentTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResponseContentTypeValue = typing___NewType(
        "ResponseContentTypeValue", builtin___int
    )
    type___ResponseContentTypeValue = ResponseContentTypeValue
    ResponseContentType: _ResponseContentType
    class _ResponseContentType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ResponseContentTypeEnum.ResponseContentTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ResponseContentTypeEnum.ResponseContentTypeValue, 0)
        RESOURCE_NAME_ONLY = typing___cast(
            ResponseContentTypeEnum.ResponseContentTypeValue, 1
        )
        MUTABLE_RESOURCE = typing___cast(
            ResponseContentTypeEnum.ResponseContentTypeValue, 2
        )
    UNSPECIFIED = typing___cast(ResponseContentTypeEnum.ResponseContentTypeValue, 0)
    RESOURCE_NAME_ONLY = typing___cast(
        ResponseContentTypeEnum.ResponseContentTypeValue, 1
    )
    MUTABLE_RESOURCE = typing___cast(
        ResponseContentTypeEnum.ResponseContentTypeValue, 2
    )
    type___ResponseContentType = ResponseContentType
    def __init__(self,) -> None: ...

type___ResponseContentTypeEnum = ResponseContentTypeEnum
