# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountLinkStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountLinkStatusValue = typing___NewType("AccountLinkStatusValue", builtin___int)
    type___AccountLinkStatusValue = AccountLinkStatusValue
    AccountLinkStatus: _AccountLinkStatus
    class _AccountLinkStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountLinkStatusEnum.AccountLinkStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 0)
        UNKNOWN = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 1)
        ENABLED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 2)
        REMOVED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 3)
        REQUESTED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 4)
        PENDING_APPROVAL = typing___cast(
            AccountLinkStatusEnum.AccountLinkStatusValue, 5
        )
    UNSPECIFIED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 0)
    UNKNOWN = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 1)
    ENABLED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 2)
    REMOVED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 3)
    REQUESTED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 4)
    PENDING_APPROVAL = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 5)
    type___AccountLinkStatus = AccountLinkStatus
    def __init__(self,) -> None: ...

type___AccountLinkStatusEnum = AccountLinkStatusEnum
