# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ClickTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ClickTypeValue = typing___NewType("ClickTypeValue", builtin___int)
    type___ClickTypeValue = ClickTypeValue
    ClickType: _ClickType
    class _ClickType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ClickTypeEnum.ClickTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ClickTypeEnum.ClickTypeValue, 0)
        UNKNOWN = typing___cast(ClickTypeEnum.ClickTypeValue, 1)
        APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 2)
        BREADCRUMBS = typing___cast(ClickTypeEnum.ClickTypeValue, 3)
        BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 4)
        CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 5)
        CALLS = typing___cast(ClickTypeEnum.ClickTypeValue, 6)
        CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickTypeValue, 7)
        GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 8)
        LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickTypeValue, 9)
        LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickTypeValue, 10)
        LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 11)
        LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 12)
        LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 13)
        LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickTypeValue, 14)
        LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickTypeValue, 15)
        LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickTypeValue, 16)
        MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 17)
        OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickTypeValue, 18)
        OTHER = typing___cast(ClickTypeEnum.ClickTypeValue, 19)
        PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 20)
        PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 21)
        SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 22)
        STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickTypeValue, 23)
        URL_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 25)
        VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 26)
        VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 27)
        VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(
            ClickTypeEnum.ClickTypeValue, 28
        )
        VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 29)
        VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 30)
        VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 31)
        WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 32)
        PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickTypeValue, 33)
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(
            ClickTypeEnum.ClickTypeValue, 34
        )
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 35
        )
        PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickTypeValue, 36)
        PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 37
        )
        PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 38)
        SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 39)
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(
            ClickTypeEnum.ClickTypeValue, 40
        )
        SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(
            ClickTypeEnum.ClickTypeValue, 42
        )
        SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 43)
        PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 44)
        SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickTypeValue, 45)
        SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickTypeValue, 46)
        SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickTypeValue, 47)
        SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 48
        )
        SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(
            ClickTypeEnum.ClickTypeValue, 49
        )
        SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 50
        )
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(
            ClickTypeEnum.ClickTypeValue, 51
        )
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 52
        )
        HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickTypeValue, 53)
        PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 54)
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(
            ClickTypeEnum.ClickTypeValue, 55
        )
        SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickTypeValue, 56)
    UNSPECIFIED = typing___cast(ClickTypeEnum.ClickTypeValue, 0)
    UNKNOWN = typing___cast(ClickTypeEnum.ClickTypeValue, 1)
    APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 2)
    BREADCRUMBS = typing___cast(ClickTypeEnum.ClickTypeValue, 3)
    BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 4)
    CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 5)
    CALLS = typing___cast(ClickTypeEnum.ClickTypeValue, 6)
    CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickTypeValue, 7)
    GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 8)
    LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickTypeValue, 9)
    LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickTypeValue, 10)
    LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 11)
    LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 12)
    LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 13)
    LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickTypeValue, 14)
    LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickTypeValue, 15)
    LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickTypeValue, 16)
    MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 17)
    OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickTypeValue, 18)
    OTHER = typing___cast(ClickTypeEnum.ClickTypeValue, 19)
    PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 20)
    PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 21)
    SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 22)
    STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickTypeValue, 23)
    URL_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 25)
    VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 26)
    VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 27)
    VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 28)
    VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 29)
    VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 30)
    VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 31)
    WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 32)
    PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickTypeValue, 33)
    PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(
        ClickTypeEnum.ClickTypeValue, 34
    )
    PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(
        ClickTypeEnum.ClickTypeValue, 35
    )
    PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickTypeValue, 36)
    PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(ClickTypeEnum.ClickTypeValue, 37)
    PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 38)
    SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 39)
    SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 40)
    SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 42)
    SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 43)
    PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 44)
    SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickTypeValue, 45)
    SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickTypeValue, 46)
    SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickTypeValue, 47)
    SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(ClickTypeEnum.ClickTypeValue, 48)
    SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(ClickTypeEnum.ClickTypeValue, 49)
    SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(
        ClickTypeEnum.ClickTypeValue, 50
    )
    SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(ClickTypeEnum.ClickTypeValue, 51)
    SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(ClickTypeEnum.ClickTypeValue, 52)
    HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickTypeValue, 53)
    PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 54)
    HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(
        ClickTypeEnum.ClickTypeValue, 55
    )
    SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickTypeValue, 56)
    type___ClickType = ClickType
    def __init__(self,) -> None: ...

type___ClickTypeEnum = ClickTypeEnum
