# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2 import (
    DynamicAffiliateLocationSetFilter as google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter,
    DynamicLocationSetFilter as google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter,
)
from google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2 import (
    FeedItemSetStatusEnum as google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemSet(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    feed: typing___Text = ...
    feed_item_set_id: builtin___int = ...
    display_name: typing___Text = ...
    status: google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum.FeedItemSetStatusValue = ...
    @property
    def dynamic_location_set_filter(
        self,
    ) -> google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter: ...
    @property
    def dynamic_affiliate_location_set_filter(
        self,
    ) -> google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed: typing___Optional[typing___Text] = None,
        feed_item_set_id: typing___Optional[builtin___int] = None,
        display_name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum.FeedItemSetStatusValue
        ] = None,
        dynamic_location_set_filter: typing___Optional[
            google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter
        ] = None,
        dynamic_affiliate_location_set_filter: typing___Optional[
            google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
            "feed",
            b"feed",
            "feed_item_set_id",
            b"feed_item_set_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "dynamic_set_filter", b"dynamic_set_filter"
        ],
    ) -> typing_extensions___Literal[
        "dynamic_location_set_filter", "dynamic_affiliate_location_set_filter"
    ]: ...

type___FeedItemSet = FeedItemSet
