# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class WebpageConditionOperandEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    WebpageConditionOperandValue = typing___NewType(
        "WebpageConditionOperandValue", builtin___int
    )
    type___WebpageConditionOperandValue = WebpageConditionOperandValue
    WebpageConditionOperand: _WebpageConditionOperand
    class _WebpageConditionOperand(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            WebpageConditionOperandEnum.WebpageConditionOperandValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 0
        )
        UNKNOWN = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 1
        )
        URL = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 2)
        CATEGORY = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 3
        )
        PAGE_TITLE = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 4
        )
        PAGE_CONTENT = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 5
        )
        CUSTOM_LABEL = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 6
        )
    UNSPECIFIED = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 0
    )
    UNKNOWN = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 1)
    URL = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 2)
    CATEGORY = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 3
    )
    PAGE_TITLE = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 4
    )
    PAGE_CONTENT = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 5
    )
    CUSTOM_LABEL = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 6
    )
    type___WebpageConditionOperand = WebpageConditionOperand
    def __init__(self,) -> None: ...

type___WebpageConditionOperandEnum = WebpageConditionOperandEnum
