# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeStatusResourceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeStatusResourceTypeValue = typing___NewType(
        "ChangeStatusResourceTypeValue", builtin___int
    )
    type___ChangeStatusResourceTypeValue = ChangeStatusResourceTypeValue
    ChangeStatusResourceType: _ChangeStatusResourceType
    class _ChangeStatusResourceType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 0
        )
        UNKNOWN = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 1
        )
        AD_GROUP = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 3
        )
        AD_GROUP_AD = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 4
        )
        AD_GROUP_CRITERION = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 5
        )
        CAMPAIGN = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 6
        )
        CAMPAIGN_CRITERION = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 7
        )
        FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 9
        )
        FEED_ITEM = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 10
        )
        AD_GROUP_FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 11
        )
        CAMPAIGN_FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 12
        )
        AD_GROUP_BID_MODIFIER = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 13
        )
    UNSPECIFIED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 0
    )
    UNKNOWN = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 1
    )
    AD_GROUP = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 3
    )
    AD_GROUP_AD = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 4
    )
    AD_GROUP_CRITERION = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 5
    )
    CAMPAIGN = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 6
    )
    CAMPAIGN_CRITERION = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 7
    )
    FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 9)
    FEED_ITEM = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 10
    )
    AD_GROUP_FEED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 11
    )
    CAMPAIGN_FEED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 12
    )
    AD_GROUP_BID_MODIFIER = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 13
    )
    type___ChangeStatusResourceType = ChangeStatusResourceType
    def __init__(self,) -> None: ...

type___ChangeStatusResourceTypeEnum = ChangeStatusResourceTypeEnum
