# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GoogleAdsFieldCategoryEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GoogleAdsFieldCategoryValue = typing___NewType(
        "GoogleAdsFieldCategoryValue", builtin___int
    )
    type___GoogleAdsFieldCategoryValue = GoogleAdsFieldCategoryValue
    GoogleAdsFieldCategory: _GoogleAdsFieldCategory
    class _GoogleAdsFieldCategory(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 0
        )
        UNKNOWN = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 1
        )
        RESOURCE = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 2
        )
        ATTRIBUTE = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 3
        )
        SEGMENT = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 5
        )
        METRIC = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 6
        )
    UNSPECIFIED = typing___cast(
        GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 0
    )
    UNKNOWN = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 1)
    RESOURCE = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 2)
    ATTRIBUTE = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 3)
    SEGMENT = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 5)
    METRIC = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 6)
    type___GoogleAdsFieldCategory = GoogleAdsFieldCategory
    def __init__(self,) -> None: ...

type___GoogleAdsFieldCategoryEnum = GoogleAdsFieldCategoryEnum
