# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.bidding_pb2 import (
    Commission as google___ads___googleads___v3___common___bidding_pb2___Commission,
    ManualCpc as google___ads___googleads___v3___common___bidding_pb2___ManualCpc,
    ManualCpm as google___ads___googleads___v3___common___bidding_pb2___ManualCpm,
    ManualCpv as google___ads___googleads___v3___common___bidding_pb2___ManualCpv,
    MaximizeConversions as google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions,
    MaximizeConversionValue as google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue,
    PercentCpc as google___ads___googleads___v3___common___bidding_pb2___PercentCpc,
    TargetCpa as google___ads___googleads___v3___common___bidding_pb2___TargetCpa,
    TargetCpm as google___ads___googleads___v3___common___bidding_pb2___TargetCpm,
    TargetImpressionShare as google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare,
    TargetRoas as google___ads___googleads___v3___common___bidding_pb2___TargetRoas,
    TargetSpend as google___ads___googleads___v3___common___bidding_pb2___TargetSpend,
)
from google.ads.google_ads.v3.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v3.proto.common.frequency_cap_pb2 import (
    FrequencyCapEntry as google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry,
)
from google.ads.google_ads.v3.proto.common.real_time_bidding_setting_pb2 import (
    RealTimeBiddingSetting as google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting,
)
from google.ads.google_ads.v3.proto.common.targeting_setting_pb2 import (
    TargetingSetting as google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting,
)
from google.ads.google_ads.v3.proto.enums.ad_serving_optimization_status_pb2 import (
    AdServingOptimizationStatusEnum as google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.advertising_channel_sub_type_pb2 import (
    AdvertisingChannelSubTypeEnum as google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.advertising_channel_type_pb2 import (
    AdvertisingChannelTypeEnum as google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.app_campaign_app_store_pb2 import (
    AppCampaignAppStoreEnum as google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum,
)
from google.ads.google_ads.v3.proto.enums.app_campaign_bidding_strategy_goal_type_pb2 import (
    AppCampaignBiddingStrategyGoalTypeEnum as google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.bidding_strategy_type_pb2 import (
    BiddingStrategyTypeEnum as google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.brand_safety_suitability_pb2 import (
    BrandSafetySuitabilityEnum as google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_experiment_type_pb2 import (
    CampaignExperimentTypeEnum as google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_serving_status_pb2 import (
    CampaignServingStatusEnum as google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_status_pb2 import (
    CampaignStatusEnum as google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.negative_geo_target_type_pb2 import (
    NegativeGeoTargetTypeEnum as google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.payment_mode_pb2 import (
    PaymentModeEnum as google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum,
)
from google.ads.google_ads.v3.proto.enums.positive_geo_target_type_pb2 import (
    PositiveGeoTargetTypeEnum as google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.vanity_pharma_display_url_mode_pb2 import (
    VanityPharmaDisplayUrlModeEnum as google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum,
)
from google.ads.google_ads.v3.proto.enums.vanity_pharma_text_pb2 import (
    VanityPharmaTextEnum as google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Campaign(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class NetworkSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def target_google_search(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_search_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_content_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_partner_search_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        def __init__(
            self,
            *,
            target_google_search: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_search_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_content_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_partner_search_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> None: ...
    type___NetworkSettings = NetworkSettings
    class HotelSettingInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def hotel_center_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            hotel_center_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> None: ...
    type___HotelSettingInfo = HotelSettingInfo
    class VanityPharma(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        vanity_pharma_display_url_mode: google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue = ...
        vanity_pharma_text: google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaTextValue = ...
        def __init__(
            self,
            *,
            vanity_pharma_display_url_mode: typing___Optional[
                google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue
            ] = None,
            vanity_pharma_text: typing___Optional[
                google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaTextValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "vanity_pharma_display_url_mode",
                b"vanity_pharma_display_url_mode",
                "vanity_pharma_text",
                b"vanity_pharma_text",
            ],
        ) -> None: ...
    type___VanityPharma = VanityPharma
    class DynamicSearchAdsSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def domain_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def use_supplied_urls_only(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def feeds(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            domain_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            language_code: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            use_supplied_urls_only: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            feeds: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "domain_name",
                b"domain_name",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "domain_name",
                b"domain_name",
                "feeds",
                b"feeds",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> None: ...
    type___DynamicSearchAdsSetting = DynamicSearchAdsSetting
    class ShoppingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def merchant_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def sales_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def campaign_priority(
            self,
        ) -> google___protobuf___wrappers_pb2___Int32Value: ...
        @property
        def enable_local(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
        def __init__(
            self,
            *,
            merchant_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            sales_country: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            campaign_priority: typing___Optional[
                google___protobuf___wrappers_pb2___Int32Value
            ] = None,
            enable_local: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> None: ...
    type___ShoppingSetting = ShoppingSetting
    class GeoTargetTypeSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        positive_geo_target_type: google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue = ...
        negative_geo_target_type: google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue = ...
        def __init__(
            self,
            *,
            positive_geo_target_type: typing___Optional[
                google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue
            ] = None,
            negative_geo_target_type: typing___Optional[
                google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "negative_geo_target_type",
                b"negative_geo_target_type",
                "positive_geo_target_type",
                b"positive_geo_target_type",
            ],
        ) -> None: ...
    type___GeoTargetTypeSetting = GeoTargetTypeSetting
    class TrackingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def tracking_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            tracking_url: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal["tracking_url", b"tracking_url"],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal["tracking_url", b"tracking_url"],
        ) -> None: ...
    type___TrackingSetting = TrackingSetting
    class AppCampaignSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        bidding_strategy_goal_type: google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalTypeValue = ...
        app_store: google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStoreValue = ...
        @property
        def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            bidding_strategy_goal_type: typing___Optional[
                google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalTypeValue
            ] = None,
            app_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            app_store: typing___Optional[
                google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStoreValue
            ] = None,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions___Literal["app_id", b"app_id"]
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "app_id",
                b"app_id",
                "app_store",
                b"app_store",
                "bidding_strategy_goal_type",
                b"bidding_strategy_goal_type",
            ],
        ) -> None: ...
    type___AppCampaignSetting = AppCampaignSetting
    class SelectiveOptimization(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def conversion_actions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            conversion_actions: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "conversion_actions", b"conversion_actions"
            ],
        ) -> None: ...
    type___SelectiveOptimization = SelectiveOptimization

    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatusValue = ...
    serving_status: google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatusValue = ...
    ad_serving_optimization_status: google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatusValue = ...
    advertising_channel_type: google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue = ...
    advertising_channel_sub_type: google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue = ...
    experiment_type: google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentTypeValue = ...
    bidding_strategy_type: google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue = ...
    video_brand_safety_suitability: google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitabilityValue = ...
    payment_mode: google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum.PaymentModeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def real_time_bidding_setting(
        self,
    ) -> google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting: ...
    @property
    def network_settings(self) -> type___Campaign.NetworkSettings: ...
    @property
    def hotel_setting(self) -> type___Campaign.HotelSettingInfo: ...
    @property
    def dynamic_search_ads_setting(self) -> type___Campaign.DynamicSearchAdsSetting: ...
    @property
    def shopping_setting(self) -> type___Campaign.ShoppingSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting: ...
    @property
    def geo_target_type_setting(self) -> type___Campaign.GeoTargetTypeSetting: ...
    @property
    def app_campaign_setting(self) -> type___Campaign.AppCampaignSetting: ...
    @property
    def labels(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def base_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def frequency_caps(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry
    ]: ...
    @property
    def vanity_pharma(self) -> type___Campaign.VanityPharma: ...
    @property
    def selective_optimization(self) -> type___Campaign.SelectiveOptimization: ...
    @property
    def tracking_setting(self) -> type___Campaign.TrackingSetting: ...
    @property
    def optimization_score(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def bidding_strategy(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def commission(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___Commission: ...
    @property
    def manual_cpc(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpc: ...
    @property
    def manual_cpm(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpm: ...
    @property
    def manual_cpv(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpv: ...
    @property
    def maximize_conversions(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue: ...
    @property
    def target_cpa(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetSpend: ...
    @property
    def percent_cpc(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___PercentCpc: ...
    @property
    def target_cpm(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetCpm: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatusValue
        ] = None,
        serving_status: typing___Optional[
            google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatusValue
        ] = None,
        ad_serving_optimization_status: typing___Optional[
            google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatusValue
        ] = None,
        advertising_channel_type: typing___Optional[
            google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue
        ] = None,
        advertising_channel_sub_type: typing___Optional[
            google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        real_time_bidding_setting: typing___Optional[
            google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting
        ] = None,
        network_settings: typing___Optional[type___Campaign.NetworkSettings] = None,
        hotel_setting: typing___Optional[type___Campaign.HotelSettingInfo] = None,
        dynamic_search_ads_setting: typing___Optional[
            type___Campaign.DynamicSearchAdsSetting
        ] = None,
        shopping_setting: typing___Optional[type___Campaign.ShoppingSetting] = None,
        targeting_setting: typing___Optional[
            google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting
        ] = None,
        geo_target_type_setting: typing___Optional[
            type___Campaign.GeoTargetTypeSetting
        ] = None,
        app_campaign_setting: typing___Optional[
            type___Campaign.AppCampaignSetting
        ] = None,
        labels: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        experiment_type: typing___Optional[
            google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentTypeValue
        ] = None,
        base_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_budget: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        bidding_strategy_type: typing___Optional[
            google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue
        ] = None,
        start_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        frequency_caps: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry
            ]
        ] = None,
        video_brand_safety_suitability: typing___Optional[
            google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitabilityValue
        ] = None,
        vanity_pharma: typing___Optional[type___Campaign.VanityPharma] = None,
        selective_optimization: typing___Optional[
            type___Campaign.SelectiveOptimization
        ] = None,
        tracking_setting: typing___Optional[type___Campaign.TrackingSetting] = None,
        payment_mode: typing___Optional[
            google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum.PaymentModeValue
        ] = None,
        optimization_score: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        bidding_strategy: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        commission: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___Commission
        ] = None,
        manual_cpc: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpc
        ] = None,
        manual_cpm: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpm
        ] = None,
        manual_cpv: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpv
        ] = None,
        maximize_conversions: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions
        ] = None,
        maximize_conversion_value: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue
        ] = None,
        target_cpa: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetCpa
        ] = None,
        target_impression_share: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare
        ] = None,
        target_roas: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetRoas
        ] = None,
        target_spend: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetSpend
        ] = None,
        percent_cpc: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___PercentCpc
        ] = None,
        target_cpm: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetCpm
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "final_url_suffix",
            b"final_url_suffix",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_score",
            b"optimization_score",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "selective_optimization",
            b"selective_optimization",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "vanity_pharma",
            b"vanity_pharma",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_serving_optimization_status",
            b"ad_serving_optimization_status",
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "bidding_strategy_type",
            b"bidding_strategy_type",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "experiment_type",
            b"experiment_type",
            "final_url_suffix",
            b"final_url_suffix",
            "frequency_caps",
            b"frequency_caps",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "labels",
            b"labels",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_score",
            b"optimization_score",
            "payment_mode",
            b"payment_mode",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "resource_name",
            b"resource_name",
            "selective_optimization",
            b"selective_optimization",
            "serving_status",
            b"serving_status",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
            "vanity_pharma",
            b"vanity_pharma",
            "video_brand_safety_suitability",
            b"video_brand_safety_suitability",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "campaign_bidding_strategy", b"campaign_bidding_strategy"
        ],
    ) -> typing_extensions___Literal[
        "bidding_strategy",
        "commission",
        "manual_cpc",
        "manual_cpm",
        "manual_cpv",
        "maximize_conversions",
        "maximize_conversion_value",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
        "percent_cpc",
        "target_cpm",
    ]: ...

type___Campaign = Campaign
