from typing import Any

class KeywordPlanKeywordServiceStub:
    GetKeywordPlanKeyword: Any = ...
    MutateKeywordPlanKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanKeywordServiceServicer:
    def GetKeywordPlanKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
