# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BudgetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BudgetTypeValue = typing___NewType("BudgetTypeValue", builtin___int)
    type___BudgetTypeValue = BudgetTypeValue
    BudgetType: _BudgetType
    class _BudgetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BudgetTypeEnum.BudgetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BudgetTypeEnum.BudgetTypeValue, 0)
        UNKNOWN = typing___cast(BudgetTypeEnum.BudgetTypeValue, 1)
        STANDARD = typing___cast(BudgetTypeEnum.BudgetTypeValue, 2)
        HOTEL_ADS_COMMISSION = typing___cast(BudgetTypeEnum.BudgetTypeValue, 3)
        FIXED_CPA = typing___cast(BudgetTypeEnum.BudgetTypeValue, 4)
    UNSPECIFIED = typing___cast(BudgetTypeEnum.BudgetTypeValue, 0)
    UNKNOWN = typing___cast(BudgetTypeEnum.BudgetTypeValue, 1)
    STANDARD = typing___cast(BudgetTypeEnum.BudgetTypeValue, 2)
    HOTEL_ADS_COMMISSION = typing___cast(BudgetTypeEnum.BudgetTypeValue, 3)
    FIXED_CPA = typing___cast(BudgetTypeEnum.BudgetTypeValue, 4)
    type___BudgetType = BudgetType
    def __init__(self,) -> None: ...

type___BudgetTypeEnum = BudgetTypeEnum
