# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AuthenticationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AuthenticationErrorValue = typing___NewType(
        "AuthenticationErrorValue", builtin___int
    )
    type___AuthenticationErrorValue = AuthenticationErrorValue
    AuthenticationError: _AuthenticationError
    class _AuthenticationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AuthenticationErrorEnum.AuthenticationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 0)
        UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 1)
        AUTHENTICATION_ERROR = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 2
        )
        CLIENT_CUSTOMER_ID_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 5
        )
        CUSTOMER_NOT_FOUND = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 8
        )
        GOOGLE_ACCOUNT_DELETED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 9
        )
        GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 10
        )
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 25
        )
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 12
        )
        LOGIN_COOKIE_REQUIRED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 13
        )
        NOT_ADS_USER = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 14
        )
        OAUTH_TOKEN_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 15
        )
        OAUTH_TOKEN_EXPIRED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 16
        )
        OAUTH_TOKEN_DISABLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 17
        )
        OAUTH_TOKEN_REVOKED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 18
        )
        OAUTH_TOKEN_HEADER_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 19
        )
        LOGIN_COOKIE_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 20
        )
        USER_ID_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 22
        )
        TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 23
        )
        ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 24
        )
    UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 0)
    UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 1)
    AUTHENTICATION_ERROR = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 2
    )
    CLIENT_CUSTOMER_ID_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 5
    )
    CUSTOMER_NOT_FOUND = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 8
    )
    GOOGLE_ACCOUNT_DELETED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 9
    )
    GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 10
    )
    GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 25
    )
    GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 12
    )
    LOGIN_COOKIE_REQUIRED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 13
    )
    NOT_ADS_USER = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 14)
    OAUTH_TOKEN_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 15
    )
    OAUTH_TOKEN_EXPIRED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 16
    )
    OAUTH_TOKEN_DISABLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 17
    )
    OAUTH_TOKEN_REVOKED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 18
    )
    OAUTH_TOKEN_HEADER_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 19
    )
    LOGIN_COOKIE_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 20
    )
    USER_ID_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 22
    )
    TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 23
    )
    ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 24
    )
    type___AuthenticationError = AuthenticationError
    def __init__(self,) -> None: ...

type___AuthenticationErrorEnum = AuthenticationErrorEnum
