from typing import Any

class ClickViewServiceStub:
    GetClickView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ClickViewServiceServicer:
    def GetClickView(self, request: Any, context: Any) -> None: ...

def add_ClickViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
