# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UrlCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    url_collection_id: typing___Text = ...
    final_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    final_mobile_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    tracking_url_template: typing___Text = ...
    def __init__(
        self,
        *,
        url_collection_id: typing___Optional[typing___Text] = None,
        final_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        final_mobile_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions___Literal["url_collection_id"]: ...

type___UrlCollection = UrlCollection
