# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedMappingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedMappingErrorValue = typing___NewType("FeedMappingErrorValue", builtin___int)
    type___FeedMappingErrorValue = FeedMappingErrorValue
    FeedMappingError: _FeedMappingError
    class _FeedMappingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedMappingErrorEnum.FeedMappingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 0)
        UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 1)
        INVALID_PLACEHOLDER_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 2
        )
        INVALID_CRITERION_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 3
        )
        INVALID_PLACEHOLDER_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 4
        )
        INVALID_CRITERION_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 5
        )
        NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 7
        )
        FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 8
        )
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 9
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 10
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 11
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 12
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 13
        )
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 14
        )
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 15
        )
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 16
        )
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 17
        )
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 18
        )
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 19
        )
    UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 0)
    UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 1)
    INVALID_PLACEHOLDER_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 2
    )
    INVALID_CRITERION_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 3
    )
    INVALID_PLACEHOLDER_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 4
    )
    INVALID_CRITERION_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 5
    )
    NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 7
    )
    FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 8
    )
    CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 9
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 10
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 11
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 12
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 13
    )
    UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 14
    )
    LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 15
    )
    CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 16
    )
    INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 17
    )
    INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 18
    )
    ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 19
    )
    type___FeedMappingError = FeedMappingError
    def __init__(self,) -> None: ...

type___FeedMappingErrorEnum = FeedMappingErrorEnum
