# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEntryTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEntryTypeValue = typing___NewType(
        "PolicyTopicEntryTypeValue", builtin___int
    )
    type___PolicyTopicEntryTypeValue = PolicyTopicEntryTypeValue
    PolicyTopicEntryType: _PolicyTopicEntryType
    class _PolicyTopicEntryType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 0
        )
        UNKNOWN = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 1)
        PROHIBITED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 2
        )
        LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 4)
        FULLY_LIMITED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 8
        )
        DESCRIPTIVE = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 5
        )
        BROADENING = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 6
        )
        AREA_OF_INTEREST_ONLY = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 7
        )
    UNSPECIFIED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 0)
    UNKNOWN = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 1)
    PROHIBITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 2)
    LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 4)
    FULLY_LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 8)
    DESCRIPTIVE = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 5)
    BROADENING = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 6)
    AREA_OF_INTEREST_ONLY = typing___cast(
        PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 7
    )
    type___PolicyTopicEntryType = PolicyTopicEntryType
    def __init__(self,) -> None: ...

type___PolicyTopicEntryTypeEnum = PolicyTopicEntryTypeEnum
