from typing import Any

class ExtensionFeedItemServiceStub:
    GetExtensionFeedItem: Any = ...
    MutateExtensionFeedItems: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ExtensionFeedItemServiceServicer:
    def GetExtensionFeedItem(self, request: Any, context: Any) -> None: ...
    def MutateExtensionFeedItems(self, request: Any, context: Any) -> None: ...

def add_ExtensionFeedItemServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
