# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanAgeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanAgeRangeValue = typing___NewType("ReachPlanAgeRangeValue", builtin___int)
    type___ReachPlanAgeRangeValue = ReachPlanAgeRangeValue
    ReachPlanAgeRange: _ReachPlanAgeRange
    class _ReachPlanAgeRange(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 0)
        UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 1)
        AGE_RANGE_18_24 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503001
        )
        AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 2)
        AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 3)
        AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 4)
        AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 5)
        AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 6)
        AGE_RANGE_18_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 7
        )
        AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 8)
        AGE_RANGE_25_34 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503002
        )
        AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 9)
        AGE_RANGE_25_49 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 10
        )
        AGE_RANGE_25_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 11
        )
        AGE_RANGE_25_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 12
        )
        AGE_RANGE_25_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 13
        )
        AGE_RANGE_35_44 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503003
        )
        AGE_RANGE_35_49 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 14
        )
        AGE_RANGE_35_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 15
        )
        AGE_RANGE_35_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 16
        )
        AGE_RANGE_35_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 17
        )
        AGE_RANGE_45_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503004
        )
        AGE_RANGE_45_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 18
        )
        AGE_RANGE_45_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 19
        )
        AGE_RANGE_50_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 20
        )
        AGE_RANGE_55_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503005
        )
        AGE_RANGE_55_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 21
        )
        AGE_RANGE_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503006
        )
    UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 0)
    UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 1)
    AGE_RANGE_18_24 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503001
    )
    AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 2)
    AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 3)
    AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 4)
    AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 5)
    AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 6)
    AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 7)
    AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 8)
    AGE_RANGE_25_34 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503002
    )
    AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 9)
    AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 10)
    AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 11)
    AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 12)
    AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 13)
    AGE_RANGE_35_44 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503003
    )
    AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 14)
    AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 15)
    AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 16)
    AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 17)
    AGE_RANGE_45_54 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503004
    )
    AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 18)
    AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 19)
    AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 20)
    AGE_RANGE_55_64 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503005
    )
    AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 21)
    AGE_RANGE_65_UP = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503006
    )
    type___ReachPlanAgeRange = ReachPlanAgeRange
    def __init__(self,) -> None: ...

type___ReachPlanAgeRangeEnum = ReachPlanAgeRangeEnum
