from typing import Any

class KeywordPlanServiceStub:
    GetKeywordPlan: Any = ...
    MutateKeywordPlans: Any = ...
    GenerateForecastMetrics: Any = ...
    GenerateHistoricalMetrics: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanServiceServicer:
    def GetKeywordPlan(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlans(self, request: Any, context: Any) -> None: ...
    def GenerateForecastMetrics(self, request: Any, context: Any) -> None: ...
    def GenerateHistoricalMetrics(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
