# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdvertisingChannelSubTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdvertisingChannelSubTypeValue = typing___NewType(
        "AdvertisingChannelSubTypeValue", builtin___int
    )
    type___AdvertisingChannelSubTypeValue = AdvertisingChannelSubTypeValue
    AdvertisingChannelSubType: _AdvertisingChannelSubType
    class _AdvertisingChannelSubType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 0
        )
        UNKNOWN = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 1
        )
        SEARCH_MOBILE_APP = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 2
        )
        DISPLAY_MOBILE_APP = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 3
        )
        SEARCH_EXPRESS = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 4
        )
        DISPLAY_EXPRESS = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 5
        )
        SHOPPING_SMART_ADS = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 6
        )
        DISPLAY_GMAIL_AD = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 7
        )
        DISPLAY_SMART_CAMPAIGN = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 8
        )
        VIDEO_OUTSTREAM = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 9
        )
        VIDEO_ACTION = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 10
        )
        VIDEO_NON_SKIPPABLE = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 11
        )
        APP_CAMPAIGN = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 12
        )
        APP_CAMPAIGN_FOR_ENGAGEMENT = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 13
        )
        SHOPPING_COMPARISON_LISTING_ADS = typing___cast(
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 15
        )
    UNSPECIFIED = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 0
    )
    UNKNOWN = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 1
    )
    SEARCH_MOBILE_APP = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 2
    )
    DISPLAY_MOBILE_APP = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 3
    )
    SEARCH_EXPRESS = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 4
    )
    DISPLAY_EXPRESS = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 5
    )
    SHOPPING_SMART_ADS = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 6
    )
    DISPLAY_GMAIL_AD = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 7
    )
    DISPLAY_SMART_CAMPAIGN = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 8
    )
    VIDEO_OUTSTREAM = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 9
    )
    VIDEO_ACTION = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 10
    )
    VIDEO_NON_SKIPPABLE = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 11
    )
    APP_CAMPAIGN = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 12
    )
    APP_CAMPAIGN_FOR_ENGAGEMENT = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 13
    )
    SHOPPING_COMPARISON_LISTING_ADS = typing___cast(
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue, 15
    )
    type___AdvertisingChannelSubType = AdvertisingChannelSubType
    def __init__(self,) -> None: ...

type___AdvertisingChannelSubTypeEnum = AdvertisingChannelSubTypeEnum
