# Stubs for google.ads.google_ads.v6.services.transports.reach_plan_service_grpc_transport (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class ReachPlanServiceGrpcTransport:
    def __init__(
        self,
        channel: Optional[Any] = ...,
        credentials: Optional[Any] = ...,
        address: str = ...,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any
    ): ...
    @property
    def channel(self): ...
    @property
    def list_plannable_locations(self): ...
    @property
    def list_plannable_products(self): ...
    @property
    def generate_product_mix_ideas(self): ...
    @property
    def generate_reach_forecast(self): ...
