from typing import Any

class AccountBudgetServiceStub:
    GetAccountBudget: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountBudgetServiceServicer:
    def GetAccountBudget(self, request: Any, context: Any) -> None: ...

def add_AccountBudgetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
