# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionTypeValue = typing___NewType(
        "ConversionActionTypeValue", builtin___int
    )
    type___ConversionActionTypeValue = ConversionActionTypeValue
    ConversionActionType: _ConversionActionType
    class _ConversionActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionTypeEnum.ConversionActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 0
        )
        UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
        AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
        CLICK_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 3
        )
        GOOGLE_PLAY_DOWNLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 4
        )
        GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 5
        )
        UPLOAD_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 6
        )
        UPLOAD_CLICKS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 7
        )
        WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
        WEBSITE_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 9
        )
        STORE_SALES_DIRECT_UPLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 10
        )
        STORE_SALES = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 11
        )
        FIREBASE_ANDROID_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 12
        )
        FIREBASE_ANDROID_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 13
        )
        FIREBASE_ANDROID_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 14
        )
        FIREBASE_IOS_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 15
        )
        FIREBASE_IOS_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 16
        )
        FIREBASE_IOS_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 17
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 18
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 19
        )
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 20
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 21
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 22
        )
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 23
        )
        ANDROID_APP_PRE_REGISTRATION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 24
        )
        ANDROID_INSTALLS_ALL_OTHER_APPS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 25
        )
        FLOODLIGHT_ACTION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 26
        )
        FLOODLIGHT_TRANSACTION = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 27
        )
        GOOGLE_HOSTED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 28
        )
        LEAD_FORM_SUBMIT = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 29
        )
        SALESFORCE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 30
        )
        SEARCH_ADS_360 = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 31
        )
        SMART_CAMPAIGN_AD_CLICKS_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 32
        )
        SMART_CAMPAIGN_MAP_CLICKS_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 33
        )
        SMART_CAMPAIGN_MAP_DIRECTIONS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 34
        )
        SMART_CAMPAIGN_TRACKED_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 35
        )
        STORE_VISITS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 36
        )
    UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 0)
    UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
    AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
    CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 3)
    GOOGLE_PLAY_DOWNLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 4
    )
    GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 5
    )
    UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 6)
    UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 7)
    WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
    WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 9)
    STORE_SALES_DIRECT_UPLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 10
    )
    STORE_SALES = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 11)
    FIREBASE_ANDROID_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 12
    )
    FIREBASE_ANDROID_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 13
    )
    FIREBASE_ANDROID_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 14
    )
    FIREBASE_IOS_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 15
    )
    FIREBASE_IOS_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 16
    )
    FIREBASE_IOS_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 17
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 18
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 19
    )
    THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 20
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 21
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 22
    )
    THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 23
    )
    ANDROID_APP_PRE_REGISTRATION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 24
    )
    ANDROID_INSTALLS_ALL_OTHER_APPS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 25
    )
    FLOODLIGHT_ACTION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 26
    )
    FLOODLIGHT_TRANSACTION = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 27
    )
    GOOGLE_HOSTED = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 28
    )
    LEAD_FORM_SUBMIT = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 29
    )
    SALESFORCE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 30)
    SEARCH_ADS_360 = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 31
    )
    SMART_CAMPAIGN_AD_CLICKS_TO_CALL = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 32
    )
    SMART_CAMPAIGN_MAP_CLICKS_TO_CALL = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 33
    )
    SMART_CAMPAIGN_MAP_DIRECTIONS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 34
    )
    SMART_CAMPAIGN_TRACKED_CALLS = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 35
    )
    STORE_VISITS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 36)
    type___ConversionActionType = ConversionActionType
    def __init__(self,) -> None: ...

type___ConversionActionTypeEnum = ConversionActionTypeEnum
