from typing import Any

class AdGroupCriterionSimulationServiceStub:
    GetAdGroupCriterionSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupCriterionSimulationServiceServicer:
    def GetAdGroupCriterionSimulation(self, request: Any, context: Any) -> None: ...

def add_AdGroupCriterionSimulationServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
