# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.batch_job_status_pb2 import (
    BatchJobStatusEnum as google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BatchJob(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BatchJobMetadata(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        creation_date_time: typing___Text = ...
        start_date_time: typing___Text = ...
        completion_date_time: typing___Text = ...
        estimated_completion_ratio: builtin___float = ...
        operation_count: builtin___int = ...
        executed_operation_count: builtin___int = ...
        def __init__(
            self,
            *,
            creation_date_time: typing___Optional[typing___Text] = None,
            start_date_time: typing___Optional[typing___Text] = None,
            completion_date_time: typing___Optional[typing___Text] = None,
            estimated_completion_ratio: typing___Optional[builtin___float] = None,
            operation_count: typing___Optional[builtin___int] = None,
            executed_operation_count: typing___Optional[builtin___int] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_completion_date_time",
                b"_completion_date_time",
                "_creation_date_time",
                b"_creation_date_time",
                "_estimated_completion_ratio",
                b"_estimated_completion_ratio",
                "_executed_operation_count",
                b"_executed_operation_count",
                "_operation_count",
                b"_operation_count",
                "_start_date_time",
                b"_start_date_time",
                "completion_date_time",
                b"completion_date_time",
                "creation_date_time",
                b"creation_date_time",
                "estimated_completion_ratio",
                b"estimated_completion_ratio",
                "executed_operation_count",
                b"executed_operation_count",
                "operation_count",
                b"operation_count",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_completion_date_time", b"_completion_date_time"
            ],
        ) -> typing_extensions___Literal["completion_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions___Literal["creation_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_estimated_completion_ratio", b"_estimated_completion_ratio"
            ],
        ) -> typing_extensions___Literal["estimated_completion_ratio"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_executed_operation_count", b"_executed_operation_count"
            ],
        ) -> typing_extensions___Literal["executed_operation_count"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_operation_count", b"_operation_count"
            ],
        ) -> typing_extensions___Literal["operation_count"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions___Literal["start_date_time"]: ...
    type___BatchJobMetadata = BatchJobMetadata

    resource_name: typing___Text = ...
    id: builtin___int = ...
    next_add_sequence_token: typing___Text = ...
    status: google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue = ...
    long_running_operation: typing___Text = ...
    @property
    def metadata(self) -> type___BatchJob.BatchJobMetadata: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        next_add_sequence_token: typing___Optional[typing___Text] = None,
        metadata: typing___Optional[type___BatchJob.BatchJobMetadata] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___batch_job_status_pb2___BatchJobStatusEnum.BatchJobStatusValue
        ] = None,
        long_running_operation: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_next_add_sequence_token",
            b"_next_add_sequence_token",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "metadata",
            b"metadata",
            "next_add_sequence_token",
            b"next_add_sequence_token",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions___Literal["long_running_operation"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_next_add_sequence_token", b"_next_add_sequence_token"
        ],
    ) -> typing_extensions___Literal["next_add_sequence_token"]: ...

type___BatchJob = BatchJob
