# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResourceCountLimitExceededErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResourceCountLimitExceededErrorValue = typing___NewType(
        "ResourceCountLimitExceededErrorValue", builtin___int
    )
    type___ResourceCountLimitExceededErrorValue = ResourceCountLimitExceededErrorValue
    ResourceCountLimitExceededError: _ResourceCountLimitExceededError
    class _ResourceCountLimitExceededError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 1
        )
        ACCOUNT_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 2
        )
        CAMPAIGN_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 3
        )
        ADGROUP_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 4
        )
        AD_GROUP_AD_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 5
        )
        AD_GROUP_CRITERION_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 6
        )
        SHARED_SET_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 7
        )
        MATCHING_FUNCTION_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 8
        )
        RESPONSE_ROW_LIMIT_EXCEEDED = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 9
        )
        RESOURCE_LIMIT = typing___cast(
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 10
        )
    UNSPECIFIED = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 0
    )
    UNKNOWN = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 1
    )
    ACCOUNT_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 2
    )
    CAMPAIGN_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 3
    )
    ADGROUP_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 4
    )
    AD_GROUP_AD_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 5
    )
    AD_GROUP_CRITERION_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 6
    )
    SHARED_SET_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 7
    )
    MATCHING_FUNCTION_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 8
    )
    RESPONSE_ROW_LIMIT_EXCEEDED = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 9
    )
    RESOURCE_LIMIT = typing___cast(
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorValue, 10
    )
    type___ResourceCountLimitExceededError = ResourceCountLimitExceededError
    def __init__(self,) -> None: ...

type___ResourceCountLimitExceededErrorEnum = ResourceCountLimitExceededErrorEnum
