from typing import Any

class MobileDeviceConstantServiceStub:
    GetMobileDeviceConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MobileDeviceConstantServiceServicer:
    def GetMobileDeviceConstant(self, request: Any, context: Any) -> None: ...

def add_MobileDeviceConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
