# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class VanityPharmaDisplayUrlModeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    VanityPharmaDisplayUrlModeValue = typing___NewType(
        "VanityPharmaDisplayUrlModeValue", builtin___int
    )
    type___VanityPharmaDisplayUrlModeValue = VanityPharmaDisplayUrlModeValue
    VanityPharmaDisplayUrlMode: _VanityPharmaDisplayUrlMode
    class _VanityPharmaDisplayUrlMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 0
        )
        UNKNOWN = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 1
        )
        MANUFACTURER_WEBSITE_URL = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 2
        )
        WEBSITE_DESCRIPTION = typing___cast(
            VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 3
        )
    UNSPECIFIED = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 0
    )
    UNKNOWN = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 1
    )
    MANUFACTURER_WEBSITE_URL = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 2
    )
    WEBSITE_DESCRIPTION = typing___cast(
        VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue, 3
    )
    type___VanityPharmaDisplayUrlMode = VanityPharmaDisplayUrlMode
    def __init__(self,) -> None: ...

type___VanityPharmaDisplayUrlModeEnum = VanityPharmaDisplayUrlModeEnum
