from typing import Any

class ChangeStatusServiceStub:
    GetChangeStatus: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ChangeStatusServiceServicer:
    def GetChangeStatus(self, request: Any, context: Any) -> None: ...

def add_ChangeStatusServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
