# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeStatusErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeStatusErrorValue = typing___NewType("ChangeStatusErrorValue", builtin___int)
    type___ChangeStatusErrorValue = ChangeStatusErrorValue
    ChangeStatusError: _ChangeStatusError
    class _ChangeStatusError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeStatusErrorEnum.ChangeStatusErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 0)
        UNKNOWN = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 1)
        START_DATE_TOO_OLD = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 3
        )
        CHANGE_DATE_RANGE_INFINITE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 4
        )
        CHANGE_DATE_RANGE_NEGATIVE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 5
        )
        LIMIT_NOT_SPECIFIED = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 6
        )
        INVALID_LIMIT_CLAUSE = typing___cast(
            ChangeStatusErrorEnum.ChangeStatusErrorValue, 7
        )
    UNSPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 0)
    UNKNOWN = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 1)
    START_DATE_TOO_OLD = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 3)
    CHANGE_DATE_RANGE_INFINITE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 4
    )
    CHANGE_DATE_RANGE_NEGATIVE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 5
    )
    LIMIT_NOT_SPECIFIED = typing___cast(ChangeStatusErrorEnum.ChangeStatusErrorValue, 6)
    INVALID_LIMIT_CLAUSE = typing___cast(
        ChangeStatusErrorEnum.ChangeStatusErrorValue, 7
    )
    type___ChangeStatusError = ChangeStatusError
    def __init__(self,) -> None: ...

type___ChangeStatusErrorEnum = ChangeStatusErrorEnum
