from typing import Any

class CarrierConstantServiceStub:
    GetCarrierConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CarrierConstantServiceServicer:
    def GetCarrierConstant(self, request: Any, context: Any) -> None: ...

def add_CarrierConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
