# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LanguageCodeErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LanguageCodeErrorValue = typing___NewType("LanguageCodeErrorValue", builtin___int)
    type___LanguageCodeErrorValue = LanguageCodeErrorValue
    LanguageCodeError: _LanguageCodeError
    class _LanguageCodeError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LanguageCodeErrorEnum.LanguageCodeErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 0)
        UNKNOWN = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 1)
        LANGUAGE_CODE_NOT_FOUND = typing___cast(
            LanguageCodeErrorEnum.LanguageCodeErrorValue, 2
        )
        INVALID_LANGUAGE_CODE = typing___cast(
            LanguageCodeErrorEnum.LanguageCodeErrorValue, 3
        )
    UNSPECIFIED = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 0)
    UNKNOWN = typing___cast(LanguageCodeErrorEnum.LanguageCodeErrorValue, 1)
    LANGUAGE_CODE_NOT_FOUND = typing___cast(
        LanguageCodeErrorEnum.LanguageCodeErrorValue, 2
    )
    INVALID_LANGUAGE_CODE = typing___cast(
        LanguageCodeErrorEnum.LanguageCodeErrorValue, 3
    )
    type___LanguageCodeError = LanguageCodeError
    def __init__(self,) -> None: ...

type___LanguageCodeErrorEnum = LanguageCodeErrorEnum
