# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudgetStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountBudgetStatusValue = typing___NewType(
        "AccountBudgetStatusValue", builtin___int
    )
    type___AccountBudgetStatusValue = AccountBudgetStatusValue
    AccountBudgetStatus: _AccountBudgetStatus
    class _AccountBudgetStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountBudgetStatusEnum.AccountBudgetStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 0)
        UNKNOWN = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 1)
        PENDING = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 2)
        APPROVED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 3)
        CANCELLED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 4)
    UNSPECIFIED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 0)
    UNKNOWN = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 1)
    PENDING = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 2)
    APPROVED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 3)
    CANCELLED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 4)
    type___AccountBudgetStatus = AccountBudgetStatus
    def __init__(self,) -> None: ...

type___AccountBudgetStatusEnum = AccountBudgetStatusEnum
