# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdTypeValue = typing___NewType("AdTypeValue", builtin___int)
    type___AdTypeValue = AdTypeValue
    AdType: _AdType
    class _AdType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdTypeEnum.AdTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdTypeEnum.AdTypeValue, 0)
        UNKNOWN = typing___cast(AdTypeEnum.AdTypeValue, 1)
        TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 2)
        EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 3)
        CALL_ONLY_AD = typing___cast(AdTypeEnum.AdTypeValue, 6)
        EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 7)
        HOTEL_AD = typing___cast(AdTypeEnum.AdTypeValue, 8)
        SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdTypeValue, 9)
        SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdTypeValue, 10)
        VIDEO_AD = typing___cast(AdTypeEnum.AdTypeValue, 12)
        GMAIL_AD = typing___cast(AdTypeEnum.AdTypeValue, 13)
        IMAGE_AD = typing___cast(AdTypeEnum.AdTypeValue, 14)
        RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 15)
        LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 16)
        APP_AD = typing___cast(AdTypeEnum.AdTypeValue, 17)
        LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdTypeValue, 18)
        RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 19)
        LOCAL_AD = typing___cast(AdTypeEnum.AdTypeValue, 20)
        HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdTypeValue, 21)
        DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdTypeValue, 22)
        APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdTypeValue, 23)
        SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdTypeValue, 24)
        VIDEO_BUMPER_AD = typing___cast(AdTypeEnum.AdTypeValue, 25)
        VIDEO_NON_SKIPPABLE_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 26)
        VIDEO_OUTSTREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 27)
        VIDEO_TRUEVIEW_DISCOVERY_AD = typing___cast(AdTypeEnum.AdTypeValue, 28)
        VIDEO_TRUEVIEW_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 29)
        VIDEO_RESPONSIVE_AD = typing___cast(AdTypeEnum.AdTypeValue, 30)
    UNSPECIFIED = typing___cast(AdTypeEnum.AdTypeValue, 0)
    UNKNOWN = typing___cast(AdTypeEnum.AdTypeValue, 1)
    TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 2)
    EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 3)
    CALL_ONLY_AD = typing___cast(AdTypeEnum.AdTypeValue, 6)
    EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 7)
    HOTEL_AD = typing___cast(AdTypeEnum.AdTypeValue, 8)
    SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdTypeValue, 9)
    SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdTypeValue, 10)
    VIDEO_AD = typing___cast(AdTypeEnum.AdTypeValue, 12)
    GMAIL_AD = typing___cast(AdTypeEnum.AdTypeValue, 13)
    IMAGE_AD = typing___cast(AdTypeEnum.AdTypeValue, 14)
    RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 15)
    LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 16)
    APP_AD = typing___cast(AdTypeEnum.AdTypeValue, 17)
    LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdTypeValue, 18)
    RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 19)
    LOCAL_AD = typing___cast(AdTypeEnum.AdTypeValue, 20)
    HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdTypeValue, 21)
    DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdTypeValue, 22)
    APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdTypeValue, 23)
    SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdTypeValue, 24)
    VIDEO_BUMPER_AD = typing___cast(AdTypeEnum.AdTypeValue, 25)
    VIDEO_NON_SKIPPABLE_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 26)
    VIDEO_OUTSTREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 27)
    VIDEO_TRUEVIEW_DISCOVERY_AD = typing___cast(AdTypeEnum.AdTypeValue, 28)
    VIDEO_TRUEVIEW_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 29)
    VIDEO_RESPONSIVE_AD = typing___cast(AdTypeEnum.AdTypeValue, 30)
    type___AdType = AdType
    def __init__(self,) -> None: ...

type___AdTypeEnum = AdTypeEnum
