# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerClient(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    client_customer: typing___Text = ...
    hidden: builtin___bool = ...
    level: builtin___int = ...
    time_zone: typing___Text = ...
    test_account: builtin___bool = ...
    manager: builtin___bool = ...
    descriptive_name: typing___Text = ...
    currency_code: typing___Text = ...
    id: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        client_customer: typing___Optional[typing___Text] = None,
        hidden: typing___Optional[builtin___bool] = None,
        level: typing___Optional[builtin___int] = None,
        time_zone: typing___Optional[typing___Text] = None,
        test_account: typing___Optional[builtin___bool] = None,
        manager: typing___Optional[builtin___bool] = None,
        descriptive_name: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_client_customer", b"_client_customer"
        ],
    ) -> typing_extensions___Literal["client_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions___Literal["descriptive_name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hidden", b"_hidden"]
    ) -> typing_extensions___Literal["hidden"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_level", b"_level"]
    ) -> typing_extensions___Literal["level"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_manager", b"_manager"]
    ) -> typing_extensions___Literal["manager"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_test_account", b"_test_account"],
    ) -> typing_extensions___Literal["test_account"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions___Literal["time_zone"]: ...

type___CustomerClient = CustomerClient
