# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomAudienceMemberTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomAudienceMemberTypeValue = typing___NewType(
        "CustomAudienceMemberTypeValue", builtin___int
    )
    type___CustomAudienceMemberTypeValue = CustomAudienceMemberTypeValue
    CustomAudienceMemberType: _CustomAudienceMemberType
    class _CustomAudienceMemberType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 1
        )
        KEYWORD = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 2
        )
        URL = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 3
        )
        PLACE_CATEGORY = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 4
        )
        APP = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 5
        )
    UNSPECIFIED = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 0
    )
    UNKNOWN = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 1
    )
    KEYWORD = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 2
    )
    URL = typing___cast(CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 3)
    PLACE_CATEGORY = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 4
    )
    APP = typing___cast(CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 5)
    type___CustomAudienceMemberType = CustomAudienceMemberType
    def __init__(self,) -> None: ...

type___CustomAudienceMemberTypeEnum = CustomAudienceMemberTypeEnum
