# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BiddingStrategyTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BiddingStrategyTypeValue = typing___NewType(
        "BiddingStrategyTypeValue", builtin___int
    )
    type___BiddingStrategyTypeValue = BiddingStrategyTypeValue
    BiddingStrategyType: _BiddingStrategyType
    class _BiddingStrategyType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 0)
        UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 1)
        COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 16)
        ENHANCED_CPC = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 2
        )
        MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 3)
        MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 4)
        MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 13)
        MAXIMIZE_CONVERSIONS = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 10
        )
        MAXIMIZE_CONVERSION_VALUE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 11
        )
        PAGE_ONE_PROMOTED = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 5
        )
        PERCENT_CPC = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 12
        )
        TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 6)
        TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 14)
        TARGET_IMPRESSION_SHARE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 15
        )
        TARGET_OUTRANK_SHARE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 7
        )
        TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 8)
        TARGET_SPEND = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 9
        )
    UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 0)
    UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 1)
    COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 16)
    ENHANCED_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 2)
    MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 3)
    MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 4)
    MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 13)
    MAXIMIZE_CONVERSIONS = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 10
    )
    MAXIMIZE_CONVERSION_VALUE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 11
    )
    PAGE_ONE_PROMOTED = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 5
    )
    PERCENT_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 12)
    TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 6)
    TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 14)
    TARGET_IMPRESSION_SHARE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 15
    )
    TARGET_OUTRANK_SHARE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 7
    )
    TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 8)
    TARGET_SPEND = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 9)
    type___BiddingStrategyType = BiddingStrategyType
    def __init__(self,) -> None: ...

type___BiddingStrategyTypeEnum = BiddingStrategyTypeEnum
