from typing import Any

class HotelPerformanceViewServiceStub:
    GetHotelPerformanceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class HotelPerformanceViewServiceServicer:
    def GetHotelPerformanceView(self, request: Any, context: Any) -> None: ...

def add_HotelPerformanceViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
