# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AgeRangeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AgeRangeTypeValue = typing___NewType("AgeRangeTypeValue", builtin___int)
    type___AgeRangeTypeValue = AgeRangeTypeValue
    AgeRangeType: _AgeRangeType
    class _AgeRangeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AgeRangeTypeEnum.AgeRangeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 0)
        UNKNOWN = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 1)
        AGE_RANGE_18_24 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503001)
        AGE_RANGE_25_34 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503002)
        AGE_RANGE_35_44 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503003)
        AGE_RANGE_45_54 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503004)
        AGE_RANGE_55_64 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503005)
        AGE_RANGE_65_UP = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503006)
        AGE_RANGE_UNDETERMINED = typing___cast(
            AgeRangeTypeEnum.AgeRangeTypeValue, 503999
        )
    UNSPECIFIED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 0)
    UNKNOWN = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 1)
    AGE_RANGE_18_24 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503001)
    AGE_RANGE_25_34 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503002)
    AGE_RANGE_35_44 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503003)
    AGE_RANGE_45_54 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503004)
    AGE_RANGE_55_64 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503005)
    AGE_RANGE_65_UP = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503006)
    AGE_RANGE_UNDETERMINED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503999)
    type___AgeRangeType = AgeRangeType
    def __init__(self,) -> None: ...

type___AgeRangeTypeEnum = AgeRangeTypeEnum
