# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LeadFormCallToActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LeadFormCallToActionTypeValue = typing___NewType(
        "LeadFormCallToActionTypeValue", builtin___int
    )
    type___LeadFormCallToActionTypeValue = LeadFormCallToActionTypeValue
    LeadFormCallToActionType: _LeadFormCallToActionType
    class _LeadFormCallToActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 0
        )
        UNKNOWN = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 1
        )
        LEARN_MORE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 2
        )
        GET_QUOTE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 3
        )
        APPLY_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 4
        )
        SIGN_UP = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 5
        )
        CONTACT_US = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 6
        )
        SUBSCRIBE = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 7
        )
        DOWNLOAD = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 8
        )
        BOOK_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 9
        )
        GET_OFFER = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 10
        )
        REGISTER = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 11
        )
        GET_INFO = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 12
        )
        REQUEST_DEMO = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 13
        )
        JOIN_NOW = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 14
        )
        GET_STARTED = typing___cast(
            LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 15
        )
    UNSPECIFIED = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 0
    )
    UNKNOWN = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 1
    )
    LEARN_MORE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 2
    )
    GET_QUOTE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 3
    )
    APPLY_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 4
    )
    SIGN_UP = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 5
    )
    CONTACT_US = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 6
    )
    SUBSCRIBE = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 7
    )
    DOWNLOAD = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 8
    )
    BOOK_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 9
    )
    GET_OFFER = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 10
    )
    REGISTER = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 11
    )
    GET_INFO = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 12
    )
    REQUEST_DEMO = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 13
    )
    JOIN_NOW = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 14
    )
    GET_STARTED = typing___cast(
        LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue, 15
    )
    type___LeadFormCallToActionType = LeadFormCallToActionType
    def __init__(self,) -> None: ...

type___LeadFormCallToActionTypeEnum = LeadFormCallToActionTypeEnum
