# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdParameterErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdParameterErrorValue = typing___NewType("AdParameterErrorValue", builtin___int)
    type___AdParameterErrorValue = AdParameterErrorValue
    AdParameterError: _AdParameterError
    class _AdParameterError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdParameterErrorEnum.AdParameterErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 0)
        UNKNOWN = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 1)
        AD_GROUP_CRITERION_MUST_BE_KEYWORD = typing___cast(
            AdParameterErrorEnum.AdParameterErrorValue, 2
        )
        INVALID_INSERTION_TEXT_FORMAT = typing___cast(
            AdParameterErrorEnum.AdParameterErrorValue, 3
        )
    UNSPECIFIED = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 0)
    UNKNOWN = typing___cast(AdParameterErrorEnum.AdParameterErrorValue, 1)
    AD_GROUP_CRITERION_MUST_BE_KEYWORD = typing___cast(
        AdParameterErrorEnum.AdParameterErrorValue, 2
    )
    INVALID_INSERTION_TEXT_FORMAT = typing___cast(
        AdParameterErrorEnum.AdParameterErrorValue, 3
    )
    type___AdParameterError = AdParameterError
    def __init__(self,) -> None: ...

type___AdParameterErrorEnum = AdParameterErrorEnum
