from typing import Any

class MutateJobServiceStub:
    CreateMutateJob: Any = ...
    GetMutateJob: Any = ...
    ListMutateJobResults: Any = ...
    RunMutateJob: Any = ...
    AddMutateJobOperations: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MutateJobServiceServicer:
    def CreateMutateJob(self, request: Any, context: Any) -> None: ...
    def GetMutateJob(self, request: Any, context: Any) -> None: ...
    def ListMutateJobResults(self, request: Any, context: Any) -> None: ...
    def RunMutateJob(self, request: Any, context: Any) -> None: ...
    def AddMutateJobOperations(self, request: Any, context: Any) -> None: ...

def add_MutateJobServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
