# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SlotEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SlotValue = typing___NewType("SlotValue", builtin___int)
    type___SlotValue = SlotValue
    Slot: _Slot
    class _Slot(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SlotEnum.SlotValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SlotEnum.SlotValue, 0)
        UNKNOWN = typing___cast(SlotEnum.SlotValue, 1)
        SEARCH_SIDE = typing___cast(SlotEnum.SlotValue, 2)
        SEARCH_TOP = typing___cast(SlotEnum.SlotValue, 3)
        SEARCH_OTHER = typing___cast(SlotEnum.SlotValue, 4)
        CONTENT = typing___cast(SlotEnum.SlotValue, 5)
        SEARCH_PARTNER_TOP = typing___cast(SlotEnum.SlotValue, 6)
        SEARCH_PARTNER_OTHER = typing___cast(SlotEnum.SlotValue, 7)
        MIXED = typing___cast(SlotEnum.SlotValue, 8)
    UNSPECIFIED = typing___cast(SlotEnum.SlotValue, 0)
    UNKNOWN = typing___cast(SlotEnum.SlotValue, 1)
    SEARCH_SIDE = typing___cast(SlotEnum.SlotValue, 2)
    SEARCH_TOP = typing___cast(SlotEnum.SlotValue, 3)
    SEARCH_OTHER = typing___cast(SlotEnum.SlotValue, 4)
    CONTENT = typing___cast(SlotEnum.SlotValue, 5)
    SEARCH_PARTNER_TOP = typing___cast(SlotEnum.SlotValue, 6)
    SEARCH_PARTNER_OTHER = typing___cast(SlotEnum.SlotValue, 7)
    MIXED = typing___cast(SlotEnum.SlotValue, 8)
    type___Slot = Slot
    def __init__(self,) -> None: ...

type___SlotEnum = SlotEnum
