from typing import Any

class DynamicSearchAdsSearchTermViewServiceStub:
    GetDynamicSearchAdsSearchTermView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DynamicSearchAdsSearchTermViewServiceServicer:
    def GetDynamicSearchAdsSearchTermView(self, request: Any, context: Any) -> None: ...

def add_DynamicSearchAdsSearchTermViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
