# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanCompetitionLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanCompetitionLevelValue = typing___NewType(
        "KeywordPlanCompetitionLevelValue", builtin___int
    )
    type___KeywordPlanCompetitionLevelValue = KeywordPlanCompetitionLevelValue
    KeywordPlanCompetitionLevel: _KeywordPlanCompetitionLevel
    class _KeywordPlanCompetitionLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 0
        )
        UNKNOWN = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 1
        )
        LOW = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 2
        )
        MEDIUM = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 3
        )
        HIGH = typing___cast(
            KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 4
        )
    UNSPECIFIED = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 0
    )
    UNKNOWN = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 1
    )
    LOW = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 2
    )
    MEDIUM = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 3
    )
    HIGH = typing___cast(
        KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue, 4
    )
    type___KeywordPlanCompetitionLevel = KeywordPlanCompetitionLevel
    def __init__(self,) -> None: ...

type___KeywordPlanCompetitionLevelEnum = KeywordPlanCompetitionLevelEnum
