# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignDraftErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignDraftErrorValue = typing___NewType("CampaignDraftErrorValue", builtin___int)
    type___CampaignDraftErrorValue = CampaignDraftErrorValue
    CampaignDraftError: _CampaignDraftError
    class _CampaignDraftError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignDraftErrorEnum.CampaignDraftErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 0)
        UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 1)
        DUPLICATE_DRAFT_NAME = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 2
        )
        INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 3
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 4
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 5
        )
        CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 6
        )
        CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 7
        )
        INVALID_DRAFT_CHANGE = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 8
        )
        INVALID_STATUS_TRANSITION = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 9
        )
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 10
        )
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(
            CampaignDraftErrorEnum.CampaignDraftErrorValue, 11
        )
    UNSPECIFIED = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 0)
    UNKNOWN = typing___cast(CampaignDraftErrorEnum.CampaignDraftErrorValue, 1)
    DUPLICATE_DRAFT_NAME = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 2
    )
    INVALID_STATUS_TRANSITION_FROM_REMOVED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 3
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 4
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 5
    )
    CUSTOMER_CANNOT_CREATE_DRAFT = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 6
    )
    CAMPAIGN_CANNOT_CREATE_DRAFT = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 7
    )
    INVALID_DRAFT_CHANGE = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 8
    )
    INVALID_STATUS_TRANSITION = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 9
    )
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 10
    )
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = typing___cast(
        CampaignDraftErrorEnum.CampaignDraftErrorValue, 11
    )
    type___CampaignDraftError = CampaignDraftError
    def __init__(self,) -> None: ...

type___CampaignDraftErrorEnum = CampaignDraftErrorEnum
