# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OperatorErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OperatorErrorValue = typing___NewType("OperatorErrorValue", builtin___int)
    type___OperatorErrorValue = OperatorErrorValue
    OperatorError: _OperatorError
    class _OperatorError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OperatorErrorEnum.OperatorErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 0)
        UNKNOWN = typing___cast(OperatorErrorEnum.OperatorErrorValue, 1)
        OPERATOR_NOT_SUPPORTED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 2)
    UNSPECIFIED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 0)
    UNKNOWN = typing___cast(OperatorErrorEnum.OperatorErrorValue, 1)
    OPERATOR_NOT_SUPPORTED = typing___cast(OperatorErrorEnum.OperatorErrorValue, 2)
    type___OperatorError = OperatorError
    def __init__(self,) -> None: ...

type___OperatorErrorEnum = OperatorErrorEnum
