# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserDataJobErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OfflineUserDataJobErrorValue = typing___NewType(
        "OfflineUserDataJobErrorValue", builtin___int
    )
    type___OfflineUserDataJobErrorValue = OfflineUserDataJobErrorValue
    OfflineUserDataJobError: _OfflineUserDataJobError
    class _OfflineUserDataJobError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 0
        )
        UNKNOWN = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 1
        )
        INVALID_USER_LIST_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 3
        )
        INVALID_USER_LIST_TYPE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 4
        )
        NOT_WHITELISTED_FOR_USER_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 5
        )
        INCOMPATIBLE_UPLOAD_KEY_TYPE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 6
        )
        MISSING_USER_IDENTIFIER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 7
        )
        INVALID_MOBILE_ID_FORMAT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 8
        )
        TOO_MANY_USER_IDENTIFIERS = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 9
        )
        NOT_WHITELISTED_FOR_STORE_SALES_DIRECT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 10
        )
        INVALID_PARTNER_ID = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 11
        )
        INVALID_ENCODING = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 12
        )
        INVALID_COUNTRY_CODE = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 13
        )
        INCOMPATIBLE_USER_IDENTIFIER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 14
        )
        FUTURE_TRANSACTION_TIME = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 15
        )
        INVALID_CONVERSION_ACTION = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 16
        )
        MOBILE_ID_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 17
        )
        INVALID_OPERATION_ORDER = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 18
        )
        CONFLICTING_OPERATION = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 19
        )
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 21
        )
        JOB_ALREADY_STARTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 22
        )
        REMOVE_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 23
        )
        REMOVE_ALL_NOT_SUPPORTED = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 24
        )
        INVALID_SHA256_FORMAT = typing___cast(
            OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 25
        )
    UNSPECIFIED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 0
    )
    UNKNOWN = typing___cast(OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 1)
    INVALID_USER_LIST_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 3
    )
    INVALID_USER_LIST_TYPE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 4
    )
    NOT_WHITELISTED_FOR_USER_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 5
    )
    INCOMPATIBLE_UPLOAD_KEY_TYPE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 6
    )
    MISSING_USER_IDENTIFIER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 7
    )
    INVALID_MOBILE_ID_FORMAT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 8
    )
    TOO_MANY_USER_IDENTIFIERS = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 9
    )
    NOT_WHITELISTED_FOR_STORE_SALES_DIRECT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 10
    )
    INVALID_PARTNER_ID = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 11
    )
    INVALID_ENCODING = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 12
    )
    INVALID_COUNTRY_CODE = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 13
    )
    INCOMPATIBLE_USER_IDENTIFIER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 14
    )
    FUTURE_TRANSACTION_TIME = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 15
    )
    INVALID_CONVERSION_ACTION = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 16
    )
    MOBILE_ID_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 17
    )
    INVALID_OPERATION_ORDER = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 18
    )
    CONFLICTING_OPERATION = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 19
    )
    EXTERNAL_UPDATE_ID_ALREADY_EXISTS = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 21
    )
    JOB_ALREADY_STARTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 22
    )
    REMOVE_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 23
    )
    REMOVE_ALL_NOT_SUPPORTED = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 24
    )
    INVALID_SHA256_FORMAT = typing___cast(
        OfflineUserDataJobErrorEnum.OfflineUserDataJobErrorValue, 25
    )
    type___OfflineUserDataJobError = OfflineUserDataJobError
    def __init__(self,) -> None: ...

type___OfflineUserDataJobErrorEnum = OfflineUserDataJobErrorEnum
