from typing import Any

class BatchJobServiceStub:
    MutateBatchJob: Any = ...
    GetBatchJob: Any = ...
    ListBatchJobResults: Any = ...
    RunBatchJob: Any = ...
    AddBatchJobOperations: Any = ...
    def __init__(self, channel: Any) -> None: ...

class BatchJobServiceServicer:
    def MutateBatchJob(self, request: Any, context: Any) -> None: ...
    def GetBatchJob(self, request: Any, context: Any) -> None: ...
    def ListBatchJobResults(self, request: Any, context: Any) -> None: ...
    def RunBatchJob(self, request: Any, context: Any) -> None: ...
    def AddBatchJobOperations(self, request: Any, context: Any) -> None: ...

def add_BatchJobServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
