# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeEventResourceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeEventResourceTypeValue = typing___NewType(
        "ChangeEventResourceTypeValue", builtin___int
    )
    type___ChangeEventResourceTypeValue = ChangeEventResourceTypeValue
    ChangeEventResourceType: _ChangeEventResourceType
    class _ChangeEventResourceType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 0
        )
        UNKNOWN = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 1
        )
        AD = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 2)
        AD_GROUP = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 3
        )
        AD_GROUP_CRITERION = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 4
        )
        CAMPAIGN = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 5
        )
        CAMPAIGN_BUDGET = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 6
        )
        AD_GROUP_BID_MODIFIER = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 7
        )
        CAMPAIGN_CRITERION = typing___cast(
            ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 8
        )
    UNSPECIFIED = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 0
    )
    UNKNOWN = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 1)
    AD = typing___cast(ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 2)
    AD_GROUP = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 3
    )
    AD_GROUP_CRITERION = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 4
    )
    CAMPAIGN = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 5
    )
    CAMPAIGN_BUDGET = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 6
    )
    AD_GROUP_BID_MODIFIER = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 7
    )
    CAMPAIGN_CRITERION = typing___cast(
        ChangeEventResourceTypeEnum.ChangeEventResourceTypeValue, 8
    )
    type___ChangeEventResourceType = ChangeEventResourceType
    def __init__(self,) -> None: ...

type___ChangeEventResourceTypeEnum = ChangeEventResourceTypeEnum
