# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdSharingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdSharingErrorValue = typing___NewType("AdSharingErrorValue", builtin___int)
    type___AdSharingErrorValue = AdSharingErrorValue
    AdSharingError: _AdSharingError
    class _AdSharingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdSharingErrorEnum.AdSharingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 0)
        UNKNOWN = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 1)
        AD_GROUP_ALREADY_CONTAINS_AD = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 2
        )
        INCOMPATIBLE_AD_UNDER_AD_GROUP = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 3
        )
        CANNOT_SHARE_INACTIVE_AD = typing___cast(
            AdSharingErrorEnum.AdSharingErrorValue, 4
        )
    UNSPECIFIED = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 0)
    UNKNOWN = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 1)
    AD_GROUP_ALREADY_CONTAINS_AD = typing___cast(
        AdSharingErrorEnum.AdSharingErrorValue, 2
    )
    INCOMPATIBLE_AD_UNDER_AD_GROUP = typing___cast(
        AdSharingErrorEnum.AdSharingErrorValue, 3
    )
    CANNOT_SHARE_INACTIVE_AD = typing___cast(AdSharingErrorEnum.AdSharingErrorValue, 4)
    type___AdSharingError = AdSharingError
    def __init__(self,) -> None: ...

type___AdSharingErrorEnum = AdSharingErrorEnum
