from typing import Any

class CustomerClientServiceStub:
    GetCustomerClient: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerClientServiceServicer:
    def GetCustomerClient(self, request: Any, context: Any) -> None: ...

def add_CustomerClientServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
