from typing import Any

class IncomeRangeViewServiceStub:
    GetIncomeRangeView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class IncomeRangeViewServiceServicer:
    def GetIncomeRangeView(self, request: Any, context: Any) -> None: ...

def add_IncomeRangeViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
