from typing import Any

class AssetServiceStub:
    GetAsset: Any = ...
    MutateAssets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AssetServiceServicer:
    def GetAsset(self, request: Any, context: Any) -> None: ...
    def MutateAssets(self, request: Any, context: Any) -> None: ...

def add_AssetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
