# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdvertisingChannelTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdvertisingChannelTypeValue = typing___NewType(
        "AdvertisingChannelTypeValue", builtin___int
    )
    type___AdvertisingChannelTypeValue = AdvertisingChannelTypeValue
    AdvertisingChannelType: _AdvertisingChannelType
    class _AdvertisingChannelType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 0
        )
        UNKNOWN = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 1
        )
        SEARCH = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 2
        )
        DISPLAY = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 3
        )
        SHOPPING = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 4
        )
        HOTEL = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 5)
        VIDEO = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 6)
        MULTI_CHANNEL = typing___cast(
            AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 7
        )
    UNSPECIFIED = typing___cast(
        AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 0
    )
    UNKNOWN = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 1)
    SEARCH = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 2)
    DISPLAY = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 3)
    SHOPPING = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 4)
    HOTEL = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 5)
    VIDEO = typing___cast(AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 6)
    MULTI_CHANNEL = typing___cast(
        AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue, 7
    )
    type___AdvertisingChannelType = AdvertisingChannelType
    def __init__(self,) -> None: ...

type___AdvertisingChannelTypeEnum = AdvertisingChannelTypeEnum
