# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.asset_policy_pb2 import (
    AdAssetPolicySummary as google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary,
)
from google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2 import (
    AssetPerformanceLabelEnum as google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum,
)
from google.ads.google_ads.v6.proto.enums.served_asset_field_type_pb2 import (
    ServedAssetFieldTypeEnum as google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdTextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    pinned_field: google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue = ...
    asset_performance_label: google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue = ...
    @property
    def policy_summary_info(
        self,
    ) -> google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        text: typing___Optional[typing___Text] = None,
        pinned_field: typing___Optional[
            google___ads___googleads___v6___enums___served_asset_field_type_pb2___ServedAssetFieldTypeEnum.ServedAssetFieldTypeValue
        ] = None,
        asset_performance_label: typing___Optional[
            google___ads___googleads___v6___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue
        ] = None,
        policy_summary_info: typing___Optional[
            google___ads___googleads___v6___common___asset_policy_pb2___AdAssetPolicySummary
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_text",
            b"_text",
            "asset_performance_label",
            b"asset_performance_label",
            "pinned_field",
            b"pinned_field",
            "policy_summary_info",
            b"policy_summary_info",
            "text",
            b"text",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___AdTextAsset = AdTextAsset

class AdImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdImageAsset = AdImageAsset

class AdVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdVideoAsset = AdVideoAsset

class AdMediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    asset: typing___Text = ...
    def __init__(self, *, asset: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_asset", b"_asset", "asset", b"asset"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...

type___AdMediaBundleAsset = AdMediaBundleAsset
