from typing import Any

class AdGroupBidModifierServiceStub:
    GetAdGroupBidModifier: Any = ...
    MutateAdGroupBidModifiers: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupBidModifierServiceServicer:
    def GetAdGroupBidModifier(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupBidModifiers(self, request: Any, context: Any) -> None: ...

def add_AdGroupBidModifierServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
