from typing import Any

class KeywordPlanAdGroupKeywordServiceStub:
    GetKeywordPlanAdGroupKeyword: Any = ...
    MutateKeywordPlanAdGroupKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanAdGroupKeywordServiceServicer:
    def GetKeywordPlanAdGroupKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanAdGroupKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanAdGroupKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
