from typing import Any

class CampaignCriterionServiceStub:
    GetCampaignCriterion: Any = ...
    MutateCampaignCriteria: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignCriterionServiceServicer:
    def GetCampaignCriterion(self, request: Any, context: Any) -> None: ...
    def MutateCampaignCriteria(self, request: Any, context: Any) -> None: ...

def add_CampaignCriterionServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
