# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class HotelDateSelectionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    HotelDateSelectionTypeValue = typing___NewType(
        "HotelDateSelectionTypeValue", builtin___int
    )
    type___HotelDateSelectionTypeValue = HotelDateSelectionTypeValue
    HotelDateSelectionType: _HotelDateSelectionType
    class _HotelDateSelectionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 0
        )
        UNKNOWN = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 1
        )
        DEFAULT_SELECTION = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 50
        )
        USER_SELECTED = typing___cast(
            HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 51
        )
    UNSPECIFIED = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 0
    )
    UNKNOWN = typing___cast(HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 1)
    DEFAULT_SELECTION = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 50
    )
    USER_SELECTED = typing___cast(
        HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue, 51
    )
    type___HotelDateSelectionType = HotelDateSelectionType
    def __init__(self,) -> None: ...

type___HotelDateSelectionTypeEnum = HotelDateSelectionTypeEnum
