# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry,
)
from google.ads.google_ads.v5.proto.enums.ad_group_ad_status_pb2 import (
    AdGroupAdStatusEnum as google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.ad_strength_pb2 import (
    AdStrengthEnum as google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)
from google.ads.google_ads.v5.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v5___resources___ad_pb2___Ad,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAd(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatusValue = ...
    ad_group: typing___Text = ...
    ad_strength: google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum.AdStrengthValue = ...
    @property
    def ad(self) -> google___ads___googleads___v5___resources___ad_pb2___Ad: ...
    @property
    def policy_summary(self) -> type___AdGroupAdPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatusValue
        ] = None,
        ad_group: typing___Optional[typing___Text] = None,
        ad: typing___Optional[
            google___ads___googleads___v5___resources___ad_pb2___Ad
        ] = None,
        policy_summary: typing___Optional[type___AdGroupAdPolicySummary] = None,
        ad_strength: typing___Optional[
            google___ads___googleads___v5___enums___ad_strength_pb2___AdStrengthEnum.AdStrengthValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group",
            b"_ad_group",
            "ad",
            b"ad",
            "ad_group",
            b"ad_group",
            "ad_strength",
            b"ad_strength",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions___Literal["ad_group"]: ...

type___AdGroupAd = AdGroupAd

class AdGroupAdPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status: google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue = ...
    approval_status: google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
        review_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

type___AdGroupAdPolicySummary = AdGroupAdPolicySummary
