from typing import Any

class ProductGroupViewServiceStub:
    GetProductGroupView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ProductGroupViewServiceServicer:
    def GetProductGroupView(self, request: Any, context: Any) -> None: ...

def add_ProductGroupViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
