# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignCriterionStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignCriterionStatusValue = typing___NewType(
        "CampaignCriterionStatusValue", builtin___int
    )
    type___CampaignCriterionStatusValue = CampaignCriterionStatusValue
    CampaignCriterionStatus: _CampaignCriterionStatus
    class _CampaignCriterionStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 0
        )
        UNKNOWN = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 1
        )
        ENABLED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 2
        )
        PAUSED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 3
        )
        REMOVED = typing___cast(
            CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 4
        )
    UNSPECIFIED = typing___cast(
        CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 0
    )
    UNKNOWN = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 1)
    ENABLED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 2)
    PAUSED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 3)
    REMOVED = typing___cast(CampaignCriterionStatusEnum.CampaignCriterionStatusValue, 4)
    type___CampaignCriterionStatus = CampaignCriterionStatus
    def __init__(self,) -> None: ...

type___CampaignCriterionStatusEnum = CampaignCriterionStatusEnum
