from typing import Any

class GroupPlacementViewServiceStub:
    GetGroupPlacementView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GroupPlacementViewServiceServicer:
    def GetGroupPlacementView(self, request: Any, context: Any) -> None: ...

def add_GroupPlacementViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...
