# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BillingSetupErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BillingSetupErrorValue = typing___NewType("BillingSetupErrorValue", builtin___int)
    type___BillingSetupErrorValue = BillingSetupErrorValue
    BillingSetupError: _BillingSetupError
    class _BillingSetupError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BillingSetupErrorEnum.BillingSetupErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 0)
        UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 1)
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 2
        )
        CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 3
        )
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 4
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 5
        )
        INVALID_PAYMENTS_ACCOUNT = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 6
        )
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 7
        )
        INVALID_START_TIME_TYPE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 8
        )
        THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 9
        )
        BILLING_SETUP_IN_PROGRESS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 10
        )
        NO_SIGNUP_PERMISSION = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 11
        )
        CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 12
        )
        PAYMENTS_PROFILE_NOT_FOUND = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 13
        )
        PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 14
        )
        PAYMENTS_PROFILE_INELIGIBLE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 15
        )
        PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 16
        )
        CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 17
        )
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = typing___cast(
            BillingSetupErrorEnum.BillingSetupErrorValue, 19
        )
    UNSPECIFIED = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 0)
    UNKNOWN = typing___cast(BillingSetupErrorEnum.BillingSetupErrorValue, 1)
    CANNOT_USE_EXISTING_AND_NEW_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 2
    )
    CANNOT_REMOVE_STARTED_BILLING_SETUP = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 3
    )
    CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 4
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 5
    )
    INVALID_PAYMENTS_ACCOUNT = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 6
    )
    BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 7
    )
    INVALID_START_TIME_TYPE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 8
    )
    THIRD_PARTY_ALREADY_HAS_BILLING = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 9
    )
    BILLING_SETUP_IN_PROGRESS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 10
    )
    NO_SIGNUP_PERMISSION = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 11
    )
    CHANGE_OF_BILL_TO_IN_PROGRESS = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 12
    )
    PAYMENTS_PROFILE_NOT_FOUND = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 13
    )
    PAYMENTS_ACCOUNT_NOT_FOUND = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 14
    )
    PAYMENTS_PROFILE_INELIGIBLE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 15
    )
    PAYMENTS_ACCOUNT_INELIGIBLE = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 16
    )
    CUSTOMER_NEEDS_INTERNAL_APPROVAL = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 17
    )
    PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH = typing___cast(
        BillingSetupErrorEnum.BillingSetupErrorValue, 19
    )
    type___BillingSetupError = BillingSetupError
    def __init__(self,) -> None: ...

type___BillingSetupErrorEnum = BillingSetupErrorEnum
