# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductTypeLevelEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ProductTypeLevelValue = typing___NewType("ProductTypeLevelValue", builtin___int)
    type___ProductTypeLevelValue = ProductTypeLevelValue
    ProductTypeLevel: _ProductTypeLevel
    class _ProductTypeLevel(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ProductTypeLevelEnum.ProductTypeLevelValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 0)
        UNKNOWN = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 1)
        LEVEL1 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 7)
        LEVEL2 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 8)
        LEVEL3 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 9)
        LEVEL4 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 10)
        LEVEL5 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 11)
    UNSPECIFIED = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 0)
    UNKNOWN = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 1)
    LEVEL1 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 7)
    LEVEL2 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 8)
    LEVEL3 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 9)
    LEVEL4 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 10)
    LEVEL5 = typing___cast(ProductTypeLevelEnum.ProductTypeLevelValue, 11)
    type___ProductTypeLevel = ProductTypeLevel
    def __init__(self,) -> None: ...

type___ProductTypeLevelEnum = ProductTypeLevelEnum
